import { BehaviorSubject, Observable, OperatorFunction, Subscription } from 'rxjs';
import { DataSourceInitialValues, MapperFn, RequestMethod } from './types';
import { DataSourceOptions } from './data-source-options';
import { DataSourceCache } from '../cache/data-source-cache';
import { DataSourceBase } from './data-source-base';
declare class CacheResponse<RESPONSE> {
    readonly response: RESPONSE;
    get exists(): boolean;
    constructor(response: RESPONSE);
}
/**
 * Abstract implementation for plain DataSources.
 */
export declare class AbstractDataSource<RESPONSE, DATA = RESPONSE, REQ_MODEL = void, OPTIONS extends DataSourceOptions<RESPONSE, DATA, REQ_MODEL> = DataSourceOptions<RESPONSE, DATA, REQ_MODEL>> implements DataSourceBase<REQ_MODEL, DATA> {
    protected readonly options?: OPTIONS;
    /**
     * Indicates whether the request is initiated and in progress.
     */
    get loading$(): BehaviorSubject<boolean>;
    protected readonly _loading$: BehaviorSubject<boolean>;
    /**
     * Stream of request results. Conditionally mapped if a mapping function is provided.
     */
    get result$(): BehaviorSubject<DATA>;
    protected readonly _result$: BehaviorSubject<DATA>;
    /**
     * Stream of errors.
     */
    get error$(): BehaviorSubject<Error>;
    protected _error$: BehaviorSubject<Error>;
    /**
     * Application wide unique DataSource name.
     */
    get name(): string;
    /**
     * Method to request data/results. Not implemented because it can be an injected dependency in Injectables.
     */
    protected get requestMethod(): RequestMethod<REQ_MODEL, RESPONSE>;
    /**
     * Response mapping function.
     */
    protected get map(): MapperFn<RESPONSE, DATA>;
    /**
     * Timeout after the request will fail if not resolved.
     */
    protected get timeout(): number;
    /**
     * Number of times to retry the request.
     */
    protected get retry(): number;
    /**
     * Cache object.
     */
    protected cache: DataSourceCache<REQ_MODEL, RESPONSE>;
    /**
     * Subscription to the request call.
     */
    protected requestSubscription: Subscription;
    /**
     * Default initial values used for the exposed observables.
     */
    protected defaultInitialValues: DataSourceInitialValues<DATA>;
    constructor(options?: OPTIONS);
    /**
     * Triggers the request for retrieving data.
     */
    request(model: REQ_MODEL): Observable<DATA>;
    /**
     * Cancels the ongoing request.
     */
    cancelRequest(): void;
    /**
     * Resets the DataSource to it's initial state.
     *
     * @param toDefault - If the DS has initial values provided it will reset to them. If toDefault is set to true, this
     * will be overriden and default DS values will be used.
     */
    reset(toDefault?: boolean): void;
    /**
     * It unsubscribes from any ongoing request and completes all exposed observables.
     */
    complete(): void;
    protected getInitialValues(): DataSourceInitialValues<DATA>;
    protected startLoading(): void;
    protected endLoading(): void;
    protected respondFromCache(model?: REQ_MODEL): CacheResponse<RESPONSE>;
    private writeToCache;
    protected getRequestPipes(): OperatorFunction<RESPONSE, RESPONSE>[];
    protected mapResponse(response: RESPONSE): DATA;
    protected success(data: DATA): void;
    protected error(error: Error): void;
    protected requestComplete(): void;
    protected setUpCache(): void;
}
export {};
//# sourceMappingURL=abstract-data-source.d.ts.map