/**
 * A generic interface that is implemented by objects to compare an internal value.
 *
 * An example use-case are objects be piped in order to be compared to a value async.
 *
 * Example:
 *
 * <ng-container *ngIf="object$ | async | imaginaryComparePipe:'is':5">
 * <ng-container *ngIf="object$ | async | imaginaryComparePipe:'not':5">
 * <ng-container *ngIf="object$ | async | imaginaryComparePipe:'gt':5">
 * <ng-container *ngIf="object$ | async | imaginaryComparePipe:'gte':5">
 * <ng-container *ngIf="object$ | async | imaginaryComparePipe:'lt':5">
 * <ng-container *ngIf="object$ | async | imaginaryComparePipe:'lte':5">
 */
export interface Comparator<T> {
    /**
     * Equality comparison.
     */
    is(value: T, ...rest: T[]): boolean;
    /**
     * Equality comparison to any of the passed values. Acts as an OR.
     */
    isIn(...value: T[]): boolean;
    /**
     * Not equal comparison.
     */
    not(value: T): boolean;
    /**
     * Not equal comparison to all passed values. Acts as an AND.
     */
    notIn(...value: T[]): boolean;
    /**
     * Greater than comparison.
     */
    gt(value: T): boolean;
    /**
     * Greater than or equal comparison.
     */
    gte(value: T): boolean;
    /**
     * Less than comparison.
     */
    lt(value: T): boolean;
    /**
     * Less than or equal comparison.
     */
    lte(value: T): boolean;
}
//# sourceMappingURL=comparator.d.ts.map