import { ChangeDetectorRef, ElementRef } from '@angular/core';
import { Subject } from 'rxjs';
import { SieIcon, SieIconRegistryService } from '@siemens/icons';
import { BreakpointKey, ComponentBreakpointDefinition } from '@siemens/core';
import * as i0 from "@angular/core";
/**
 * # Accordion Item Component
 *
 * The accordion item represents each individual item within the accordion component
 * (although the accordion item component can be used independently,
 * always use it in combination with the accordion component).
 *
 * ## Component variations
 *
 * There are no variations.
 *
 * ## Content
 *
 * The content of the accordion item component can be any valid markup.
 *
 * ## Code example
 * @example
 * Template:
 * ```html
 * <sie-ui-accordion-item
 *   *ngFor="let item of accordionItems"
 *   [headline]="item.headline"
 *   [subHeadline]="item.subHeadline"
 *   [showTopBorder]="item.showTopBorder"
 *   [headlineBold]="item.headlineBold"
 *   [icon]="item.icon"
 *   [id]="item.id"
 *   [open]="item.open"
 * >
 *   <div>{{ item.html }}</div>
 * </sie-ui-accordion-item>
 * ```
 *
 * Accordion item data example:
 * ```js
 *  accordionItems = [
 *   {
 *     headline: 'Headline',
 *     subHeadline: 'Sub Headline',
 *     showTopBorder: true,
 *     icon: SieIcon.Information,
 *     id: 'test-id',
 *     open: false,
 *     html: 'Lorem ipsum dolor sit amet, consetetur sadipscing elitr'
 *   },
 *   {
 *     headline: 'Headline 2',
 *     showTopBorder: true,
 *     headlineBold: true,
 *     id: 'test-id-2',
 *     open: true,
 *     html: 'Hello World!'
 *   }
 * ];
 * ```
 */
export declare class UiAccordionItemComponent {
    iconReg: SieIconRegistryService;
    private readonly cdr;
    /**
     * Defines the headline that is shown above the accordion item.
     */
    headline: string;
    /**
     * Defines optional subheadline shown below headline in open and closed state
     */
    subHeadline: string;
    /**
     * Defines the identification of the accordion item.
     */
    id: string;
    /**
     * @param value Defines if the top border on accordion item should be shown.
     * @default false
     */
    set showTopBorder(value: boolean);
    get showTopBorder(): boolean;
    /**
     * @param value defines the look of the headline: regular or bold (enhanced, bigger)
     * @default false
     */
    set headlineBold(value: boolean);
    get headlineBold(): boolean;
    /**
     * @param icon {@link SieIcon Icon} Defines optional custom icon before the headline
     */
    set icon(icon: SieIcon);
    get icon(): SieIcon;
    /**
     * @param open Defines if the accordion item should be expanded by default.
     * @default false
     */
    set open(open: boolean);
    get open(): boolean;
    /**
     * @param value Defines if the accordion should display custom header content or not. It becomes true once header
     * content for the item is correctly provided.
     * @default false
     */
    set customHeaderContent(value: boolean);
    get customHeaderContent(): boolean;
    /**
     * Event triggered when the accordion item is clicked.
     */
    clicked: Subject<boolean>;
    /** @ignore */
    accordionBody: ElementRef<HTMLElement>;
    /** @ignore */
    accordionItem: ElementRef<HTMLElement>;
    /** @ignore */
    readonly componentViewports: ComponentBreakpointDefinition;
    /** @ignore */
    hoverActive: boolean;
    /** @ignore */
    animationRunning: boolean;
    /** @ignore */
    userAction: boolean;
    /** @ignore */
    breakpoint: BreakpointKey;
    private _showTopBorder;
    private _open;
    private _headlineBold;
    private _icon;
    private _customHeaderContent;
    constructor(iconReg: SieIconRegistryService, cdr: ChangeDetectorRef);
    /** @ignore */
    setBreakpoint(breakpoint: BreakpointKey): void;
    /** @ignore */
    onToggle(): void;
    /** @ignore */
    mouseEnter(): void;
    /** @ignore */
    mouseLeave(): void;
    /** @ignore */
    onAnimationEvent(): void;
    stopHeaderPropagation(event: Event): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<UiAccordionItemComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<UiAccordionItemComponent, "sie-ui-accordion-item", never, { "headline": { "alias": "headline"; "required": false; }; "subHeadline": { "alias": "subHeadline"; "required": false; }; "id": { "alias": "id"; "required": false; }; "showTopBorder": { "alias": "showTopBorder"; "required": false; }; "headlineBold": { "alias": "headlineBold"; "required": false; }; "icon": { "alias": "icon"; "required": false; }; "open": { "alias": "open"; "required": false; }; "customHeaderContent": { "alias": "customHeaderContent"; "required": false; }; }, { "clicked": "clicked"; }, never, ["[headerSlot]", "*"], false, never>;
}
//# sourceMappingURL=ui-accordion-item.component.d.ts.map