import { OnChanges, SimpleChanges } from '@angular/core';
import { ThemeVariant } from '@siemens/core';
import { SieIcon, SieIconRegistryService } from '@siemens/icons';
import { Subject } from 'rxjs';
import { UiColorHashService } from '../services/ui-color-hashing.service';
import { UiAccountIdHashingOption, UiAccountIdSize, UiAccountIdVariant, UiAccountStatus } from './ui-account-identifier.model';
import { UiLabelBadgeModel } from '../ui-label-badge/ui-label-badge.model';
import * as i0 from "@angular/core";
/**
 * # Account Identifier component
 *
 * Account identifier identifies a particular user in their current (pre-/post-)login context.
 *
 * ## Component variations
 *
 * - avatar (displays only avatar)
 * - name (displays name and avatar)
 * - name-primary (displays name, primary meta, and avatar)
 * - name-action (displays name, secondary meta as action and avatar) - M - XL size only
 * - primary-secondary (displays primary and secondary meta, and avatar) - XS size only
 * - name-primary-secondary (displays name, primary and secondary meta, and avatar) - M - XL size only
 * - name-primary-action (displays name, primary, secondary meta as action and avatar) - M - XL size only
 *
 * ## Content
 *
 * The account identifier component does not accept any content.
 *
 * ## Code example
 * @example ```html
 * <h1>Avatar</h1>
 * <sie-ui-account-identifier
 *   size="xs"
 *   mode="dark"
 *   variant="avatar"
 *   initials="BZ"
 *   name="Benno Zerr"
 *   primaryMetaData="Primary meta information"
 *   secondaryMetaData="Secondary meta information"
 *   avatarImage="https://..."
 * ></sie-ui-account-identifier>
 *
 * <h1>Regular Account Identifier with name and action</h1>
 * <sie-ui-account-identifier
 *   size="l"
 *   mode="light"
 *   variant="name-primary-action"
 *   initials="ML"
 *   name="Maximilian Leutheusser-Schnarrenberger"
 *   primary-meta-data="Primary meta information"
 *   greetings="Welcome back Maximilian Leutheusser-Schnarrenberger!"
 *   link-text="Edit Profile"
 * >
 * </sie-ui-account-identifier>
 * ```
 */
export declare class UiAccountIdentifierComponent implements OnChanges {
    readonly iconReg: SieIconRegistryService;
    private readonly colorHashService;
    /**
     * Defines the {@link UiAccountIdSize Size} of the component
     * @default 'xs'
     */
    size: UiAccountIdSize;
    /**
     * Defines the {@link ThemeVariant Mode} of the component
     * @default 'light'
     */
    mode: ThemeVariant;
    /**
     * Defines which elements of the component should be shown. Checkout {@link UiAccountIdVariant} for possible combinations.
     * @default 'avatar'
     */
    variant: UiAccountIdVariant;
    /**
     * Defines the activity {@link UiAccountStatus status} of the user
     * @default 'neutral'
     */
    status: UiAccountStatus;
    /**
     * Defines the name of the user
     */
    name: string;
    /**
     * Defines the initials of the user
     */
    initials: string;
    /**
     * Defines the primary metadata
     */
    primaryMetaData: string;
    /**
     * Defines the secondary metadata
     */
    secondaryMetaData: string;
    /**
     * Sets the text that represents the link (mandatory for link display)
     */
    linkText: string;
    /**
     * Defines the greeting text
     */
    greetings: string;
    /**
     * Defines which part of `name` and `primaryMetaData` will be highlighted
     */
    searchHighlight: string;
    /**
     * Defines the picture of the user
     */
    avatarImage: string;
    /**
     * Defines the badge data
     */
    badgeData: UiLabelBadgeModel;
    /**
     * @param networkIcon Sets the icon that represents the current network used (given by the user rights from API)
     */
    set networkIcon(networkIcon: SieIcon);
    get networkIcon(): SieIcon;
    /**
     * @param value Defines which {@link UiAccountIdHashingOption attribute} should be used for color hashing to determine the background color
     */
    set forHashing(value: UiAccountIdHashingOption);
    get forHashing(): UiAccountIdHashingOption;
    /**
     * @param disabled Defines whether the component has a disabled style or not
     * @default false
     */
    set disabled(disabled: boolean);
    get disabled(): boolean;
    /**
     * @param interactable Defines if the component is interactable or not
     * @default false
     */
    set interactable(interactable: boolean);
    get interactable(): boolean;
    /**
     * Event emitter when the action link is clicked
     */
    actionLinkClicked: Subject<Event>;
    /** @ignore */
    nameVisible: boolean;
    /** @ignore */
    primaryVisible: boolean;
    /** @ignore */
    secondaryVisible: boolean;
    /** @ignore */
    actionVisible: boolean;
    /** @ignore */
    hashedColor: string;
    /** @ignore */
    imgFailedToLoad: boolean;
    private _networkIcon;
    private _disabled;
    private _interactable;
    private _forHashing;
    private readonly nameVisibility;
    private readonly primaryMetaVisibility;
    private readonly secondaryMetaVisibility;
    private readonly actionVisibility;
    constructor(iconReg: SieIconRegistryService, colorHashService: UiColorHashService);
    /** @ignore */
    ngOnChanges(changes: SimpleChanges): void;
    /** @ignore */
    hasAction(): boolean;
    /** @ignore */
    onClickActionLink(event: Event): void;
    /** @ignore */
    loadInitials(isImageLoaded: boolean): void;
    private setVisibility;
    private setColorHashingOption;
    private getValueToHash;
    static ɵfac: i0.ɵɵFactoryDeclaration<UiAccountIdentifierComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<UiAccountIdentifierComponent, "sie-ui-account-identifier", never, { "size": { "alias": "size"; "required": false; }; "mode": { "alias": "mode"; "required": false; }; "variant": { "alias": "variant"; "required": false; }; "status": { "alias": "status"; "required": false; }; "name": { "alias": "name"; "required": false; }; "initials": { "alias": "initials"; "required": false; }; "primaryMetaData": { "alias": "primaryMetaData"; "required": false; }; "secondaryMetaData": { "alias": "secondaryMetaData"; "required": false; }; "linkText": { "alias": "linkText"; "required": false; }; "greetings": { "alias": "greetings"; "required": false; }; "searchHighlight": { "alias": "searchHighlight"; "required": false; }; "avatarImage": { "alias": "avatarImage"; "required": false; }; "badgeData": { "alias": "badgeData"; "required": false; }; "networkIcon": { "alias": "networkIcon"; "required": false; }; "forHashing": { "alias": "forHashing"; "required": false; }; "disabled": { "alias": "disabled"; "required": false; }; "interactable": { "alias": "interactable"; "required": false; }; }, { "actionLinkClicked": "actionLinkClicked"; }, never, ["[customNameAppendix]"], false, never>;
}
//# sourceMappingURL=ui-account-identifier.component.d.ts.map