import { UiButtonClickModel, UiButtonModel } from '../ui-button';
import { UiButtonGroupComponent } from '../ui-button-group';
import { LayoutService, ThemeVariant } from '@siemens/core';
import { ChangeDetectorRef, ElementRef, EventEmitter, OnChanges, SimpleChanges } from '@angular/core';
import { SieIconRegistryService } from '@siemens/icons';
import { ActionsModel, UiActionBarMode } from './ui-action-bar.model';
import * as i0 from "@angular/core";
/**
 * # Action Bar Component
 *
 * Action Bar facilitates on-demand, clear and transparent access to section- or page-specific actions.
 *
 * ## Component variations
 *
 * - page mode
 * - bulk action mode
 *
 * ## Content
 *
 * The Action Bar component does not accept any content.
 *
 * ## Code example
 * @example ```html
 * <sie-ui-action-bar
 *  mode="page"
 *  [buttons]="buttons"
 *  theme="light"
 *  (stickyModeChange)="onActionBarStickyModeChange($event)"
 *  [toggleStickyMode]="true"
 * ></sie-ui-action-bar>
 * ```
 *
 * ```ts
 * const buttons = [
 *   {
 *     id: 'Apply',
 *     buttonType: 'button',
 *     variant: 'secondary',
 *     background: 'dark',
 *     label: 'Apply'
 *   },
 *   {
 *     id: 'Cancel',
 *     buttonType: 'button',
 *     variant: 'tertiary',
 *     background: 'dark',
 *     label: 'Cancel'
 *   }
 * ];
 * ```
 */
export declare class UiActionBarComponent implements OnChanges {
    readonly iconReg: SieIconRegistryService;
    private readonly layoutService;
    private readonly host;
    private readonly cdr;
    /** @ignore */
    buttonGroupComponent: UiButtonGroupComponent;
    /**
     * Defines {@link UiActionBarMode mode} of action bar
     * @default 'bulkAction'
     */
    mode: UiActionBarMode;
    /**
     * Defines the text on the dropdown before the action is selected
     * @default null
     */
    dropdownPlaceholder: string;
    /**
     * Defines the screen reader text for the action bar
     */
    dropdownScreenReaderText?: string;
    /**
     * Defines the label on the left side of the action bar (e.g. to display the number of selected items)
     */
    actionsLabel: any;
    /**
     * Defines {@link UiButtonModel buttons} which are added to the action bar
     */
    buttons: UiButtonModel[];
    /**
     * Defines if sticky mode of the action bar should be toggled
     * @default true
     */
    toggleStickyMode: boolean;
    /**
     * @param value {@link ThemeVariant Theme} of action bar
     * @default 'dark'
     */
    set theme(value: ThemeVariant);
    get theme(): ThemeVariant;
    /**
     * @param value defines if the component use the full width when the viewport is L (Large)
     * @default false
     */
    set isFullWidthOnViewportL(value: boolean);
    get isFullWidthOnViewportL(): boolean;
    /**
     * @param selectedItemsLength defines the count of selected items
     */
    set selectedItemsLength(selectedItemsLength: number);
    infoButtonLabel: string;
    infoButtonTooltipLabel: string;
    /**
     * @param actions defines array of {@link ActionsModel actions} which will be applied
     */
    set dropdownOptions(actions: ActionsModel[]);
    get dropdownOptions(): ActionsModel[];
    /**
     * @param value defines whether the action bar is in sticky mode or not
     * @default true
     */
    set stickyMode(value: boolean);
    get stickyMode(): boolean;
    /**
     * @param value flag so that the z-index is increased and the dropdown overlay is above other elements
     * @default false
     */
    set dropdownOverlayOnTop(value: boolean);
    get dropdownOverlayOnTop(): boolean;
    /**
     * Triggered when button is clicked
     * * bulk mode: value of the selected action
     * * page mode: id of the clicked button (save or cancel)
     */
    appliedAction: EventEmitter<string>;
    /**
     * Triggered when the action bar becomes or stops being sticky (when scrolling)
     */
    stickyModeChange: EventEmitter<boolean>;
    /**
     * Triggered when save button is clicked (page mode)
     */
    save: EventEmitter<void>;
    /**
     * Triggered when cancel button is clicked (page mode)
     */
    cancel: EventEmitter<void>;
    /**
     * Triggered when infoButtonLabel button is clicked (page mode)
     */
    infoButtonClicked: EventEmitter<string>;
    /**
     * Triggered on dropdown changed event
     */
    dropdownChanged: EventEmitter<ActionsModel>;
    /** @ignore */
    selectedAction: ActionsModel;
    /** @ignore */
    showRequirementsLabel: boolean;
    private _theme;
    private _dropdownOptions;
    private _stickyMode;
    private _isFullWidthOnViewportL;
    private _selectedItemsLength;
    /** @ignore */
    private _dropdownOverlayOnTop;
    constructor(iconReg: SieIconRegistryService, layoutService: LayoutService, host: ElementRef<HTMLElement>, cdr: ChangeDetectorRef);
    /** @ignore */
    ngOnChanges(changes: SimpleChanges): void;
    /** @ignore */
    intersected(inView: boolean): void;
    /** @ignore */
    onSelectionChange(actionValue: string): void;
    /** @ignore */
    emitAction(event: UiButtonClickModel): void;
    onInfoButtonClick(): void;
    private outOfSelectedActionRange;
    private isActionValid;
    private setRestrictionState;
    private setApprovedState;
    private findDropdownActionByValue;
    static ɵfac: i0.ɵɵFactoryDeclaration<UiActionBarComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<UiActionBarComponent, "sie-ui-action-bar", never, { "mode": { "alias": "mode"; "required": false; }; "dropdownPlaceholder": { "alias": "dropdownPlaceholder"; "required": false; }; "dropdownScreenReaderText": { "alias": "dropdownScreenReaderText"; "required": false; }; "actionsLabel": { "alias": "actionsLabel"; "required": false; }; "buttons": { "alias": "buttons"; "required": false; }; "toggleStickyMode": { "alias": "toggleStickyMode"; "required": false; }; "theme": { "alias": "theme"; "required": false; }; "isFullWidthOnViewportL": { "alias": "isFullWidthOnViewportL"; "required": false; }; "selectedItemsLength": { "alias": "selectedItemsLength"; "required": false; }; "infoButtonLabel": { "alias": "infoButtonLabel"; "required": false; }; "infoButtonTooltipLabel": { "alias": "infoButtonTooltipLabel"; "required": false; }; "dropdownOptions": { "alias": "dropdownOptions"; "required": false; }; "stickyMode": { "alias": "stickyMode"; "required": false; }; "dropdownOverlayOnTop": { "alias": "dropdownOverlayOnTop"; "required": false; }; "_dropdownOverlayOnTop": { "alias": "_dropdownOverlayOnTop"; "required": false; }; }, { "appliedAction": "appliedAction"; "stickyModeChange": "stickyModeChange"; "save": "save"; "cancel": "cancel"; "infoButtonClicked": "infoButtonClicked"; "dropdownChanged": "dropdownChanged"; }, never, never, false, never>;
}
//# sourceMappingURL=ui-action-bar.component.d.ts.map