import { ChangeDetectorRef, ElementRef, QueryList } from '@angular/core';
import { UiBreadcrumbModel } from './ui-breadcrumb.model';
import { Subject } from 'rxjs';
import { SieIconRegistryService } from '@siemens/icons';
import { LayoutService } from '@siemens/core';
import * as i0 from "@angular/core";
/**
 * Defines breadcrumb variants
 */
export type UiBreadcrumbVariants = 'onlyOneLevel' | 'allWithRoot' | 'allWithoutRoot';
/**
 * # Breadcrumb Component
 *
 * Breadcrumb allows user to gain orientation about on which page they are currently and the path of the page. It also
 * allows them to navigate to a specific page mentioned in the breadcrumb trail. Breadcrumb should be used in the main
 * menu as well as on the actual pages.
 *
 * ## Content
 *
 * The breadcrumb component does not accept any content.
 *
 * ## Component variations
 * - Only one breadcrumb is available
 * - All breadcrumbs available (incl. root element)
 * - All breadcrumbs available (excl. root element)
 *
 * ## Code example
 * @example ```html
 * <sie-ui-breadcrumb
 *   [pageBreadcrumbs]="true"
 *   [breadcrumbs]="breadcrumbs"
 *   [variant]="'onlyOneLevel'"
 *   (clicked)="onBreadcrumbClicked($event)"
 *   [screenReaderHomeButton]="'Home'"
 * ></sie-ui-breadcrumb>
 * ```
 *
 * Breadcrumb data example:
 * ```js
 * const breadcrumbs = [
 *   {
 *     parentId: 'noParent',
 *     id: 'root',
 *     title: '',
 *     hasChildren: true
 *   },
 *   {
 *     parentId: 'root',
 *     id: 'services',
 *     title: 'Services',
 *     hasChildren: true
 *   },
 *   {
 *     parentId: 'services',
 *     id: '2300',
 *     title: 'Service Partner Management',
 *     hasChildren: true
 *   },
 *   {
 *     parentId: '2300',
 *     id: '5460',
 *     title: 'Approved Partner Industry Service Program',
 *     hasChildren: false,
 *     href: 'https://www.siemens.com'
 *   }
 * ];
 * ```
 */
export declare class UiBreadcrumbComponent {
    readonly iconReg: SieIconRegistryService;
    private readonly cd;
    private readonly layoutService;
    /** @ignore */
    breadCrumbItems: QueryList<ElementRef>;
    /** @ignore */
    olElement: ElementRef;
    /**
     * Defines text used by screen readers for breadcrumbs title.
     * @default ''
     */
    screenReaderMenuTitle: string;
    /**
     * Defines text used by screen readers for breadcrumbs back button.
     * @default ''
     */
    screenReaderBackButton: string;
    /**
     * Defines text used by screen readers for breadcrumbs home button.
     * @default ''
     */
    screenReaderHomeButton: string;
    /**
     * @param value Defines whether on-page component version should be used.
     * @default false
     */
    set pageBreadcrumbs(value: boolean);
    get pageBreadcrumbs(): boolean;
    /**
     * @param breadcrumbs Defines {@link UiBreadcrumbModel content} of the breadcrumbs component.
     * @default []
     */
    set breadcrumbs(breadcrumbs: Array<UiBreadcrumbModel>);
    /**
     * @param variant Defines which {@link UiBreadcrumbVariants variant} should be used
     * @default "onlyOneLevel"
     */
    set variant(variant: UiBreadcrumbVariants);
    /**
     * {@link UiBreadcrumbModel Event} triggered when the breadcrumb element is clicked.
     */
    clicked: Subject<UiBreadcrumbModel>;
    /** @ignore */
    readonly truncationPlaceholderId = "TRUNCATION_PLACEHOLDER";
    /** @ignore */
    readonly truncationPlaceholderWidth = 46;
    /** @ignore */
    rootItem: UiBreadcrumbModel;
    /** @ignore */
    activeItem: UiBreadcrumbModel;
    /** @ignore */
    levels: Array<UiBreadcrumbModel>;
    /** @ignore */
    breadcrumbWidthOnViewportS: number;
    /** @ignore */
    _variant: UiBreadcrumbVariants;
    private _pageBreadcrumbs;
    private _breadcrumbs;
    constructor(iconReg: SieIconRegistryService, cd: ChangeDetectorRef, layoutService: LayoutService);
    /** @ignore internal use only */
    rerender(): void;
    /** @ignore */
    onClick(clickedItem: UiBreadcrumbModel, event?: Event): void;
    private checkWidthOfBreadCrumbs;
    private removeItemsTillItFits;
    private setRootItem;
    private setActiveItem;
    private populateLevels;
    static ɵfac: i0.ɵɵFactoryDeclaration<UiBreadcrumbComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<UiBreadcrumbComponent, "sie-ui-breadcrumb", never, { "screenReaderMenuTitle": { "alias": "screenReaderMenuTitle"; "required": false; }; "screenReaderBackButton": { "alias": "screenReaderBackButton"; "required": false; }; "screenReaderHomeButton": { "alias": "screenReaderHomeButton"; "required": false; }; "pageBreadcrumbs": { "alias": "pageBreadcrumbs"; "required": false; }; "breadcrumbs": { "alias": "breadcrumbs"; "required": false; }; "variant": { "alias": "variant"; "required": false; }; }, { "clicked": "clicked"; }, never, never, false, never>;
}
//# sourceMappingURL=ui-breadcrumb.component.d.ts.map