import { EventEmitter, OnChanges, OnInit, SimpleChanges } from '@angular/core';
import { LocaleString, ThemeVariant } from '@siemens/core';
import { SieIcon, SieIconRegistryService } from '@siemens/icons';
import { UiCardLandscapeModel } from './ui-card-landscape.model';
import { UiMenuButtonModel } from '../../ui-menu-button/ui-menu-button.model';
import { UiChildActionEventModel } from '../../shared/models/child-action-event.model';
import { UiBasicNavigationTarget, UiLinkClickedEventModel } from '../../shared/models/ui-navigation-model';
import * as i0 from "@angular/core";
/**
 * # Card Landscape Component
 *
 * Cards are used to take a sneak peek at some type of content(e.g. product information).
 * Usually, it holds marketing or promotional material. There are two types of cards: Portrait and Landscape.
 *
 * ## Component variations
 *
 * Card Landscape is horizontally oriented and has certain content exclusive to it
 * (rating stars, secondary meta) with the option to show/hide the media.
 *
 * ## Content
 *
 * The card landscape component does not accept any content.
 *
 * ## Code example
 * @example
 * Template:
 * ```html
 * <sie-ui-card-landscape
 *   [titleLines]="3"
 *   [showMedia]="true"
 *   [item]="cardLandscapeItem"
 *   [locale]="'en'"
 *   >
 * <sie-ui-card-landscape>
 * ```
 *
 * Card Landscape item example:
 * ``` js
 * const cardLandscapeItem = {
 *  title: 'Card Landscape Title',
 *  tagLabel: 'Manual',
 *  type: 'Manual',
 *  documentDate: '2021-01-22T00:11:52.907',
 *  linkToItem:
 *   'https://supportstage.industry.siemens.com/cs/document/109786741/tc_111062_cluster_iat_automated_importer_test_2310_1.01.22.2021?dti=0&lc=en-WW',
 *  linkToAllItems: 'https://supportstage.industry.siemens.com/cs/products?dtp=Manual&mfn=ps&lc=en-WW',
 *  version: '02/2017',
 *  rating: 3,
 *  tooltipLabel: 'Rating cannot be displayed at the moment',
 *  childActions: [
 *     {
 *       value: '...',
 *       label: 'Edit'
 *     }
 *   ]
 * };
 * ```
 */
export declare class UiCardLandscapeComponent implements OnInit, OnChanges {
    readonly iconReg: SieIconRegistryService;
    /**
     * The main source of {@link UiCardLandscapeModel card data}.
     */
    item: UiCardLandscapeModel;
    /**
     * The index of the page where the card is currently placed inside of the carousel.
     */
    slideIndex: number;
    /**
     * The target of the link when the card is clicked.
     * @default '_self'
     */
    target?: UiBasicNavigationTarget;
    /**
     * {@link ThemeVariant Theme} of the card.
     * @default 'light'
     */
    theme: ThemeVariant;
    /**
     * Locale being used for formatting purposes
     */
    locale: LocaleString;
    /**
     * @param value Height of the card.
     */
    set height(value: number);
    get height(): number;
    /**
     * @param value Number of lines of title to display, more than 3 isn't realistic use case.
     * @default 3
     */
    set titleLines(value: number);
    get titleLines(): number;
    /**
     * @param value Defines should the media be shown.
     */
    set showMedia(value: boolean);
    get showMedia(): boolean;
    /**
     * Defines if container-queries or media-queries are used for the card styling
     * @default false
     */
    containerStyled: boolean;
    /**
     * {@link UiChildActionEventModel Event} triggered when the action in the dropdown is clicked or selected via keyboard
     * (options button on the card).
     */
    cardChildActionClicked: EventEmitter<UiChildActionEventModel>;
    /**
     * {@link UiLinkClickedEventModel Event} triggered when a link is clicked on the component
     */
    linkClicked: EventEmitter<UiLinkClickedEventModel>;
    /**
     * {@link UiCardLandscapeModel Event} triggered when card is clicked
     */
    cardClicked: EventEmitter<UiCardLandscapeModel>;
    /** @ignore */
    readonly cardBaseHeight = 92;
    /** @ignore */
    readonly titleLineHeight = 26;
    /** @ignore */
    readonly titleBaseMarginBottom = 18;
    /** @ignore */
    readonly titleSpacingCoefficient = 6;
    /** @ignore */
    cardHeight: string;
    /** @ignore */
    titleStyle: {
        '-webkit-line-clamp': number;
        height: string;
        'margin-bottom': string;
    };
    /** @ignore */
    iconName: SieIcon;
    private _height;
    private _titleLines;
    private _showMedia;
    constructor(iconReg: SieIconRegistryService);
    /** @ignore */
    ngOnInit(): void;
    /** @ignore */
    onNavigateLink(href: string): void;
    /** @ignore */
    onCardClicked(item: UiCardLandscapeModel): void;
    /** @ignore */
    ngOnChanges(_: SimpleChanges): void;
    /** @ignore */
    onChildActionClicked(button: UiMenuButtonModel, item: UiCardLandscapeModel): void;
    private calculateDimensions;
    private calculateCardHeight;
    private calculateTitleHeight;
    private calculateTitleMarginBottom;
    /** @ignore */
    onAllItemsLinkClick(event: Event): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<UiCardLandscapeComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<UiCardLandscapeComponent, "sie-ui-card-landscape", never, { "item": { "alias": "item"; "required": false; }; "slideIndex": { "alias": "slideIndex"; "required": false; }; "target": { "alias": "target"; "required": false; }; "theme": { "alias": "theme"; "required": false; }; "locale": { "alias": "locale"; "required": false; }; "height": { "alias": "height"; "required": false; }; "titleLines": { "alias": "titleLines"; "required": false; }; "showMedia": { "alias": "showMedia"; "required": false; }; "containerStyled": { "alias": "containerStyled"; "required": false; }; }, { "cardChildActionClicked": "cardChildActionClicked"; "linkClicked": "linkClicked"; "cardClicked": "cardClicked"; }, never, never, false, never>;
    static ngAcceptInputType_containerStyled: unknown;
}
//# sourceMappingURL=ui-card-landscape.component.d.ts.map