import { EventEmitter } from '@angular/core';
import { SieIconRegistryService } from '@siemens/icons';
import { ClassFlags } from '@siemens/core';
import { UiCardPortraitModel } from './ui-card-portrait.model';
import { Subject } from 'rxjs';
import { UiButtonClickModel } from '../../ui-button/base/ui-button.model';
import { UiMenuButtonModel } from '../../ui-menu-button/ui-menu-button.model';
import { UiChildActionEventModel } from '../../shared/models/child-action-event.model';
import * as i0 from "@angular/core";
/**
 * # Card Portrait Component
 *
 * Cards are used to take a sneak peek at some type of content(e.g. product information).
 * Usually, it holds marketing or promotional material. There are two types of cards: Portrait and Landscape.
 *
 * ## Component variations
 *
 * Card Portrait is vertically oriented. It has an image describing the topic of the content.
 * Holds additional descriptive copy or a list of benefits, and has the button that triggers some kind of action
 * (e.g. plays a video).
 *
 * ## Content
 *
 * The card portrait component does not accept any content.
 *
 * ## Code example
 * @example
 * Template:
 * ```html
 * <sie-ui-card-portrait [item]="cardPortraitItem"><sie-ui-card-portrait>
 * ````
 *
 * Card Portrait item example:
 * ``` js
 * const cardPortraitItem = {
 *  picture: {
 *   mode: 'cover',
 *   urlLarge:
 *     'https://assets.new.siemens.com/siemens/assets/api/uuid:7a2780b6-d058-4e8d-9acc-eb3daa974c00/width:1920/quality:HIGH/Siemens-WinCC-Unified-Software-Visual.jpg',
 *   urlMedium:
 *     'https://assets.new.siemens.com/siemens/assets/api/uuid:7a2780b6-d058-4e8d-9acc-eb3daa974c00/width:1280/quality:MEDIUM/Siemens-WinCC-Unified-Software-Visual.jpg',
 *   urlSmall:
 *     'https://assets.new.siemens.com/siemens/assets/api/uuid:7a2780b6-d058-4e8d-9acc-eb3daa974c00/width:640/quality:LOW/Siemens-WinCC-Unified-Software-Visual.jpg',
 *   altText: 'Image Description'
 *  },
 *  benefits: [
 *   'Latest technology with proven engineering',
 *   'Simple and unlimited scalability',
 *   'Runs any time, in different environments'
 *  ],
 *  itemType: 'certificate',
 *  button: {
 *   id: '',
 *   label: 'Buy now',
 *   link: 'https://mall.industry.siemens.com/mall/de/de/Catalog/Products/10364582',
 *   variant: 'secondary',
 *   background: 'light',
 *   icon: 'ShoppingCart',
 *   iconPosition: 'leading',
 *   buttonType: 'link',
 *   target: '_self'
 *  },
 *  showPrice: false,
 *  title: 'Card with image mode "Covered"',
 *  visualTag: '',
 *  description: '',
 *  childActions: [
 *     {
 *      value: '...',
 *       label: 'Edit'
 *     }
 *   ]
 *  };
 *```
 */
export declare class UiCardPortraitComponent {
    readonly iconReg: SieIconRegistryService;
    /**
     * Main source of {@link UiCardPortraitModel card data}.
     */
    item: UiCardPortraitModel;
    /**
     * Defines the text that the screen reader will read for the options button.
     */
    menuButtonScreenReaderText: string;
    /**
     * Defines if container-queries or media-queries are used for the card styling
     * @default false
     */
    containerStyled: boolean;
    /**
     * {@link UiButtonClickModel Event} triggered when the button is clicked.
     */
    buttonClick: Subject<UiButtonClickModel>;
    /**
     * {@link UiChildActionEventModel Event} triggered when the action in the dropdown is clicked or selected via keyboard
     * (options button on the card).
     */
    cardChildActionClicked: EventEmitter<UiChildActionEventModel>;
    /**
     * {@link UiCardPortraitModel Event} triggered when card is clicked
     */
    cardClicked: EventEmitter<UiCardPortraitModel>;
    /** @ignore */
    imageUrl: string;
    /** @ignore */
    primaryMetaPlaceholder: string;
    constructor(iconReg: SieIconRegistryService);
    /** @ignore */
    onButtonClick(event: Event): void;
    /** @ignore */
    navigateLink(href: string): void;
    /** @ignore */
    onCardClicked(item: UiCardPortraitModel, event?: Event): void;
    /** @ignore */
    dropdownOptionSelected(button: UiMenuButtonModel, item: UiCardPortraitModel): void;
    /** @ignore */
    getLongHeadlineClass(item: UiCardPortraitModel): ClassFlags;
    static ɵfac: i0.ɵɵFactoryDeclaration<UiCardPortraitComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<UiCardPortraitComponent, "sie-ui-card-portrait", never, { "item": { "alias": "item"; "required": false; }; "menuButtonScreenReaderText": { "alias": "menuButtonScreenReaderText"; "required": false; }; "containerStyled": { "alias": "containerStyled"; "required": false; }; }, { "buttonClick": "buttonClick"; "cardChildActionClicked": "cardChildActionClicked"; "cardClicked": "cardClicked"; }, never, never, false, never>;
    static ngAcceptInputType_containerStyled: unknown;
}
//# sourceMappingURL=ui-card-portrait.component.d.ts.map