import { AnimationBuilder } from '@angular/animations';
import { AfterViewInit, ChangeDetectorRef, ElementRef, OnDestroy, QueryList } from '@angular/core';
import { UiCarouselSlideDirective } from './ui-carousel-slide.directive';
import { BreakpointKey, Direction, ElementResizeDirective, LayoutService, PanEvent, ThemeVariant } from '@siemens/core';
import { SieIconRegistryService } from '@siemens/icons';
import { PaginationEventModel } from './pagination/pagination-event.model';
import { UiCarouselService } from './ui-carousel.service';
import { SlideGroup, UiCarouselItem, UiCarouselScreenReader, UiCarouselType } from './ui-carousel.types';
import { Observable } from 'rxjs';
import { UiCarouselComponentService } from './ui-carousel.component.service';
import * as i0 from "@angular/core";
import * as i1 from "@siemens/core";
/**
 * # Carousel component
 *
 * Provide access to an overflowing number of items of a kind in a paginated area.
 *
 * ## Component variations
 *
 * - Regular carousel
 * - Cut off version
 *
 * ## Content
 *
 * Next to the parameters, the content can be passed as child elements with using `UiCarouselSlideDirective`.
 * See the example below.
 *
 * ## Code example
 * @example
 * Template:
 * ```html
 *  <sie-ui-carousel [type]="'thermometer'" [theme]="'dark'" [cutOff]="false">
 *    <ng-container *ngFor="let slide of carouselSlides">
 *       <ng-template sieUiCarouselSlide>
 *         <sie-ui-teaser [teaserData]="slide"></sie-ui-teaser>
 *       </ng-template>
 *     </ng-container>
 *  </sie-ui-carousel>
 * ```
 *
 * Carousel items data example:
 * ```js
 * carouselSlides = [
 *  {
 *   id: 1,
 *   visualizationType: 'stage-full-width-teaser',
 *   title: '1111Headline Lorem ipsum Headline Lorem ipsum 12345678',
 *   subTitle: 'Subheadline consetetur sadipscing elitr, sed diam nonumy eirmod tempor aliquayam',
 *   buttons: [
 *    {
 *      id: 'cta1',
 *      label: 'Details',
 *      link: 'https://www.siemens.com',
 *      buttonType: 'link',
 *      variant: 'primary',
 *      background: 'dark'
 *    }
 *  ],
 *   picture: {
 *    urlSmall: 'https://picsum.photos/id/33/500/500',
 *    urlMedium: 'https://picsum.photos/id/33/1000/500',
 *    urlLarge: 'https://picsum.photos/id/33/2000/500'
 *    }
 *  }
 * ];
 * ```
 */
export declare class UiCarouselComponent implements AfterViewInit, OnDestroy {
    layoutService: LayoutService;
    carouselService: UiCarouselService;
    readonly iconReg: SieIconRegistryService;
    private readonly animationBuilder;
    elementRef: ElementRef;
    private readonly cd;
    private readonly resizeDirective;
    private readonly uiCarouselComponentService;
    /** @ignore */
    carouselUl: ElementRef;
    /** @ignore */
    carouselButtons: QueryList<ElementRef>;
    /** @ignore */
    elementsRef: ElementRef;
    /** @ignore */
    slides: QueryList<UiCarouselSlideDirective> | UiCarouselItem[];
    /**
     * The {@link Direction direction} of the carousel (only available in combination with autoplay feature).
     * @default 'ltr'
     */
    dir: Direction;
    /**
     * The {@link ThemeVariant theme} that is used for the component.
     * @default 'light'
     */
    theme: ThemeVariant;
    /**
     * The {@link UiCarouselType Type of carousel} that is used to determine pagination.
     * @default 'dots'
     */
    type: UiCarouselType;
    /**
     * @param value Defines screen reader texts.
     */
    screenReader: UiCarouselScreenReader;
    /**
     * Defines if container-queries or media-queries are used for the carousel styling
     * @default false
     */
    containerStyled: boolean;
    /**
     * Defines whether this carousel will be rendered in the cut-off version.
     * NOTE: if cutOff is enabled containerStyled doesn't work
     * @default false
     */
    cutOff: boolean;
    /**
     * Defines whether this carousel will pause autoplay feature.
     * @default false
     */
    pauseAutoplay: boolean;
    /**
     * @param value Set the number of the current displayed slide in component.
     * @default 0
     */
    set currentSlide(value: number);
    get currentSlide(): number;
    /** @ignore */
    get duplicateSlidesCount(): number;
    viewportContainer$: Observable<BreakpointKey>;
    private readonly _duplicateSlidesCount;
    private slideCount;
    private _currentSlide;
    private panStartPosition;
    private panStartCurrentSlide;
    private player;
    private readonly subscriptions;
    /** @ignore */
    autoPlay: boolean;
    /** @ignore */
    SlideGroup: typeof SlideGroup;
    /** @ignore */
    slideIds: string[];
    /** @ignore */
    currentGroup: number;
    /** @ignore */
    currentRealSlideIndex: number;
    /** @ignore */
    inlineTranslate: string;
    /** @ignore */
    isSliding: boolean;
    /** @ignore */
    invalidPanStartEventTriggered: boolean;
    /** @ignore */
    isPanning: boolean;
    /** @ignore */
    cutOffHovered: 'previous' | 'next';
    /** @ignore */
    realCutOff: boolean;
    /** @ignore */
    slideWidth: number;
    /** @ignore */
    cutOffSpacing: number;
    /** @ignore */
    smallViewport$: Observable<boolean>;
    constructor(layoutService: LayoutService, carouselService: UiCarouselService, iconReg: SieIconRegistryService, animationBuilder: AnimationBuilder, elementRef: ElementRef, cd: ChangeDetectorRef, resizeDirective: ElementResizeDirective, uiCarouselComponentService: UiCarouselComponentService<UiCarouselSlideDirective | UiCarouselItem, UiCarouselComponent>);
    /** @ignore */
    ngAfterViewInit(): void;
    /** @ignore */
    ngOnDestroy(): void;
    /** @ignore */
    getSlidesForGroup(groupIndex: number): (UiCarouselSlideDirective | UiCarouselItem)[];
    /** @ignore */
    goToSlide(event: PaginationEventModel): void;
    /**
     * This method is exposed to web components and not suggested to be used inside of the SiePortal
     * @param index Navigates to slide at index.
     */
    goToSlideAt(index: number): void;
    /**
     * Navigates to previous slide.
     */
    goToPrevious(): void;
    /**
     * Navigates to next slide.
     */
    goToNext(): void;
    /** @ignore */
    updateSlidingState(isSliding: boolean): void;
    /** @ignore */
    onPanStart(event: PanEvent): void;
    /** @ignore */
    onPan(event: PanEvent): void;
    /** @ignore */
    onPanEnd(event: PanEvent): void;
    private forcePanEnd;
    /** @ignore */
    slideVisibility(group: SlideGroup, index: number): string;
    /** @ignore */
    isPreviousSlide(group: SlideGroup, index: number): boolean;
    /** @ignore */
    isNextSlide(group: SlideGroup, index: number): boolean;
    /** @ignore */
    toggleCutOffSlideStyle(direction?: 'previous' | 'next'): void;
    /** @ignore */
    checkIfRealCutOff(): void;
    /**
     * Toggles the carousel autoplay pause.
     */
    toggleCarouselPause(): void;
    getScreenReaderText(index: number, count: number): string;
    private destroyPlayer;
    private playAnimation;
    /** @ignore */
    resetCarousel(): void;
    private jumpToInnerSlide;
    private updateSlideForCutoffVersion;
    private calculateSlideWidth;
    private resizeControlsForCutoffVersion;
    private calculateCutOffSpacing;
    private getInnerSlideIndex;
    private getGroupForSlide;
    private getPreviousIndex;
    private getNextIndex;
    private setPauseAutoplay;
    private calculateTranslate;
    private handleSlideFocus;
    private listenToSizeChange;
    static ɵfac: i0.ɵɵFactoryDeclaration<UiCarouselComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<UiCarouselComponent, "sie-ui-carousel", never, { "dir": { "alias": "dir"; "required": false; }; "theme": { "alias": "theme"; "required": false; }; "type": { "alias": "type"; "required": false; }; "screenReader": { "alias": "screenReader"; "required": false; }; "containerStyled": { "alias": "containerStyled"; "required": false; }; "cutOff": { "alias": "cutOff"; "required": false; }; "pauseAutoplay": { "alias": "pauseAutoplay"; "required": false; }; }, {}, ["slides"], [".item"], false, [{ directive: typeof i1.ElementResizeDirective; inputs: {}; outputs: {}; }]>;
    static ngAcceptInputType_containerStyled: unknown;
    static ngAcceptInputType_cutOff: unknown;
    static ngAcceptInputType_pauseAutoplay: unknown;
}
/** @ignore */
export declare class UiCarouselWebComponent extends UiCarouselComponent {
    readonly iconReg: SieIconRegistryService;
    constructor(layoutService: LayoutService, carouselService: UiCarouselService, iconReg: SieIconRegistryService, animationBuilder: AnimationBuilder, elementRef: ElementRef, cd: ChangeDetectorRef, resizeDirective: ElementResizeDirective, uiCarouselComponentService: UiCarouselComponentService<UiCarouselSlideDirective | UiCarouselItem, UiCarouselComponent>);
    static ɵfac: i0.ɵɵFactoryDeclaration<UiCarouselWebComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<UiCarouselWebComponent, "sie-ui-carousel-webcomponent-donotuseit", never, {}, {}, never, [".item"], false, [{ directive: typeof i1.ElementResizeDirective; inputs: {}; outputs: {}; }]>;
}
//# sourceMappingURL=ui-carousel.component.d.ts.map