import { UiButtonComponent } from '../ui-button/base/ui-button.component';
import { ChangeDetectorRef, ElementRef, OnDestroy, OnInit } from '@angular/core';
import { LayoutService } from '@siemens/core';
import { SieIconRegistryService } from '@siemens/icons';
import { Subject } from 'rxjs';
import { UiScrollData } from '../ui-scrollable/ui-scroll-data';
import { UiDrawerAnimationType } from './ui-drawer-animation-type.enum';
import { UiScrollableComponent } from '../ui-scrollable/ui-scrollable.component';
import { UiDrawerOptions } from './ui-drawer.model';
import * as i0 from "@angular/core";
/**
 * # Drawer component
 *
 * Provide temporary access to contents on-demand which go beyond current page content.
 *
 * ## Component variations
 *
 * There are two scrolling animations on the drawer headline:
 * - transform
 * - opacity
 *
 * ## Content
 *
 * The content of the drawer component can be any valid markup.
 *
 * ## Code example
 * @example
 * Template:
 * ```html
 * <sie-ui-drawer (opening)="contactDrawerOpening()" (closed)="contactDrawerClosed()" [headline]="'Find your contact'">
 *   <!-- Add content here that you want to keep in the drawer -->
 * </sie-ui-drawer>
 * <button (click)="openContactDrawer()">Open Contact Drawer</button>
 * ```
 *
 * Component code:
 * ```ts
 * @Component(...)
 * export class HeaderComponent {
 *   @ViewChild(UiDrawerComponent) contactDrawer: UiDrawerComponent;
 *
 *   contactDrawerOpening(): void {
 *     console.log('Drawer is about to be opened');
 *   }
 *
 *   contactDrawerClosed(): void {
 *     console.log('Contact drawer was closed');
 *   }
 *
 *   openContactDrawer(): void {
 *     this.contactDrawer.open();
 *   }
 * }
 * ```
 */
export declare class UiDrawerComponent implements OnInit, OnDestroy {
    private readonly document;
    private readonly cdr;
    private readonly layoutService;
    iconReg: SieIconRegistryService;
    private readonly elementRef;
    /**
     * Type of {@link UiDrawerAnimationType scrolling animation} for the headline
     * @default 'transform'
     */
    headlineAnimationType: UiDrawerAnimationType;
    /**
     * Headline of the drawer that is displayed on top
     */
    headline: string;
    /**
     * Event triggered when the drawer starts opening
     */
    opening: Subject<void>;
    /**
     * Event triggered when the drawer is opened
     */
    opened: Subject<void>;
    /**
     * Event when the drawer starts closing
     */
    closing: Subject<void>;
    /**
     * Event when the drawer is closed
     */
    closed: Subject<void>;
    /** @ignore */
    closeButton: UiButtonComponent;
    scrollableContent: UiScrollableComponent;
    /** @ignore */
    readonly uiDrawerAnimationType: typeof UiDrawerAnimationType;
    /** @ignore */
    contentPadding: string;
    private readonly headlineAnimationDistance;
    private readonly headlineShadowOpacityMax;
    private readonly headlineOpacityRange;
    private readonly headlineShadowOpacityRange;
    private headerShadowOpacity;
    private onCombinerResetSub;
    private escapeKeyDownSub;
    private isCloseable;
    private optionsSubscriptions;
    constructor(document: Document, cdr: ChangeDetectorRef, layoutService: LayoutService, iconReg: SieIconRegistryService, elementRef: ElementRef);
    private _isOpen;
    /**
     * Readonly property containing information if the drawer is open
     */
    get isOpen(): boolean;
    private _isAnimating;
    private readonly handlerCombiner;
    private readonly subscriptions;
    /**
     * Readonly property containing information if the drawer is currently animating
     */
    get isAnimating(): boolean;
    private _isScrolled;
    /**
     * Readonly property containing information if the drawer is "scrolled" (not scroll top)
     */
    get isScrolled(): boolean;
    private _headlineOpacity;
    /**
     * Readonly property containing information if the drawer's headline is transparent
     */
    get headlineOpacity(): number;
    private _headlineTranslate;
    /** @ignore */
    get headlineTranslate(): string;
    /** @ignore */
    get headerShadow(): string;
    /** @ignore */
    ngOnInit(): void;
    /** @ignore */
    ngOnDestroy(): void;
    /**
     * Opens the drawer
     */
    open(options?: UiDrawerOptions): void;
    /**
     * Closes the drawer
     */
    close(): void;
    /**
     * Toggles the drawer
     */
    toggle(): void;
    /** @ignore */
    onAnimationEnd(): void;
    /** @ignore */
    onScroll(scrollData: UiScrollData): void;
    private setState;
    private subscribeToCombinerReset;
    private subscribeToEscapeKeyDown;
    private emitStateChangeFinished;
    private resetToDefaults;
    private subscribeToScreenResize;
    private scrollbarExists;
    private handleOptions;
    private subscribeToOption;
    static ɵfac: i0.ɵɵFactoryDeclaration<UiDrawerComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<UiDrawerComponent, "sie-ui-drawer", never, { "headlineAnimationType": { "alias": "headlineAnimationType"; "required": false; }; "headline": { "alias": "headline"; "required": false; }; }, { "opening": "opening"; "opened": "opened"; "closing": "closing"; "closed": "closed"; }, never, ["*", "[slot=drawer-footer-content]"], false, never>;
}
//# sourceMappingURL=ui-drawer.component.d.ts.map