import { AfterViewInit, ChangeDetectorRef, ElementRef, EventEmitter } from '@angular/core';
import { AttachmentService } from '@siemens/core';
import { SieIcon, SieIconRegistryService } from '@siemens/icons';
import { UiButtonModel } from '../ui-button/base/ui-button.model';
import { UiSpinnerSize } from '../ui-spinner/ui-spinner.types';
import { UiThumbnailComponent } from '../ui-thumbnail/ui-thumbnail.component';
import { UiThumbnailType } from '../ui-thumbnail/ui-thumbnail.model';
import { UiDropZoneFile, UiDropZoneHelperLinkModel, UiDropZoneLocalizationModel, UiDropZoneModel } from './ui-drop-zone.model';
import { DropZoneVariant, UiDropZoneStatus, ThumbnailAlignment } from './ui-drop-zone.types';
import * as i0 from "@angular/core";
/**
 * # Drop Zone component
 *
 * Adds a mechanism to upload files for further processing.
 *
 * ## Component variations
 *
 * - `default`: The default drop zone is displayed
 * - `invisible`: Will hide the component but preserve functionality if an `fileDropElement` is provided
 *
 * ## Content
 *
 * The Drop Zone component does not accept any content.
 *
 * ## Code example
 *
 * @example ```html
 * <sie-ui-drop-zone [config]="dropZoneConfig" [status]="'uploading'"></sie-ui-drop-zone>
 * ```
 */
export declare class UiDropZoneComponent implements AfterViewInit {
    private readonly cdr;
    private readonly iconReg;
    private readonly attachmentService;
    /** @ignore */
    dropZone: ElementRef;
    /** @ignore */
    fileInputRef: ElementRef;
    /**
     * Defines which area should be used for uploading the files with drag and drop
     */
    fileDropElement?: HTMLElement;
    /**
     * {@link DropZoneVariant Variant} of the Drop Zone.
     */
    variant: DropZoneVariant;
    /**
     * Set alignment of thumbnails
     */
    thumbnailAlignment: ThumbnailAlignment;
    /**
     * Defines {@link UiButtonModel button} configuration
     */
    button: UiButtonModel;
    /**
     * Defines how the component will handle dropped files
     *
     * - `true` -> will emit files by replacing already existing files, does not show thumbnails
     * - `false` -> will emit files by appending to already existing files, does show thumbnails
     */
    set contextSwitch(contextSwitch: boolean);
    get contextSwitch(): boolean;
    /**
     * @param status {@link UiDropZoneStatus Status} of the Drop Zone.
     */
    set status(status: UiDropZoneStatus);
    get status(): UiDropZoneStatus;
    /**
     * @param config {@link UiDropZoneModel Configuration} of the Drop Zone.
     */
    set config(config: UiDropZoneModel);
    get config(): UiDropZoneModel;
    /**
     * @param files Update the displayed file thumbnails on the component after outside change.
     */
    set files(files: UiDropZoneFile[]);
    get files(): UiDropZoneFile[];
    /**
     * @param errorMessage Allows specifying an error message which is displayed below the component.
     */
    set errorMessage(errorMessage: string);
    get errorMessage(): string;
    /**
     * Event triggered when files are removed or uploaded, containing current {@link UiDropZoneFile list} of files.
     */
    filesChanged: EventEmitter<UiDropZoneFile[]>;
    /** @ignore */
    get localization(): UiDropZoneLocalizationModel;
    /** @ignore */
    allowedMimeTypes: string[];
    /** @ignore */
    spinnerSize: UiSpinnerSize;
    /** @ignore */
    errorLines: string[];
    /** @ignore */
    errorInfoParagraph: string;
    /** @ignore */
    maxAllowedFiles: number;
    /** @ignore */
    maxAllowedFileSize: number;
    /** @ignore */
    icon: SieIcon;
    /** @ignore */
    label: string;
    /** @ignore */
    helperText: string;
    /** @ignore */
    helperTextTitle: string;
    /** @ignore */
    helperTextAfterLink: string;
    /** @ignore */
    helperTextLink: UiDropZoneHelperLinkModel;
    /** @ignore */
    fileDropRef: string;
    /** @ignore */
    statusBeforeDragValidation: UiDropZoneStatus;
    private _contextSwitch;
    private _status;
    private _config;
    private _files;
    private _errorMessage;
    constructor(cdr: ChangeDetectorRef, iconReg: SieIconRegistryService, attachmentService: AttachmentService);
    /** @ignore */
    ngAfterViewInit(): void;
    /** @ignore */
    onFileDropped(fileList: FileList): void;
    /** @ignore */
    onFileDragOver(itemList: DataTransferItemList): void;
    /** @ignore */
    onFileDragOut(): void;
    /** @ignore */
    fileBrowseHandler(fileList: FileList): void;
    /** @ignore */
    closeActionClicked(index: number): void;
    /** @ignore */
    refreshActionClicked(file: UiDropZoneFile, thumbnailRef: UiThumbnailComponent): void;
    /** @ignore */
    prepareFilesList(fileList: FileList): void;
    /** @ignore */
    attachmentDownload(e: Event): void;
    /** @ignore */
    getType(type: string): UiThumbnailType;
    /** @ignore */
    isDisabled(): boolean;
    /** @ignore */
    openFileBrowser(): void;
    private processFilesWithContextSwitch;
    private transformErrors;
    private processFiles;
    private validateFile;
    private getNumberOfFilesRemaining;
    /**
     * @param mimetype
     * @returns true if allowedMimeTypes is undefined/empty or mimetype includes in allowedMimeTypes
     */
    private isAllowedFileType;
    private transformHelperText;
    private loadAttachment;
    static ɵfac: i0.ɵɵFactoryDeclaration<UiDropZoneComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<UiDropZoneComponent, "sie-ui-drop-zone", never, { "fileDropElement": { "alias": "fileDropElement"; "required": false; }; "variant": { "alias": "variant"; "required": false; }; "thumbnailAlignment": { "alias": "thumbnailAlignment"; "required": false; }; "button": { "alias": "button"; "required": false; }; "contextSwitch": { "alias": "contextSwitch"; "required": false; }; "status": { "alias": "status"; "required": false; }; "config": { "alias": "config"; "required": false; }; "files": { "alias": "files"; "required": false; }; "errorMessage": { "alias": "errorMessage"; "required": false; }; }, { "filesChanged": "filesChanged"; }, never, never, false, never>;
}
//# sourceMappingURL=ui-drop-zone.component.d.ts.map