import { BehaviorSubject } from 'rxjs';
import { UiThumbnailStatus } from '../ui-thumbnail/ui-thumbnail.model';
import { UiDropZoneStatus } from './ui-drop-zone.types';
export interface UiDropZoneHelperLinkModel {
    /**
     * The label displayed for the anchor element inside the helper text
     */
    label: string;
    /**
     * The relative or absolute URL for file download, be aware that CORS restrictions must be considered
     */
    url: string;
    /**
     * Name the file will be downloaded as, make sure that the file extension is appropriate
     */
    fileName: string;
    /**
     * @ignore
     */
    blob?: Blob;
    /**
     * @ignore
     */
    loading$?: BehaviorSubject<boolean>;
}
export interface UiDropZoneStatusConfigModel {
    /**
     * The icon displayed
     */
    icon?: string;
    /**
     * Allows overriding the default label below the icon
     */
    label?: string;
    /**
     * Hint displayed to give user an info about the current state
     */
    helperText?: string;
    /**
     * Defines the link attributes that will be placed inside helper text for link
     */
    helperTextLink?: UiDropZoneHelperLinkModel;
}
/**
 * Model of a single file in Drop Zone.
 */
export interface UiDropZoneFile extends File {
    hasValidationError?: boolean;
    thumbnailStatus?: UiThumbnailStatus;
    errorMessage?: string;
    appliedConstraints?: string;
}
export interface UiDropZoneLocalizationModel {
    /**
     * Labels used for fine pointer devices, e.g. desktop with mouse input
     */
    fine: {
        /**
         * The label below the icon
         */
        label: string;
        /**
         * The localization for the clickable link to browse for files with file explorer
         */
        browseLink: string;
    };
    /**
     * Labels used for coarse pointer devices, e.g. touchpads
     */
    coarse: {
        /**
         * The label below the icon
         */
        label: string;
        /**
         * The localization for the clickable button to browse for files with file explorer
         */
        browseButton?: string;
    };
}
/**
 * Model of the drop zone component
 */
export interface UiDropZoneModel {
    /**
     * Defines the basic drop-zone {@link UiDropZoneLocalizationModel localization}
     */
    localization: UiDropZoneLocalizationModel;
    /**
     * Configuration for each possible status
     */
    statusConfig: {
        [key in UiDropZoneStatus]?: UiDropZoneStatusConfigModel;
    };
    /**
     * Maximum amount of files that can be uploaded
     */
    maxAllowedFiles?: number;
    /**
     * File size limit (per file), in megabyte
     */
    maxAllowedFileSize?: number;
    /**
     * Types of files that can be uploaded, all file types will be accepted if left empty.
     */
    allowedFileExtensions?: string[];
    /**
     * Config of error messages that will be displayed below the drop zone
     */
    errorLabels: {
        /**
         * Error displayed on thumbnail level
         */
        thumbnail?: string;
        /**
         * Error labels when context switch is enabled
         */
        contextSwitch?: {
            /**
             * Error displayed for a single file validation violation
             */
            error: string;
            /**
             * Fragments necessary to display when multiple file have validation errors
             */
            multipleFiles: {
                /**
                 * General description explaining that validation errors happened
                 */
                error: string;
                /**
                 * Label after the file errors were listed to explain ways to resolve the errors
                 */
                info: string;
                /**
                 * Individual file error
                 */
                file: string;
            };
        };
        /**
         * Fragments necessary to describe various constraints violations
         */
        constraintLabels: {
            /**
             * Error fragment for file format (based on mimetype) validation violation
             */
            invalidFormat: string;
            /**
             * Error fragment for file size validation violation
             */
            fileSizeExceeded: string;
            /**
             * Used to concat error fragments
             */
            conjunction: string;
        };
        /**
         * Error displayed when the maximum number of files is exceeded
         */
        numberOfFilesExceeded: string;
        /**
         * Error displayed when the file download referenced in the helper text failed
         */
        sampleFileNotLoaded?: string;
    };
}
//# sourceMappingURL=ui-drop-zone.model.d.ts.map