import { ChangeDetectorRef, ElementRef, EventEmitter, OnDestroy, OnInit } from '@angular/core';
import { DropdownType, UiDropdownModel } from './ui-dropdown.model';
import { SieIconRegistryService } from '@siemens/icons';
import { LayoutService } from '@siemens/core';
import { UiDropdownBaseDirective } from './base/ui-dropdown.base.directive';
import { FormControl } from '../ui-form-control/ui-form.control';
import { HintModel } from '../shared/models/hint.model';
import { AbstractControl, ControlValueAccessor, ValidationErrors, Validator } from '@angular/forms';
import { UiEventPropagationService } from '../services/ui-event-propagation.service';
import { UiDropdownOptionsComponent } from '../ui-dropdown-options/ui-dropdown-options.component';
import { CdkOverlayService } from '../services/cdk-overlay.service';
import * as i0 from "@angular/core";
/**
 * # Dropdown Component
 * Dropdowns provide a list of options out of which users can pick one. It is used when a list of multiple options must
 * be provided to the user, but are not shown open persistently.
 *
 * ## Component variations
 *
 * - Contained (on light)
 * - Uncontained (on light and on dark)
 * - Disabled
 * - Readonly
 * - Invalid
 * - Required
 *
 * ## Content
 * The dropdown component does not accept any content.
 *
 * ## Code example
 *
 * @example ```html
 *
 * <sie-ui-dropdown
 *  [options]="dropdownData.data"
 *  placeholder="Please select"
 *  [theme]="dropdownData.theme"
 *  [clearInputEnabled]="true">
 * </sie-ui-dropdown>
 * ```
 *
 * ```ts
 * const dropdownData = {
 *  data: [
 *    { value: null, label: '&lt;please select&gt;', disabled: false },
 *    { value: '1', label: 'Engineering', disabled: false, icon: 'SieportalIntIdleWithBorderTag' },
 *    {
 *      value: '2',
 *      label: 'Environmental Protection, Health & Safety',
 *      disabled: false,
 *      icon: 'SieportalExtIdleWithBorderTag'
 *    },
 *    { value: '3', label: 'General Management', disabled: false },
 *    { value: '4', label: 'Information Technology', disabled: false },
 *    { value: '5', label: 'Legal & Compliance', disabled: false },
 *    { value: '6', label: 'Maintenance & Operation', disabled: false },
 *    { value: '7', label: 'Manufacturing', disabled: false },
 *    { value: '8', label: 'Product Management', disabled: false },
 *    { value: '9', label: 'SCM-Procurement', disabled: false }
 *  ],
 *  selectedValue: null,
 *  customClass: 'dropdown--big',
 *  theme: 'light'
 * };
 * ```
 */
export declare class UiDropdownComponent extends UiDropdownBaseDirective<UiDropdownModel> implements OnInit, OnDestroy, FormControl, ControlValueAccessor, Validator {
    readonly iconReg: SieIconRegistryService;
    readonly eventPropagationService: UiEventPropagationService;
    protected readonly elementRef: ElementRef;
    protected readonly cdr: ChangeDetectorRef;
    protected readonly cdkOverlayService: CdkOverlayService;
    private readonly layoutService;
    /** @ignore */
    optionsComponent: UiDropdownOptionsComponent;
    /**
     * Defines dropdown type {@link DropdownType }
     * @default 'un-contained'
     */
    type: DropdownType;
    get condensed(): boolean;
    /**
     * @param value manages a label on top of dropdown and dropdown height
     * @default false
     */
    set condensed(value: boolean);
    get options(): UiDropdownModel[];
    /**
     * @param value defines dropdown content {@link UiDropdownModel}
     */
    set options(value: UiDropdownModel[]);
    /**
     * @param selectedValue Defines which option of the component is selected by default (controlled through `value` set in `options` input)
     */
    set selectedValue(selectedValue: string);
    /**
     * @param value adds styles for required state to the placeholder when set to true
     * @default false
     */
    set required(value: boolean);
    get required(): boolean;
    /** The dropdown button ID */
    id?: string;
    /** The name of the dropdown input field  */
    name?: string;
    /** The label of the dropdown input field */
    label: string;
    /** The placeholder text of the dropdown input field */
    placeholder: string;
    /** Message displayed when dropdown state is invalid */
    errorMessage: string;
    /**
     * Used to add custom ccs classes to the dropdown
     * @default ''
     */
    customClass: string;
    /**
     * @param value adds styles for readonly state to the placeholder when set to true
     * @default false
     */
    set readonly(value: boolean);
    get readonly(): boolean;
    /**
     * @param value adds styles for invalid state when set to true
     * @default false
     */
    set invalid(value: boolean);
    get invalid(): boolean;
    /**
     * @param hint  hint displayed at the dropdown {@link HintModel}
     */
    set hint(hint: HintModel);
    get hint(): HintModel;
    /** @ignore SPA use only */
    marginBottomOnInvalidState: string;
    protected _disabled: boolean;
    protected _readonly: boolean;
    protected _invalid: boolean;
    protected _hint: HintModel;
    /**
     * Event triggered when a different option in dropdown is selected
     */
    selectionChanged: EventEmitter<string>;
    /** @ignore */
    selectedItem: UiDropdownModel;
    /** @ignore */
    leftStyle: string;
    /** @ignore */
    cdkOverlayOffsetX: number;
    /** @ignore */
    trackingDataAttr: {};
    private buffer;
    private lastKeyTime;
    private breakpointSubscription;
    private _required;
    private _condensed;
    private readonly _ngFormControlDirective;
    constructor(iconReg: SieIconRegistryService, eventPropagationService: UiEventPropagationService, elementRef: ElementRef, cdr: ChangeDetectorRef, cdkOverlayService: CdkOverlayService, layoutService: LayoutService);
    /** @ignore */
    ngOnInit(): void;
    /** @ignore */
    ngOnDestroy(): void;
    /** @ignore */
    itemSelected(selectedItem: UiDropdownModel): void;
    /** @ignore */
    keydownSearch(event: KeyboardEvent): void;
    protected determineHorizontalMenuAlignment(): void;
    private updateSelectedItem;
    private updateTracking;
    /** @ignore */
    focusOut(): void;
    /** @ignore */
    onResetButtonClicked(selector?: string): void;
    /**
     * Concrete implementation of {@link ControlValueAccessor ControlValueAccessor.registerOnChange} method allowing
     * changing `onChange` function
     * @param fn callback function
     */
    registerOnChange(fn: any): void;
    /**
     * Concrete implementation of {@link ControlValueAccessor ControlValueAccessor.registerOnTouched} method allowing
     * changing `onTouched` function
     * @param fn callback function
     */
    registerOnTouched(fn: any): void;
    /**
     * Concrete implementation of {@link ControlValueAccessor ControlValueAccessor.setDisabledState} method allowing
     * setting/removing the component's disabled state
     * @param disabled whether the component shall be enabled or disabled
     */
    setDisabledState(disabled: boolean): void;
    /**
     * Method to be implemented allowing Angular's FormModule two-way binding the control
     * @param obj value to be set
     */
    writeValue(obj: any): void;
    /**
     * Concrete implementation of {@link ControlValueAccessor ControlValueAccessor.registerOnValidatorChange} method
     * allowing changing `onValidatorChanged` function
     * @param fn callback function
     */
    registerOnValidatorChange(fn: () => void): void;
    /**
     * Concrete implementation that wraps abstract `validateInternal` method
     * @param control Concrete access to {@link AbstractControl form control object}
     * @return checkout {@link Validator}
     */
    validate(control: AbstractControl): ValidationErrors | null;
    private dispatchChangeEvent;
    static ɵfac: i0.ɵɵFactoryDeclaration<UiDropdownComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<UiDropdownComponent, "sie-ui-dropdown", never, { "type": { "alias": "type"; "required": false; }; "condensed": { "alias": "condensed"; "required": false; }; "options": { "alias": "options"; "required": false; }; "selectedValue": { "alias": "selectedValue"; "required": false; }; "required": { "alias": "required"; "required": false; }; "id": { "alias": "id"; "required": false; }; "name": { "alias": "name"; "required": false; }; "label": { "alias": "label"; "required": false; }; "placeholder": { "alias": "placeholder"; "required": false; }; "errorMessage": { "alias": "errorMessage"; "required": false; }; "customClass": { "alias": "customClass"; "required": false; }; "readonly": { "alias": "readonly"; "required": false; }; "invalid": { "alias": "invalid"; "required": false; }; "hint": { "alias": "hint"; "required": false; }; "marginBottomOnInvalidState": { "alias": "marginBottomOnInvalidState"; "required": false; }; }, { "selectionChanged": "selectionChanged"; }, never, never, false, never>;
}
//# sourceMappingURL=ui-dropdown.component.d.ts.map