import { ChangeDetectorRef } from '@angular/core';
import { BreakpointKey, ComponentBreakpointDefinition, ThemeVariant } from '@siemens/core';
import { SieIcon, SieIconRegistryService } from '@siemens/icons';
import { EmptyStateVariant, EmptyStateIconPosition } from './ui-empty-state.model';
import { Subject } from 'rxjs';
import { LinkModel } from '../ui-link/ui-link.model';
import { UiButtonModel } from '../ui-button/base/ui-button.model';
import * as i0 from "@angular/core";
/**
 * # Empty State Component
 * The empty state component is ensuring the same empty state experience wherever Empty state (Pattern) gets applied.
 * Whenever an empty state is to be shown according to the Empty state (Pattern) this component is to be used.
 * It can be used in different manifestations.
 *
 * ## Component variations
 *
 * - Regular
 * - Small (depending on the breakpoint)
 * - Light/dark theme
 *
 * ## Content
 * The empty state component does not accept any content.
 *
 * ## Code example
 *
 * @example ```html
 *
 * <sie-ui-empty-state
 *  customIcon="SieportalEmptyStateRecentlyViewed"
 *  headline="Empty State Headline"
 *  text="Empty State text lorem ipsum dolor sit"
 *  theme="light"
 *  [link]="emptyStateLink"
 * ></sie-ui-empty-state>
 * ```
 *
 * ```ts
 * const emptyStateLink = {
 *  href: 'https://www.siemens.com',
 *  variant: 'icon-link',
 *  background: 'light',
 *  linkText: 'Lorem Ipsum dolor'
 * };
 * ```
 */
export declare class UiEmptyStateComponent {
    readonly iconReg: SieIconRegistryService;
    private readonly cdr;
    /**
     * Defines {@link ThemeVariant theme} for empty state
     * @default 'light'
     */
    theme: ThemeVariant;
    /**
     * Defines headline of empty state
     */
    headline: string;
    /**
     * Defines text for empty state
     */
    text: string;
    /**
     * Defines {@link LinkModel link} for empty state
     */
    link: LinkModel;
    /**
     * Defines {@link UiButtonModel button} for empty state
     */
    button: UiButtonModel;
    /**
     * Defines {@link EmptyStateIconPosition position} for icon displayed in empty state
     * @default 'onTop'
     */
    iconPosition: EmptyStateIconPosition;
    /**
     * Defines top and bottom component padding
     */
    padding: string;
    /**
     * @param icon defines {@link SieIcon icon} which is displayed in empty state
     */
    set customIcon(icon: SieIcon);
    get customIcon(): SieIcon;
    /**
     * Triggered when button is clicked
     */
    buttonClicked: Subject<Event>;
    /** @ignore */
    variant: EmptyStateVariant;
    /** @ignore */
    readonly componentViewports: ComponentBreakpointDefinition;
    private _customIcon;
    constructor(iconReg: SieIconRegistryService, cdr: ChangeDetectorRef);
    /** @ignore */
    setBreakpoint(breakpoint: BreakpointKey): void;
    /** @ignore */
    onClick(event: Event): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<UiEmptyStateComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<UiEmptyStateComponent, "sie-ui-empty-state", never, { "theme": { "alias": "theme"; "required": false; }; "headline": { "alias": "headline"; "required": false; }; "text": { "alias": "text"; "required": false; }; "link": { "alias": "link"; "required": false; }; "button": { "alias": "button"; "required": false; }; "iconPosition": { "alias": "iconPosition"; "required": false; }; "padding": { "alias": "padding"; "required": false; }; "customIcon": { "alias": "customIcon"; "required": false; }; }, { "buttonClicked": "buttonClicked"; }, never, never, false, never>;
}
//# sourceMappingURL=ui-empty-state.component.d.ts.map