import { ChangeDetectorRef, ElementRef, EventEmitter, OnInit } from '@angular/core';
import { ThemeVariant } from '@siemens/core';
import { SieIconRegistryService } from '@siemens/icons';
import { UiExpandableHeadlineVariant } from './ui-expandable.types';
import * as i0 from "@angular/core";
/**
 * # Expandable component
 *
 * Expandable support the interaction mechanism to show and hide information on-demand.
 *
 * ## Component variations
 *
 * - Small headline
 * - Large headline
 * - Headline displayed only
 * - Body (content) displayed only
 * - Light theme
 * - Dark theme
 * - Disabled
 *
 * ## Content
 *
 * The content of the expandable component can be any valid markup.
 *
 * ## Code example
 * @example
 *  ```html
 * <sie-ui-expandable headlineCollapsed="Show More" headlineExpanded="Show Less" headlineVariant="s">
 *   <p>
 *     Lorem ipsum dolor sit amet, consetetur sadipscing elitr, sed diam nonumy eirmod tempor invidunt ut labore et
 *     dolore magna aliquyam erat, sed diam voluptua.
 *   </p>
 * </sie-ui-expandable>
 * ```
 */
export declare class UiExpandableComponent implements OnInit {
    cdr: ChangeDetectorRef;
    readonly iconReg: SieIconRegistryService;
    /** @ignore */
    body: ElementRef;
    /**
     * Defines {@link ThemeVariant the theme} of the component.
     * @default 'light'
     */
    theme: ThemeVariant;
    /**
     * Defines {@link UiExpandableHeadlineVariant the size} of the component headline.
     * @default 'm'
     */
    headlineVariant: UiExpandableHeadlineVariant;
    /**
     * @param disabled Removes functionality (click events, expanding capability) from the component and changes heading
     * color when set to true.
     * @default false
     */
    set disabled(disabled: boolean);
    get disabled(): boolean;
    /**
     * @param value Displays only the header and icon of the component when set to true.
     * @default false
     */
    set onlyHeader(value: boolean);
    get onlyHeader(): boolean;
    /**
     * @param value Displays only content of the component when set to true.
     * @default false
     */
    set onlyBody(value: boolean);
    get onlyBody(): boolean;
    /**
     * @param headlineCollapsed Defines content displayed in the heading when the component is collapsed.
     * @default ''
     */
    set headlineCollapsed(headlineCollapsed: string);
    get headlineCollapsed(): string;
    /**
     * @param headlineExpanded Defines content displayed in the heading when the component is expanded.
     * @default ''
     */
    set headlineExpanded(headlineExpanded: string);
    get headlineExpanded(): string;
    /**
     * @param expanded defines if the component is expanded.
     * @default false
     */
    set expanded(expanded: boolean);
    get expanded(): boolean;
    /**
     * @param disabled defines whether the expandable animation is disabled.
     * @default false
     */
    set animationDisabled(disabled: boolean);
    get animationDisabled(): boolean;
    /**
     * @param hasMargin defines whether the content inside the body of the component has a top margin.
     * @default true
     */
    set hasBodyMargin(hasMargin: boolean);
    get hasBodyMargin(): boolean;
    /**
     * Screen reader text which is used for icon when component can be expanded and the headline is missing.
     * @default ''
     */
    screenReaderTextExpand: string;
    /**
     * Screen reader text which is used for icon when component can be collapsed and the headline is missing.
     * @default ''
     */
    screenReaderTextCollapse: string;
    /**
     * Event triggered when component expands or collapses.
     */
    toggled: EventEmitter<boolean>;
    /**
     * Event is triggered when animation is done.
     */
    animationEnd: EventEmitter<void>;
    /** @ignore */
    headline: string;
    /** @ignore */
    expandableClosedAndAnimationFinished: boolean;
    private _disabled;
    private _onlyHeader;
    private _onlyBody;
    private _headlineCollapsed;
    private _headlineExpanded;
    private _expanded;
    private _animationDisabled;
    private _hasBodyMargin;
    constructor(cdr: ChangeDetectorRef, iconReg: SieIconRegistryService);
    /** @ignore */
    ngOnInit(): void;
    /** @ignore */
    toggle(): void;
    /** Expands the component. */
    open(): void;
    /** Collapses the component. */
    close(): void;
    /** @ignore */
    onAnimationEnd(): void;
    private changeExpand;
    private checkForExpandedTitle;
    static ɵfac: i0.ɵɵFactoryDeclaration<UiExpandableComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<UiExpandableComponent, "sie-ui-expandable", never, { "theme": { "alias": "theme"; "required": false; }; "headlineVariant": { "alias": "headlineVariant"; "required": false; }; "disabled": { "alias": "disabled"; "required": false; }; "onlyHeader": { "alias": "onlyHeader"; "required": false; }; "onlyBody": { "alias": "onlyBody"; "required": false; }; "headlineCollapsed": { "alias": "headlineCollapsed"; "required": false; }; "headlineExpanded": { "alias": "headlineExpanded"; "required": false; }; "expanded": { "alias": "expanded"; "required": false; }; "animationDisabled": { "alias": "animationDisabled"; "required": false; }; "hasBodyMargin": { "alias": "hasBodyMargin"; "required": false; }; "screenReaderTextExpand": { "alias": "screenReaderTextExpand"; "required": false; }; "screenReaderTextCollapse": { "alias": "screenReaderTextCollapse"; "required": false; }; }, { "toggled": "toggled"; "animationEnd": "animationEnd"; }, never, ["*"], false, never>;
}
//# sourceMappingURL=ui-expandable.component.d.ts.map