import { ChangeDetectorRef, ElementRef, EventEmitter, OnChanges, OnDestroy, OnInit } from '@angular/core';
import { LayoutService } from '@siemens/core';
import { SieIcon, SieIconRegistryService } from '@siemens/icons';
import { UiDropdownBaseDirective } from '../ui-dropdown/base/ui-dropdown.base.directive';
import { CdkOverlayService } from '../services/cdk-overlay.service';
import { UiEventPropagationService } from '../services/ui-event-propagation.service';
import { UiDropdownMenuModel } from '../ui-dropdown-menu/ui-dropdown-menu.model';
import { UiDropdownOptionsComponent } from '../ui-dropdown-options/ui-dropdown-options.component';
import { UiFilterTagScreenReader, UiFilterTagSelection, UiFilterTagSelectionType } from './ui-filter-tag.model';
import * as i0 from "@angular/core";
/**
 * # Filter tag component
 *
 * Filter tags signalize the state or category of an item. As a selectable tag, it is interactive for the user and enables content filtering.
 *
 * ## Component variations
 *
 * - Single select
 * - Multiple select
 *
 * ## Content
 *
 * The filter tag component does not accept any content.
 *
 * ## Code examples
 * @example ```html
 * <sie-ui-filter-tag
 *   [options]="options"
 *   selectionType="single"
 *   placeholder="select"
 *   selectedPrefix="selected"
 *   (selectionChanged)="onSelectionChanged($event)"
 *   (clearInput)="onClearInput()"
 *   (dropdownMenuOpened)="onDropdownMenuOpened($event)"
 * ></sie-ui-filter-tag>
 *
 * <sie-ui-filter-tag
 *   selectionType="boolean"
 *   placeholder="select"
 *   selectedPrefix="unselect"
 *   (selectionChanged)="onSelectionChanged($event)"
 * ></sie-ui-filter-tag>
 *
 * <sie-ui-filter-tag
 *   placeholder="event only"
 *   [screenReader]="screenReader"
 *   [openOverlayOnClick]="false"
 *   (dropdownMenuOpened)="onDropdownMenuOpened($event)"
 * ></sie-ui-filter-tag>
 * ```
 */
export declare class UiFilterTagComponent extends UiDropdownBaseDirective<UiDropdownMenuModel> implements OnInit, OnChanges, OnDestroy {
    readonly iconReg: SieIconRegistryService;
    protected readonly elementRef: ElementRef;
    protected readonly cdr: ChangeDetectorRef;
    private readonly layoutService;
    readonly eventPropagationService: UiEventPropagationService;
    protected readonly cdkOverlayService: CdkOverlayService;
    /** @ignore */
    optionsComponent: UiDropdownOptionsComponent;
    /**
     * Defines the style of the menu {@link UiFilterTagSelectionType selectionType}
     * @default 'single'
     */
    selectionType: UiFilterTagSelectionType;
    /** The placeholder text of the dropdown input field */
    placeholder: string;
    /** The prefix to be utilized when items have been selected */
    selectedPrefix: string;
    /** Labels used by screen readers */
    screenReader: UiFilterTagScreenReader;
    get options(): UiDropdownMenuModel[];
    /**
     * @param value defines dropdown content {@link UiDropdownMenuModel}. This will also reset the selection, make sure to call 'selectedValues' to restore selection
     * if selectionType = 'boolean' options should be omitted
     */
    set options(value: UiDropdownMenuModel[]);
    get selectedValues(): UiFilterTagSelection;
    /**
     * @param values Defines which options of the component are selected by default (controlled through `value` set in `options` input)
     */
    set selectedValues(values: UiFilterTagSelection);
    /**
     * @param value defines if overlay should open on click or just trigger the dropdownMenuOpened without opening
     * @default true
     */
    set openOverlayOnClick(value: boolean);
    get openOverlayOnClick(): boolean;
    /**
     * @param icon {@link SieIcon Icon} Defines optional icon before the text
     */
    set icon(icon: SieIcon);
    get icon(): SieIcon;
    /**
     * Event triggered when a different option in dropdown is selected
     * or when selectionType = 'boolean' and button is being clicked
     */
    selectionChanged: EventEmitter<UiFilterTagSelection>;
    computedLabel: string;
    selectionDisplay: string;
    selected: boolean;
    private breakpointSubscription;
    private _selectedValues;
    private _openOverlayOnClick;
    private _icon;
    constructor(iconReg: SieIconRegistryService, elementRef: ElementRef, cdr: ChangeDetectorRef, layoutService: LayoutService, eventPropagationService: UiEventPropagationService, cdkOverlayService: CdkOverlayService);
    /** @ignore */
    ngOnInit(): void;
    ngOnChanges(): void;
    /** @ignore */
    ngOnDestroy(): void;
    /** @ignore */
    protected determineHorizontalMenuAlignment(): void;
    /** @ignore */
    toggleDropDown(): void;
    /** @ignore */
    focusOut(): void;
    /** @ignore */
    resetSelection(clickEvent: Event): void;
    /** @ignore */
    itemSelected(selectedItem: UiDropdownMenuModel): void;
    private setButtonLabel;
    private updateSelection;
    private updateItemDisplay;
    static ɵfac: i0.ɵɵFactoryDeclaration<UiFilterTagComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<UiFilterTagComponent, "sie-ui-filter-tag", never, { "selectionType": { "alias": "selectionType"; "required": false; }; "placeholder": { "alias": "placeholder"; "required": false; }; "selectedPrefix": { "alias": "selectedPrefix"; "required": false; }; "screenReader": { "alias": "screenReader"; "required": false; }; "options": { "alias": "options"; "required": false; }; "selectedValues": { "alias": "selectedValues"; "required": false; }; "openOverlayOnClick": { "alias": "openOverlayOnClick"; "required": false; }; "icon": { "alias": "icon"; "required": false; }; }, { "selectionChanged": "selectionChanged"; }, never, never, false, never>;
}
//# sourceMappingURL=ui-filter-tag.component.d.ts.map