import { AfterViewInit, ChangeDetectorRef, ElementRef, EventEmitter, OnDestroy } from '@angular/core';
import { SieIconRegistryService } from '@siemens/icons';
import { UiInlineSearchSuggestion } from './ui-inline-search.types';
import { Subject } from 'rxjs';
import { LayoutService } from '@siemens/core';
import { PointerDeviceService } from '../services/pointer-device.service';
import { UiTextInputComponent } from '../ui-input/ui-text-input';
import * as i0 from "@angular/core";
/**
 * # Inline Search Component
 *
 * Search field provides search results within the same context it has been used. It allows user to find the information
 * without changing the page/context and intends to provide the results quickly.
 *
 * ## Component variations
 *
 * - Component can include suggestion list which is then filtered as the user adds input to the field.
 *
 * ## Content
 *
 * The component can contain any type of content. If content is provided, it will be displayed in the flyout instead of the suggestion list.
 *
 * ## Code example
 * @example ```html
 * <sie-ui-inline-search
 *   placeholder="Search for..."
 *   [suggestions]="[
 *     {
 *       primaryLabel: 'Apple',
 *       secondaryLabel: 'Sweet reddish fruit',
 *       suggestionData: 'anything you want you can add here'
 *     }
 *   ]"
 *   (suggestionSelected)="suggestionSelected($event)"
 *   noResultsMessage="No results"
 *   (fieldCleared)="clearSuggestion()"
 * >
 *  <placeholder-component></placeholder-component>
 * </sie-ui-inline-search>
 * ```
 */
export declare class UiInlineSearchComponent implements AfterViewInit, OnDestroy {
    readonly iconReg: SieIconRegistryService;
    readonly layoutService: LayoutService;
    private readonly cdr;
    private readonly cdrSelf;
    private readonly elementRef;
    /**
     * Defines the identification of the inline search component
     */
    id: string;
    /**
     * List of {@link UiInlineSearchSuggestion suggestion items} being rendered in this component
     */
    get suggestions(): UiInlineSearchSuggestion[];
    set suggestions(value: UiInlineSearchSuggestion[] | undefined);
    private _suggestions;
    /**
     * Placeholder for the component
     * @default empty string
     */
    placeholder: string;
    /**
     * @param value Whether to show the placeholder icon
     * @default true
     */
    set showPlaceholderIcon(value: boolean);
    get showPlaceholderIcon(): boolean;
    /**
     * Used to add custom ccs classes to the inline search
     * @default ''
     */
    customClass: string;
    /**
     * @param value Whether to show the suggestion icon
     * @default false
     */
    set showMobileSuggestionIcon(value: boolean);
    get showMobileSuggestionIcon(): boolean;
    /**
     * @param value Whether to animate the suggestions dropdown
     * @default false
     */
    set enableAnimation(value: boolean);
    get enableAnimation(): boolean;
    /**
     * @param value Whether to disable the mobile fullscreen suggestions dropdown
     * @default false
     */
    set disableMobileFullScreenOverlay(value: boolean);
    get disableMobileFullScreenOverlay(): boolean;
    /**
     * Current value of the component's text input field
     */
    value: string;
    /**
     * Defines should component be locked after selecting suggestion from the flyout
     * @default true
     */
    set lockComponent(value: boolean);
    get lockComponent(): boolean;
    /**
     * Message to be shown if the suggestions are available and entered entry gives no results
     * @default empty string
     */
    noResultsMessage: string;
    /**
     * Message to be shown if no custom content is provided
     * @default empty string
     */
    noContentMessage: string;
    /**
     * ARIA-Label to be shown for the "clear search" button
     * @default empty string
     */
    clearSearchScreenReaderText: string;
    /**
     * @param value to hide initial overlay when there is no content
     * @default false
     */
    disableFirstOverlayWhenEmpty: boolean;
    /**
     * @param value Disables the component
     * @default false
     */
    set disabled(value: boolean);
    get disabled(): boolean;
    /**
     * @param value Locks the component
     * @default false
     */
    set locked(value: boolean);
    get locked(): boolean;
    /**
     * @param value Whether to use the secondary label of suggestion as value
     * @default false (by default primary label is used)
     */
    set useSecondaryLabelAsValue(value: boolean);
    get useSecondaryLabelAsValue(): boolean;
    /**
     * @param value Boolean value with which we can force the active state on the component
     * @default false
     */
    set activated(value: boolean);
    get activated(): boolean;
    /**
     * @param value Flag to toggle between showing and hiding overlay as fixed variant to span the whole screen (only
     * relevant for viewport S)
     * @default true
     */
    set fixable(value: boolean);
    get fixable(): boolean;
    /**
     * @param value Flag to enable custom content within the flyout
     * @default false
     */
    set enableCustomContent(value: boolean);
    get enableCustomContent(): boolean;
    /**
     * @param value Defines whether the invalid state of the component should be shown
     * @default false
     */
    set invalid(value: boolean);
    get invalid(): boolean;
    /**
     * Defines the error message shown under the component when component is in invalid state
     */
    invalidErrorMessage: string;
    /**
     * Defines if inline search is displayed in condensed styling
     * @default false
     */
    condensed: boolean;
    /**
     * Defines whether the padding for the search overlay should be set to 0 if customContent is enabled
     * @default false
     */
    resetCustomContentPadding: boolean;
    /** @ignore */
    get isFixed(): boolean;
    /** @ignore */
    set focused(value: boolean);
    get focused(): boolean;
    /**
     * {@link UiInlineSearchSuggestion Event} triggered when the suggestion is selected
     */
    suggestionSelected: Subject<UiInlineSearchSuggestion<unknown>>;
    /**
     * Event triggered when the search field is cleared
     */
    fieldCleared: Subject<void>;
    /**
     * Event triggered when the value of the search field changes. Debounced with 300ms.
     */
    valueChange: EventEmitter<string>;
    /**
     * Event when the search is executed (e.g. Enter key pressed)
     */
    search: Subject<string>;
    /**
     * Event triggered when the value of the search field changes and emits `true` when a value is changed manually
     * (not selected from suggestions)
     */
    manualValueChange: EventEmitter<boolean>;
    /**
     * Event triggered the input is blurred
     */
    blurred: EventEmitter<void>;
    /** @ignore */
    inputField: UiTextInputComponent;
    customContent: ElementRef<HTMLElement>;
    /** @ignore */
    get notEmpty(): boolean;
    /** @ignore */
    get showOverlay(): boolean;
    /** @ignore */
    get highlightedSuggestion(): number;
    /** @ignore */
    fixed: boolean;
    private _activated;
    private _fixable;
    private _disabled;
    private _locked;
    private _useSecondaryLabelAsValue;
    private _focused;
    private _highlightedSuggestion?;
    private _showPlaceholderIcon;
    private _enableAnimation;
    private _showMobileSuggestionIcon;
    private _disableMobileFullScreenOverlay;
    private _lockComponent;
    private _customContent;
    private _invalid;
    private _inputElement;
    private readonly blurTimeout;
    private readonly blurSubject;
    private readonly blurSubscription;
    private readonly suggestionCircularArray;
    readonly avoidPointerDownCollision: typeof PointerDeviceService.avoidPointerDownCollision;
    /** @ignore */
    blurCustomContent(event: FocusEvent): void;
    constructor(iconReg: SieIconRegistryService, layoutService: LayoutService, cdr: ChangeDetectorRef, cdrSelf: ChangeDetectorRef, elementRef: ElementRef);
    /** @ignore */
    ngOnDestroy(): void;
    /** @ignore */
    ngAfterViewInit(): void;
    /** @ignore */
    onFieldFocus(): void;
    /** @ignore */
    onFieldBlur(force?: boolean): void;
    /** @ignore */
    selectSuggestion(event: Event, suggestion: UiInlineSearchSuggestion): void;
    /** @ignore */
    copySuggestion(event: MouseEvent, suggestion: UiInlineSearchSuggestion): void;
    /** @ignore */
    onOverlayClick(event: MouseEvent): void;
    /**
     * Method to lock the component and blur the input field
     */
    lock(): void;
    /**
     * Method to unlock the component which clears the input component and focuses it
     */
    unlock(): void;
    /** @ignore */
    highlightNextSuggestion(): void;
    /** @ignore */
    highlightPreviousSuggestion(): void;
    /** @ignore */
    highlightSuggestion(index: number): void;
    handleEscape(event: Event): void;
    /** @ignore */
    unhighlightSuggestion(): void;
    /** @ignore */
    onValueChange(value: string): void;
    /**
     * Method to set the focus to the component's input field
     */
    focusField(): void;
    /**
     * Method to blur the focus to the component's input field
     */
    blurField(): void;
    continueTyping(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<UiInlineSearchComponent, [null, null, { optional: true; skipSelf: true; }, null, null]>;
    static ɵcmp: i0.ɵɵComponentDeclaration<UiInlineSearchComponent, "sie-ui-inline-search", never, { "id": { "alias": "id"; "required": false; }; "suggestions": { "alias": "suggestions"; "required": false; }; "placeholder": { "alias": "placeholder"; "required": false; }; "showPlaceholderIcon": { "alias": "showPlaceholderIcon"; "required": false; }; "customClass": { "alias": "customClass"; "required": false; }; "showMobileSuggestionIcon": { "alias": "showMobileSuggestionIcon"; "required": false; }; "enableAnimation": { "alias": "enableAnimation"; "required": false; }; "disableMobileFullScreenOverlay": { "alias": "disableMobileFullScreenOverlay"; "required": false; }; "value": { "alias": "value"; "required": false; }; "lockComponent": { "alias": "lockComponent"; "required": false; }; "noResultsMessage": { "alias": "noResultsMessage"; "required": false; }; "noContentMessage": { "alias": "noContentMessage"; "required": false; }; "clearSearchScreenReaderText": { "alias": "clearSearchScreenReaderText"; "required": false; }; "disableFirstOverlayWhenEmpty": { "alias": "disableFirstOverlayWhenEmpty"; "required": false; }; "disabled": { "alias": "disabled"; "required": false; }; "locked": { "alias": "locked"; "required": false; }; "useSecondaryLabelAsValue": { "alias": "useSecondaryLabelAsValue"; "required": false; }; "activated": { "alias": "activated"; "required": false; }; "fixable": { "alias": "fixable"; "required": false; }; "enableCustomContent": { "alias": "enableCustomContent"; "required": false; }; "invalid": { "alias": "invalid"; "required": false; }; "invalidErrorMessage": { "alias": "invalidErrorMessage"; "required": false; }; "condensed": { "alias": "condensed"; "required": false; }; "resetCustomContentPadding": { "alias": "resetCustomContentPadding"; "required": false; }; }, { "suggestionSelected": "suggestionSelected"; "fieldCleared": "fieldCleared"; "valueChange": "valueChange"; "search": "search"; "manualValueChange": "manualValueChange"; "blurred": "blurred"; }, never, ["*"], false, never>;
}
//# sourceMappingURL=ui-inline-search.component.d.ts.map