import { ChangeDetectorRef, ElementRef, EventEmitter, OnChanges, OnInit, SimpleChanges } from '@angular/core';
import { NgFormControlDirective } from '../ui-form-control/ui-ng-form-control.directive';
import { AbstractControl, ValidationErrors } from '@angular/forms';
import { UiInputMode } from './ui-input.model';
import { Fallible, InternallyValidatable } from '@siemens/core';
import * as i0 from "@angular/core";
/** @ignore */
export declare enum InputValidity {
    Valid = 0,
    RequiredError = 1,
    Error = 2,
    AllowedLengthError = 3,
    PatternValidationError = 4
}
/**
 * Possible values for native HTML `autocomplete` attribute, `on` | `off`
 */
export type Autocomplete = 'on' | 'off';
/**
 * Base directive as base for all components that allow user's inputs
 */
export declare abstract class InputBaseDirective extends NgFormControlDirective implements OnInit, OnChanges, Fallible, InternallyValidatable {
    readonly cdr: ChangeDetectorRef;
    /** @ignore */
    labelTransformed: boolean;
    private _value;
    private _error;
    private _required;
    private _inputFocused;
    private _allowedCharacterLength;
    private _condensed;
    protected validityState: InputValidity;
    protected errorMessages: string[];
    get value(): string;
    /**
     * @param value Value of the input
     * @default '' empty string
     */
    set value(value: string);
    /**
     * Message displayed when `required` flag was set but user entered no value
     */
    requiredErrorMessage: string;
    /**
     * Message displayed when `allowedCharacterLength` is provided but user entered a longer text
     */
    allowedLengthErrorMessage: string;
    /**
     * Defines which regex should be used for password validation
     * @type string or RegexP
     */
    validationPattern: string | RegExp;
    /**
     * Message displayed when `validationPattern` is provided but user entered an invalid value
     */
    patternValidationErrorMessage: string;
    /**
     * Defines the text used by screen readers for the reset icon button
     * @default '' (empty string)
     */
    resetButtonScreenReaderText: string;
    /** @ignore */
    cssErrorClass: string;
    /**
     * Defines the autocomplete attribute
     * @default 'on'
     */
    autocomplete: Autocomplete;
    /**
     * @param required Defines if input is required
     * @default false
     */
    set required(required: boolean);
    get required(): boolean;
    /**
     * @param invalid Sets state of the component as invalid and adds style changes
     * @default false
     */
    set invalid(invalid: boolean);
    get invalid(): boolean;
    /**
     * @param value Defines if input is focused
     * @default false
     */
    set inputFocused(value: boolean);
    get inputFocused(): boolean;
    /**
     * @param value Defines how much characters text input components accepts
     */
    set allowedCharacterLength(value: number);
    get allowedCharacterLength(): number;
    /**
     * @param value Defines the condensed variance of the input.
     * Available only for the following input types:
     * - `text`: regular text input
     * - `textarea`: textarea input
     * @default false
     */
    set condensed(value: boolean);
    get condensed(): boolean;
    /** @ignore */
    set error(error: string);
    get error(): string;
    /**
     * Defines whether internal validation is used.
     * If set to `false` the error must be set externally, bound to a FormControl for example.
     */
    internalValidation: boolean;
    /** @ignore */
    mode: UiInputMode;
    /** @ignore */
    inlineSearch: boolean;
    /** @ignore */
    combobox: boolean;
    /**
     * Event triggered when the input is focused
     */
    focused: EventEmitter<void>;
    /**
     * Event triggered the input is blurred
     */
    blurred: EventEmitter<void>;
    /**
     * When a value in the input is changed. The emitted value is the input's value
     */
    valueChange: EventEmitter<string>;
    /**
     * Event triggered when the reset input icon is clicked.
     */
    resetInput: EventEmitter<void>;
    /** @ignore */
    inputField: ElementRef<HTMLInputElement>;
    protected constructor(cdr: ChangeDetectorRef);
    /** @ignore */
    ngOnInit(): void;
    /** @ignore */
    ngOnChanges(changes: SimpleChanges): void;
    /**
     * Triggers the change detection of the component
     */
    updateView(): void;
    /** @ignore */
    onFocus(e: Event): void;
    /** @ignore */
    onBlur(e: Event): void;
    /** @ignore */
    onValueChange(e: string): void;
    /** @ignore */
    checkLabelStyleOnLoad(): void;
    /** @ignore */
    writeValue(value: string): void;
    /** @ignore */
    isInputValid(): InputValidity;
    /**
     * Enforces the validation of the input component to be triggered
     */
    validateInput(): void;
    /** @ignore */
    validateInternal(control: AbstractControl): ValidationErrors | null;
    onResetButtonClicked(event: Event): void;
    getInput(): ElementRef;
    focus(): void;
    protected isValidRequired(): boolean;
    protected isValidAllowedLength(): boolean;
    protected isValidPattern(): boolean;
    protected isValid(): boolean;
    protected setValidity(validity: InputValidity): void;
    protected condition(testCondition: boolean, error: InputValidity): InputValidity;
    private populateErrorMessages;
    private dispatchChangeEvent;
    static ɵfac: i0.ɵɵFactoryDeclaration<InputBaseDirective, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<InputBaseDirective, never, never, { "value": { "alias": "value"; "required": false; }; "requiredErrorMessage": { "alias": "requiredErrorMessage"; "required": false; }; "allowedLengthErrorMessage": { "alias": "allowedLengthErrorMessage"; "required": false; }; "validationPattern": { "alias": "validationPattern"; "required": false; }; "patternValidationErrorMessage": { "alias": "patternValidationErrorMessage"; "required": false; }; "resetButtonScreenReaderText": { "alias": "resetButtonScreenReaderText"; "required": false; }; "cssErrorClass": { "alias": "cssErrorClass"; "required": false; }; "autocomplete": { "alias": "autocomplete"; "required": false; }; "required": { "alias": "required"; "required": false; }; "invalid": { "alias": "invalid"; "required": false; }; "inputFocused": { "alias": "inputFocused"; "required": false; }; "allowedCharacterLength": { "alias": "allowedCharacterLength"; "required": false; }; "condensed": { "alias": "condensed"; "required": false; }; "error": { "alias": "error"; "required": false; }; "internalValidation": { "alias": "internalValidation"; "required": false; }; "mode": { "alias": "mode"; "required": false; }; "inlineSearch": { "alias": "inlineSearch"; "required": false; }; "combobox": { "alias": "combobox"; "required": false; }; }, { "focused": "focused"; "blurred": "blurred"; "valueChange": "valueChange"; "resetInput": "resetInput"; }, never, never, false, never>;
}
//# sourceMappingURL=ui-input-base.directive.d.ts.map