import { Subject } from 'rxjs';
import { ChangeDetectorRef, OnInit } from '@angular/core';
import { LinkModel } from '../ui-link/ui-link.model';
import * as i0 from "@angular/core";
/**
 * # Link List component
 *
 * Link list provides a list of links that are contextual and related to each other in most cases.
 * Link list is used when there are multiple links required to be displayed.
 * For example, footer. The link list is available in all the variants defined in links.
 *
 * ## Component variations
 *
 * - With separator
 * - Without separator
 *
 * ## Content
 *
 * The link list component does not accept any content.
 *
 * ## Code example
 * @example
 * Template:
 * ```html
 *  <sie-ui-link-list
 *    [numberOfVisibleLinks]="3"
 *    [hasUnderline]="true"
 *    [links]="linkListItems"
 *    [headlineCollapsed]="'Show More'"
 *    [headlineExpanded]="'Show Less'"
 *  ></sie-ui-link-list>
 * ```
 *
 * Link list items data example:
 * ```js
 *  linkListItems = [
 *    {
 *       href: '#',
 *       linkText: 'Test link'
 *    },
 *    {
 *       href: '#',
 *       linkText: 'Test link with a bit longer text',
 *       icon: SieIcon.Email
 *    },
 *    {
 *       href: '#',
 *       linkText: 'Test link without icon'
 *    },
 *    {
 *       href: '#',
 *       linkText: 'Link that overflows'
 *    },
 *    {
 *       href: '#',
 *       linkText: 'Link that overflows',
 *       disabled: true
 *    }
 *  ];
 * ```
 */
export declare class UiLinkListComponent implements OnInit {
    cdr: ChangeDetectorRef;
    /**
     * The main source array of the {@link LinkModel link data} that should be displayed.
     */
    links: LinkModel[];
    /**
     * Sets the headline for the collapsed overflow button.
     */
    headlineCollapsed: string;
    /**
     * Sets the headline for the expanded overflow button.
     */
    headlineExpanded: string;
    /**
     * Defines the gradient color of the overflow
     */
    overflowGradientColor: string;
    /**
     * @param numberOfVisibleLinks Sets the number of visible links inside the overflow.
     * If it is not set, all links will be visible without overflow.
     * @default null
     */
    set numberOfVisibleLinks(numberOfVisibleLinks: number);
    get numberOfVisibleLinks(): number;
    /**
     * @param value Defines whether the links inside the link list are separated.
     * @default false
     */
    set hasUnderline(value: boolean);
    get hasUnderline(): boolean;
    /**
     * @param value Defines whether the content inside the links should be truncated.
     * @default true
     */
    set truncate(value: boolean);
    get truncate(): boolean;
    /**
     * Event triggered when one of the link in the link list is clicked.
     */
    clicked: Subject<unknown>;
    /** @ignore */
    expandableLimit: string;
    private _numberOfVisibleLinks;
    private _hasUnderline;
    private _truncate;
    constructor(cdr: ChangeDetectorRef);
    /** @ignore */
    ngOnInit(): void;
    private calculateExpandableLimit;
    /** @ignore */
    onClicked(link: LinkModel): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<UiLinkListComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<UiLinkListComponent, "sie-ui-link-list", never, { "links": { "alias": "links"; "required": false; }; "headlineCollapsed": { "alias": "headlineCollapsed"; "required": false; }; "headlineExpanded": { "alias": "headlineExpanded"; "required": false; }; "overflowGradientColor": { "alias": "overflowGradientColor"; "required": false; }; "numberOfVisibleLinks": { "alias": "numberOfVisibleLinks"; "required": false; }; "hasUnderline": { "alias": "hasUnderline"; "required": false; }; "truncate": { "alias": "truncate"; "required": false; }; }, { "clicked": "clicked"; }, never, never, false, never>;
}
//# sourceMappingURL=ui-link-list.component.d.ts.map