import { PlainObject } from '@siemens/core';
import { Subject } from 'rxjs';
import { ElementRef, OnInit } from '@angular/core';
import { SieIcon, SieIconRegistryService } from '@siemens/icons';
import { LinkBackground, LinkSize, LinkType, LinkVariant } from './ui-link.model';
import * as i0 from "@angular/core";
/**
 * # Link component
 *
 * Links are used to connect two or more contexts (e.g. pages or sections).
 * It could be a standard link or could be an in-line link that is embedded in a paragraph.
 *
 * ## Component variations
 *
 * - Standard link/icon link
 * - Inline link
 *
 * ## Content
 *
 * The label of the link component can be any valid markup.
 *
 * ## Code example
 * @example
 * Template:
 * ```html
 * Standard link:
 * <sie-ui-link
 *   background="light-neutral"
 *   secondaryLabel="Secondary label with long line of text, long enough for truncation."
 *   href="https://www.siemens.com"
 * >
 *   Neutral link component gets truncated after two lines of text, let's see it
 * </sie-ui-link>
 *
 * Inline link:
 * <p>
 *   Medium sized link with inline link variant:
 *   <sie-ui-link href="https://www.siemens.com" variant="inline">
 *     Lorem Ipsum One line
 *   </sie-ui-link>. And some more content
 * </p>
 * ```
 */
export declare class UiLinkComponent implements OnInit {
    iconReg: SieIconRegistryService;
    /** @ignore */
    link: ElementRef;
    /**
     * @param disabled Defines if the link is disabled.
     * @default false
     */
    set disabled(disabled: boolean);
    get disabled(): boolean;
    /** @ignore */
    get validInlineBlock(): boolean;
    /**
     * @param disableVisitedStyle Defines if the links visited style should be disabled.
     * @default false
     */
    set disableVisitedStyle(disableVisitedStyle: boolean);
    get disableVisitedStyle(): boolean;
    /**
     * @param hasMarginTop Defines if the link should have a margin top set.
     * @default false
     */
    set hasMarginTop(hasMarginTop: boolean);
    get hasMarginTop(): boolean;
    /**
     * @param offsetIcon Defines if the link's icon should have a negative offset set.
     * @default false
     */
    set offsetIcon(offsetIcon: boolean);
    get offsetIcon(): boolean;
    /**
     * @param truncate Defines whether the content inside the link should be truncated.
     * @default true
     */
    set truncate(truncate: boolean);
    get truncate(): boolean;
    /**
     * @param inLinkList Defines if the link is placed within the link list.
     * If so, the padding around the link would be set to a lower value, to appear condensed.
     * @default false
     */
    set inLinkList(inLinkList: boolean);
    get inLinkList(): boolean;
    /**
     * @param trailingIcon Defines the {@link SieIcon icon} in the trailing position.
     */
    set trailingIcon(trailingIcon: SieIcon);
    get trailingIcon(): SieIcon;
    /**
     * @param icon Defines which {@link SieIcon icon} should be shown inside the link.
     * If not provided, the `ArrowRight` icon is used by default
     */
    set icon(icon: SieIcon);
    get icon(): SieIcon;
    /**
     * Sets the custom css class on the anchor element.
     * To add multiple classes provide the string with the whitespace between classes, e.g.: `class-a class-b`.
     * @default ''
     */
    cssClass: string;
    /**
     * Sets the URL that the link redirects you to.
     */
    href: string;
    /**
     * Defines the {@link LinkSize size} of the link.
     * @default ''
     */
    size: LinkSize;
    /**
     * Defines where the link should be opened.
     * @default '_self'
     */
    target?: string;
    /**
     * Defines the {@link LinkVariant variation} of the link.
     * @default 'icon-link'
     */
    variant?: LinkVariant;
    /**
     * Defines on which {@link LinkBackground background} the link is placed.
     * @default 'light'
     */
    background?: LinkBackground;
    /**
     * Defines the actual {@link LinkType type} of HTML element.
     * @default 'link'
     */
    type?: LinkType;
    /**
     * Sets the referenced part of the link name to be highlighted.
     */
    reference?: string;
    /**
     * Sets the text for screen readers.
     */
    screenReaderText?: string;
    /**
     * Defines a secondary label for a link variant `icon-link`, normally used with `light-neutral`, `dark-neutral` background type.
     */
    secondaryLabel?: string;
    /**
     * Defines the value of the data attribute `download`.
     */
    download?: string;
    /**
     * Add additional attributes to the link component (e.g.: for tracking).
     */
    dataAttributes?: PlainObject;
    /**
     * Sets the browser tooltip value
     */
    tooltip: string;
    /**
     * Sets the button type when the link is of type `button`. Possible values submit | reset | button.
     */
    buttonType: HTMLButtonElement['type'];
    /**
     * Event triggered when the link is of type `button` and is clicked.
     */
    clicked: Subject<unknown>;
    private _icon;
    private _disableVisitedStyle;
    private _hasMarginTop;
    private _offsetIcon;
    private _truncate;
    private _inLinkList;
    private _disabled;
    private _trailingIcon;
    constructor(iconReg: SieIconRegistryService);
    /** @ignore */
    ngOnInit(): void;
    /** Focuses the link. */
    focus(): void;
    /** @ignore */
    onClick(event: Event): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<UiLinkComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<UiLinkComponent, "sie-ui-link", never, { "disabled": { "alias": "disabled"; "required": false; }; "disableVisitedStyle": { "alias": "disableVisitedStyle"; "required": false; }; "hasMarginTop": { "alias": "hasMarginTop"; "required": false; }; "offsetIcon": { "alias": "offsetIcon"; "required": false; }; "truncate": { "alias": "truncate"; "required": false; }; "inLinkList": { "alias": "inLinkList"; "required": false; }; "trailingIcon": { "alias": "trailingIcon"; "required": false; }; "icon": { "alias": "icon"; "required": false; }; "cssClass": { "alias": "cssClass"; "required": false; }; "href": { "alias": "href"; "required": false; }; "size": { "alias": "size"; "required": false; }; "target": { "alias": "target"; "required": false; }; "variant": { "alias": "variant"; "required": false; }; "background": { "alias": "background"; "required": false; }; "type": { "alias": "type"; "required": false; }; "reference": { "alias": "reference"; "required": false; }; "screenReaderText": { "alias": "screenReaderText"; "required": false; }; "secondaryLabel": { "alias": "secondaryLabel"; "required": false; }; "download": { "alias": "download"; "required": false; }; "dataAttributes": { "alias": "dataAttributes"; "required": false; }; "tooltip": { "alias": "tooltip"; "required": false; }; "buttonType": { "alias": "buttonType"; "required": false; }; }, { "clicked": "clicked"; }, never, ["*"], false, never>;
}
//# sourceMappingURL=ui-link.component.d.ts.map