import { UiListComponent } from '../ui-list/ui-list.component';
import { ChangeDetectorRef, ElementRef, OnInit, Type } from '@angular/core';
import { SieIcon } from '@siemens/icons';
import { Subject } from 'rxjs';
import { UIListItemAppearance, UIListItemType } from '../ui-list/ui-list.types';
import { PaginationType, UiListDataAttributeWrapper, UiListNavigatorInputs, UiPaginationScreenReaderInputs } from './ui-list-navigator-inputs';
import { UiListItemModel } from '../ui-list/ui-list-item/ui-list-item.model';
import { UiAdvancedListItemSelectionChangeData, UiListItemDirective, UiListItemEvent } from '../ui-list/ui-list-item/ui-list-item.directive';
import { UiButtonModel } from '../ui-button/base/ui-button.model';
import { LinkModel } from '../ui-link/ui-link.model';
import { BaseListPagination, LayoutService } from '@siemens/core';
import { EmptyStateIconPosition, EmptyStateModel } from '../ui-empty-state/ui-empty-state.model';
import { PaginationSize } from '../ui-pagination/ui-pagination.types';
import * as i0 from "@angular/core";
/**
 * # List Navigator Component
 *
 * Lists provide a structured and manageable view on content items of a kind.
 *
 * ## Content
 *
 * The content can be passed as child elements and only those with the class `.list-item` are
 * recognized. List can also accept header as any valid HTML markup with an attribute `headerslot` on the element.
 *
 * ## Component variations
 *
 * - `itemType: 'file'` and `itemAppearance: 'simple'`
 * - `itemType: 'file'` and `itemAppearance: 'complex'`
 * - `itemType: 'folder'`
 *
 * ## Code example
 * @example ```html
 * <sie-ui-list-navigator
 *   itemType="file"
 *   itemAppearance="complex"
 *   [itemComponents]="itemComponents"
 *   [loading]="loading"
 *   [itemData]="itemData"
 *   [itemsPerPage]="10"
 *   [numberOfSkeletons]="3"
 *   [bulkMode]="false"
 * ></sie-ui-list-navigator>
 * ```
 *
 * List data example:
 * ```js
 * itemComponents: Type<any>[] = [UiCockpitListItemComponent];
 * itemData: any[] = [
 *   {
 *     id: 1,
 *     categoryName: 'orders',
 *     statusPhraseLabel: 'A product is not available',
 *     primaryMeta: 'Your order no.: 740490/Freiherr-von-Vincke-Reals',
 *     secondaryMeta: 'Order date: 07/20/2020',
 *     timestampRelative: 'Just now',
 *     urlToItemDetails: 'https://new.siemens.com/at/de.html'
 *   }
 * ```
 */
export declare class UiListNavigatorComponent<ItemData extends UiListItemModel> implements UiListNavigatorInputs<ItemData>, OnInit {
    protected cd: ChangeDetectorRef;
    private readonly layoutService;
    /** @ignore */
    elementsRef: ElementRef;
    /**
     * Defines {@link UIListItemType} list item type
     */
    itemType: UIListItemType;
    /**
     * Defines {@link UIListItemAppearance} appearance of the list item
     */
    itemAppearance: UIListItemAppearance;
    /**
     * Component type which is created for each list item dynamically
     * @default `[UiBaseListItemComponent]`
     */
    itemComponents: Type<UiListItemDirective>[];
    /**
     * Defines what {@link PaginationType pagination type} should be used if pagination is needed
     * @default 'default'
     */
    paginationType: PaginationType;
    /**
     * Defined based on the {@link PaginationSize pagination size} whether 5 or 7 visible pages are displayed.
     * @default 'regular' 7 visible pages
     */
    paginationSize: PaginationSize;
    /**
     * Set the maximum number of items to render
     */
    limitOfItemsToRender: number;
    /**
     * Set the text of the tooltip when the result limit reached
     */
    resultLimitReachedTooltipLabel: string;
    /**
     * Set the headline of the message box when the result limit reached
     */
    resultLimitReachedMessageBoxHeadline: string;
    /**
     * Set the message of the message box when the result limit reached
     */
    resultLimitReachedMessageBoxMessage: string;
    /** @ignore only for SPA purpose */
    showCatalogConfigureProducts: boolean;
    /** @ignore only for SPA purpose */
    pagination: BaseListPagination;
    /**
     * Defines the selector of the element (e.g. class, id, etc.) on which scroll to the top will be performed
     */
    scrollToTopElementSelector: string;
    /**
     * Removes some margins and paddings for a 'condensed' styling if set to true
     * @default false
     */
    condensed: boolean;
    /**
     * Displays item per page selector if set to true
     * @default true
     */
    showItemPerPageSelector: boolean;
    /**
     * Displays 'back to top' button if set to true
     * @default true
     */
    showBackToTopButton: boolean;
    /**
     * Defines if pagination is displayed if set to true
     * @default true
     */
    showPagination: boolean;
    /**
     * Adds styling to align pagination to the bottom of the parent container if set to true
     * @default false
     */
    alignPaginationToBottom: boolean;
    /**
     * Defines which pagination page is set to active
     * @default 1
     */
    activePage: number;
    /**
     * @param data {@link UiListItemModel} list data to be set
     */
    set itemData(data: ItemData[]);
    get itemData(): ItemData[];
    /**
     * Count of all list items
     * @default null
     */
    totalResultsCount: number;
    /**
     * Number of displayed list item per pagination page (displayed options in dropdown)
     */
    itemsPerPageOptions: number[];
    /** Icon displayed in empty state */
    emptyStateCustomIcon: SieIcon;
    /**
     * {@link EmptyStateIconPosition Position} of empty state icon
     * @default 'onTop'
     */
    emptyStateIconPosition: EmptyStateIconPosition;
    /**
     * Defines if bulk mode is used if set to true
     * @default false
     */
    bulkMode: boolean;
    /**
     * Allows items to be dismissed when set to true
     * @default false
     */
    itemsDismissible: boolean;
    /**
     * If true list items are loading (shows loading indicator)
     * @default true
     */
    set loading(isLoading: boolean);
    get loading(): boolean;
    /**
     * If true more list items are being loaded (used in infinite pagination style)
     * @default false
     */
    loadingMore: boolean;
    /** @ignore only for SPA purpose */
    loadingChildren: boolean;
    /**
     * If true hover is tracked and a styling for hover is added for the list items
     * @default false
     */
    trackHover: boolean;
    /**
     * Defines if only selected items will be displayed in print preview, does nothing when not in bulk-selection mode
     * @default false
     */
    hideNotSelectedItemsInPrintPreview: boolean;
    /**
     * Number of displayed skeleton elements
     * @default 5
     */
    numberOfSkeletons: number;
    /**
     * Number of displayed skeleton elements in case of infinite pagination
     * @default 3
     */
    numberOfLoadMoreSkeletons: number;
    /**
     * Number of items per pagination page
     * @default 5
     */
    itemsPerPage: number;
    /** @ignore only for SPA purpose */
    set emptyState(emptyState: EmptyStateModel);
    /**
     * Headline of empty state
     * @default ''
     */
    emptyStateHeadline: string;
    /**
     * Text of empty state
     * @default ''
     */
    emptyStateText: string;
    /**
     * {@link UiButtonModel empty state button} data
     */
    emptyStateButton?: UiButtonModel;
    /**
     * {@link LinkModel empty state link} data
     */
    emptyStateLink?: LinkModel;
    /**
     * Text for show more button of list item
     * @default ''
     */
    expandableButtonMore: string;
    /**
     * Text for show less button of list items
     * @default ''
     */
    expandableButtonLess: string;
    /**
     * Text displayed next to 'items per page' dropdown
     * @default ''
     */
    itemsPerPageText: string;
    /**
     * Text used by screen readers for back to top button
     * @default ''
     */
    backToTopButtonScreenReaderText: string;
    /**
     * {@link UiPaginationScreenReaderInputs} screen reader texts for pagination
     */
    paginationScreenReader: UiPaginationScreenReaderInputs;
    /**
     * {@link UiListDataAttributeWrapper} additional data attributes which are attached to result list and footer sections
     */
    dataAttributeWrapper?: UiListDataAttributeWrapper;
    /**
     * Sets the pagination dropdown overlay in top position.
     */
    paginationOverlayOnTop: boolean;
    /**
     * Provide an additional offset for scroll to top button
     */
    scrollToTopOffset?: number;
    /**
     * Triggered when empty state is present and action was clicked
     */
    emptyStateActionClicked: Subject<Event>;
    /**
     * Triggered when in the items per page dropdown a new value was selected
     */
    itemsPerPageChanged: Subject<number>;
    /**
     * Triggered when a new page in pagination was selected
     */
    pageChanged: Subject<number>;
    /**
     * Triggered when user interaction is done, see {@link UiListItemEvent} for implementation details
     */
    itemEvent: Subject<UiListItemEvent<ItemData, import("@siemens/core").PlainObject>>;
    /** Triggered when component is in bulk mode and a new item was selected {@link UiAdvancedListItemSelectionChangeData} */
    selectionChanged: Subject<UiAdvancedListItemSelectionChangeData>;
    /** @ignore */
    listComponent: UiListComponent;
    /** @ignore */
    isSelectedSubject: Subject<string[]>;
    private _itemData;
    private _loading;
    /** @ignore */
    showEmptyState: boolean;
    constructor(cd: ChangeDetectorRef, layoutService: LayoutService);
    /** @ignore */
    ngOnInit(): void;
    /**
     * Set the empty state if the list items do not load and there is no data
     */
    setEmptyState(): void;
    /** @ignore */
    onBackToTopClicked(el: HTMLElement): void;
    /** @ignore */
    onEmptyStateActionClicked(event: Event): void;
    /** @ignore */
    onItemsPerPageChange(itemsPerPage: number): void;
    /** @ignore */
    onPageChange(page: number): void;
    /**
     * Selects or deselects all checkboxes currently available in the list (only if bulkMode is true)
     * @param [selected=true] if checkbox is selected or not
     */
    bulkSelect(selected?: boolean): void;
    /**
     * Selects or deselects the items provided
     * @param [ids] array of ids of the items which should be selected or deselected
     * @param [select=true] whether a bulk select or unselect is carried out
     */
    specificBulkSelect(ids: Array<string>, select?: boolean): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<UiListNavigatorComponent<any>, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<UiListNavigatorComponent<any>, "sie-ui-list-navigator", never, { "itemType": { "alias": "itemType"; "required": false; }; "itemAppearance": { "alias": "itemAppearance"; "required": false; }; "itemComponents": { "alias": "itemComponents"; "required": false; }; "paginationType": { "alias": "paginationType"; "required": false; }; "paginationSize": { "alias": "paginationSize"; "required": false; }; "limitOfItemsToRender": { "alias": "limitOfItemsToRender"; "required": false; }; "resultLimitReachedTooltipLabel": { "alias": "resultLimitReachedTooltipLabel"; "required": false; }; "resultLimitReachedMessageBoxHeadline": { "alias": "resultLimitReachedMessageBoxHeadline"; "required": false; }; "resultLimitReachedMessageBoxMessage": { "alias": "resultLimitReachedMessageBoxMessage"; "required": false; }; "showCatalogConfigureProducts": { "alias": "showCatalogConfigureProducts"; "required": false; }; "pagination": { "alias": "pagination"; "required": false; }; "scrollToTopElementSelector": { "alias": "scrollToTopElementSelector"; "required": false; }; "condensed": { "alias": "condensed"; "required": false; }; "showItemPerPageSelector": { "alias": "showItemPerPageSelector"; "required": false; }; "showBackToTopButton": { "alias": "showBackToTopButton"; "required": false; }; "showPagination": { "alias": "showPagination"; "required": false; }; "alignPaginationToBottom": { "alias": "alignPaginationToBottom"; "required": false; }; "activePage": { "alias": "activePage"; "required": false; }; "itemData": { "alias": "itemData"; "required": false; }; "totalResultsCount": { "alias": "totalResultsCount"; "required": false; }; "itemsPerPageOptions": { "alias": "itemsPerPageOptions"; "required": false; }; "emptyStateCustomIcon": { "alias": "emptyStateCustomIcon"; "required": false; }; "emptyStateIconPosition": { "alias": "emptyStateIconPosition"; "required": false; }; "bulkMode": { "alias": "bulkMode"; "required": false; }; "itemsDismissible": { "alias": "itemsDismissible"; "required": false; }; "loading": { "alias": "loading"; "required": false; }; "loadingMore": { "alias": "loadingMore"; "required": false; }; "loadingChildren": { "alias": "loadingChildren"; "required": false; }; "trackHover": { "alias": "trackHover"; "required": false; }; "hideNotSelectedItemsInPrintPreview": { "alias": "hideNotSelectedItemsInPrintPreview"; "required": false; }; "numberOfSkeletons": { "alias": "numberOfSkeletons"; "required": false; }; "numberOfLoadMoreSkeletons": { "alias": "numberOfLoadMoreSkeletons"; "required": false; }; "itemsPerPage": { "alias": "itemsPerPage"; "required": false; }; "emptyState": { "alias": "emptyState"; "required": false; }; "emptyStateHeadline": { "alias": "emptyStateHeadline"; "required": false; }; "emptyStateText": { "alias": "emptyStateText"; "required": false; }; "emptyStateButton": { "alias": "emptyStateButton"; "required": false; }; "emptyStateLink": { "alias": "emptyStateLink"; "required": false; }; "expandableButtonMore": { "alias": "expandableButtonMore"; "required": false; }; "expandableButtonLess": { "alias": "expandableButtonLess"; "required": false; }; "itemsPerPageText": { "alias": "itemsPerPageText"; "required": false; }; "backToTopButtonScreenReaderText": { "alias": "backToTopButtonScreenReaderText"; "required": false; }; "paginationScreenReader": { "alias": "paginationScreenReader"; "required": false; }; "dataAttributeWrapper": { "alias": "dataAttributeWrapper"; "required": false; }; "paginationOverlayOnTop": { "alias": "paginationOverlayOnTop"; "required": false; }; "scrollToTopOffset": { "alias": "scrollToTopOffset"; "required": false; }; }, { "emptyStateActionClicked": "emptyStateActionClicked"; "itemsPerPageChanged": "itemsPerPageChanged"; "pageChanged": "pageChanged"; "itemEvent": "itemEvent"; "selectionChanged": "selectionChanged"; }, never, ["[HeaderSlot]", ".list-item", "[ButtonSlot]", "[footerLink]"], false, never>;
    static ngAcceptInputType_hideNotSelectedItemsInPrintPreview: unknown;
}
//# sourceMappingURL=ui-list-navigator.component.d.ts.map