import { AfterViewInit, ChangeDetectorRef, OnChanges, OnDestroy, SimpleChanges, ViewContainerRef } from '@angular/core';
import { BehaviorSubject, Observable, Subject } from 'rxjs';
import { UIListItemAppearance, UIListItemType } from '../ui-list.types';
import { UiListItemModel } from './ui-list-item.model';
import { PlainObject } from '@siemens/core';
import { DismissAnimationState } from '../../shared/animations/ui-fade-in-out.animations';
import * as i0 from "@angular/core";
/**
 * Predefined actions that a list item element can trigger
 */
export declare type UiItemActions = 'GET_ATTACHMENTS' | 'GET_VERSIONS' | 'GET_CHAPTER_LINKS' | 'GET_ALTERNATIVE_BUYING_OPTIONS' | 'LOGIN_TO_BUY' | 'UPDATE_PRICE' | 'ADD_TO_CART' | 'CHECK_AVAILABILITY' | 'DISMISS_ONE_ITEM' | 'DISMISS_ONE_ITEM_NO_API_ANSWER' | 'LOAD_ITEM_CHILDREN' | 'LOAD_ITEM_ATTRIBUTES' | 'REFRESH' | 'OPEN_DETAILS_PAGE' | 'LOAD_EMAIL_BODY' | 'LOAD_ATTACHMENT_BLOB' | 'LOAD_MORE_LIST_ITEMS' | 'ACTION_MENU_CLICKED' | 'EDIT_BUTTON_CLICKED' | 'OPEN_SPECIFICATIONS_MODAL';
export interface UiAdvancedListItemSelectionChangeData {
    /**
     * Id of the list item that has got a selection change
     */
    id: string;
    /**
     * Specify whether the element is selected or deselected
     */
    isSelected: boolean;
}
export interface UiListItemEvent<ItemModel = UiListItemModel, AED = PlainObject> {
    /**
     * Type of {@link UiItemActions}
     */
    action: UiItemActions;
    /**
     * List item for which the action was triggered
     */
    item: ItemModel;
    /**
     * Id of list item which was triggered
     */
    id?: string;
    /**
     * Additional information that can be passed along
     */
    additionalData?: AED;
    /**
     * Will be provided for 'DISMISS_ONE_ITEM' action when user clicked the dismiss button.
     * Call appropiate functions when event gets evaluated.
     */
    fadeOutOptions?: {
        /**
         * Fades out the item completely
         */
        success: () => void;
        /**
         * Fades the item in again
         */
        failure: () => void;
    };
}
export declare class UiListItemDirective<ItemModel extends UiListItemModel = UiListItemModel, AED = PlainObject> implements AfterViewInit, OnChanges, OnDestroy {
    protected cdr: ChangeDetectorRef;
    viewContainerRef?: ViewContainerRef;
    /**
     * @param itemData data of the list item
     */
    set itemData(itemData: ItemModel);
    get itemData(): ItemModel;
    /**
     * Defines list item type {@link UIListItemType}
     * @default 'file'
     */
    itemType: UIListItemType;
    /**
     * Defines appearance of list item {@link UIListItemAppearance}
     * @default 'simple'
     */
    itemAppearance: UIListItemAppearance;
    /**
     * Manages styling with less padding and margin
     * @default false
     */
    condensed: boolean;
    /**
     * Defines if hover should be tracked and hover styles applied on the list items
     * @default false
     */
    trackHover: boolean;
    /**
     * Displays loading state of list items if set to true
     * @default false
     */
    loading: boolean;
    /** @ignore */
    loadingChildren: boolean;
    /**
     * Defines if bulk mode is active if true
     * @default false
     */
    bulkMode: boolean;
    /**
     * Allows item to be dissmissed when set to true
     * @default false
     */
    dismissable: boolean;
    /**
     * Observable to notify list item that selection changed by parent component
     */
    isSelected$: Observable<Array<string>>;
    /**
     * Text for show more button of list item
     * @default ''
     */
    expandableButtonMore: string;
    /**
     * Text for show less button of list item
     * @default ''
     */
    expandableButtonLess: string;
    /** @ignore */
    index: number;
    /**
     * Additional data attributes which can be passed to list item (e.g. tracking)
     */
    dataAttributes: PlainObject;
    /** @ignore */
    showCatalogConfigureProducts: boolean;
    /** @ignore */
    connectedComponent: UiListItemDirective;
    /**
     * Defines if status indicator is displayed
     * @default true
     */
    showStatusIndicator: boolean;
    /**
     * Triggered when component is in bulk mode and a new item was selected {@link UiAdvancedListItemSelectionChangeData}
     */
    selectionChanged: Subject<UiAdvancedListItemSelectionChangeData>;
    /**
     * Triggered when list element is selected and passes {@link UiItemActions} and selected item
     */
    itemEvent: Subject<UiListItemEvent<ItemModel, AED>>;
    _itemData: ItemModel;
    dismissAnimationState$: BehaviorSubject<DismissAnimationState>;
    private isSelectedSubscription;
    constructor(cdr: ChangeDetectorRef, viewContainerRef?: ViewContainerRef);
    /** @ignore */
    ngAfterViewInit(): void;
    /** @ignore */
    ngOnChanges(_changes: SimpleChanges): void;
    /** @ignore */
    ngOnDestroy(): void;
    /** @ignore */
    headerContentAvailable(): boolean;
    static ɵfac: i0.ɵɵFactoryDeclaration<UiListItemDirective<any, any>, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<UiListItemDirective<any, any>, "[sieUiAdvancedListItem]", never, { "itemData": { "alias": "itemData"; "required": false; }; "itemType": { "alias": "itemType"; "required": false; }; "itemAppearance": { "alias": "itemAppearance"; "required": false; }; "condensed": { "alias": "condensed"; "required": false; }; "trackHover": { "alias": "trackHover"; "required": false; }; "loading": { "alias": "loading"; "required": false; }; "loadingChildren": { "alias": "loadingChildren"; "required": false; }; "bulkMode": { "alias": "bulkMode"; "required": false; }; "dismissable": { "alias": "dismissable"; "required": false; }; "isSelected$": { "alias": "isSelected$"; "required": false; }; "expandableButtonMore": { "alias": "expandableButtonMore"; "required": false; }; "expandableButtonLess": { "alias": "expandableButtonLess"; "required": false; }; "index": { "alias": "index"; "required": false; }; "dataAttributes": { "alias": "dataAttributes"; "required": false; }; "showCatalogConfigureProducts": { "alias": "showCatalogConfigureProducts"; "required": false; }; "connectedComponent": { "alias": "connectedComponent"; "required": false; }; "showStatusIndicator": { "alias": "showStatusIndicator"; "required": false; }; }, { "selectionChanged": "selectionChanged"; "itemEvent": "itemEvent"; }, never, never, false, never>;
}
//# sourceMappingURL=ui-list-item.directive.d.ts.map