import { ChangeDetectorRef, ElementRef, EventEmitter, OnInit } from '@angular/core';
import { SieIcon, SieIconRegistryService } from '@siemens/icons';
import { UiMenuButtonModel } from './ui-menu-button.model';
import { UiDropdownBaseDirective } from '../ui-dropdown/base/ui-dropdown.base.directive';
import { ButtonType, LayoutService, ThemeVariant } from '@siemens/core';
import { UiEventPropagationService } from '../services/ui-event-propagation.service';
import { BehaviorSubject } from 'rxjs';
import { CdkOverlayService } from '../services';
import { UiButtonThemeType, UiButtonVariant } from '../ui-button/base/ui-button.types';
import * as i0 from "@angular/core";
/**
 * # Menu button component
 *
 * Menu button is a combination of a button and a menu. It provides access to multiple related actions to the user
 * within one button.
 *
 * ## Component variations
 *
 * - standard menu button: The default menu button is displayed.
 * - icon button: Provided icon will be used to display the menu button.
 *
 * ## Content
 *
 * The Menu Button component does not accept any content.
 *
 * ## Code example
 *
 * @example ```html
 * <sie-ui-menu-button
 *   theme="light"
 *   menuButtonType="standard"
 *   menuButtonText="Export"
 *   [leadingButtonIcon]="iconReg.sieIcon.Globe"
 *   [options]="[
 *     { value: '1', label: 'Value Option 1', disabled: false },
 *     { value: '5', label: 'Value Option 5', disabled: false}
 *   ]"
 *   (actionClicked)="menuButtonActionClicked($event)"
 * ></sie-ui-menu-button>
 *
 * <sie-ui-menu-button
 *   theme="light"
 *   [options]= "[
 *     {
 *       value: '1',
 *       label: 'SieportalIntMiniWithoutBorderTag',
 *       disabled: false,
 *       icon: SieIcon.SieportalIntMiniWithoutBorderTag
 *     }
 *   ]"
 *   (actionClicked)="menuButtonActionClicked($event)"
 * ></sie-ui-menu-button>
 * ```
 */
export declare class UiMenuButtonComponent extends UiDropdownBaseDirective<UiMenuButtonModel> implements OnInit {
    readonly iconReg: SieIconRegistryService;
    readonly layoutService: LayoutService;
    readonly eventPropagationService: UiEventPropagationService;
    protected readonly cdr: ChangeDetectorRef;
    protected readonly elementRef: ElementRef;
    protected readonly cdkOverlayService: CdkOverlayService;
    /**
     * Defines the screen reader text for the options button
     */
    menuButtonScreenReaderText: string;
    /**
     * {@link UiMenuButtonModel Event emitter} when action is clicked or selected via keyboard
     */
    actionClicked: EventEmitter<import("@siemens/ui").UiDropdownMenuModel>;
    /**
     * Overrides the {@link ThemeVariant Mode} of the menu when necessary. When not provided defaults to `theme`
     * @default 'light'
     */
    menuTheme: ThemeVariant;
    /**
     * Defines the {@link ButtonType type} of the menu button
     * @default 'icon'
     */
    menuButtonType: ButtonType;
    /**
     * Defines the {@link UiButtonVariant variant} of the standard menu button
     * @default 'secondary'
     */
    menuButtonVariant: UiButtonVariant;
    /**
     * Defines the {@link UiButtonThemeType theme} of the standard menu button
     * @default 'un-contained'
     */
    menuButtonThemeType: UiButtonThemeType;
    /**
     * @param value Adds the text to the button used when the standard type was chosen
     * @default ''
     */
    set menuButtonText(value: string);
    get menuButtonText(): string;
    private _menuButtonText;
    /**
     * {@link SieIcon Icon} used for the main button that will open the dropdown selection
     */
    leadingButtonIcon: SieIcon;
    /** @ignore */
    leftAligned: boolean;
    /** @ignore */
    isSecondaryIconRotated$: BehaviorSubject<boolean>;
    constructor(iconReg: SieIconRegistryService, layoutService: LayoutService, eventPropagationService: UiEventPropagationService, cdr: ChangeDetectorRef, elementRef: ElementRef, cdkOverlayService: CdkOverlayService);
    /** @ignore */
    ngOnInit(): void;
    /** @ignore */
    itemSelected(item: UiMenuButtonModel): void;
    /** @ignore */
    focusOut(): void;
    /** @ignore */
    toggleDropDown(): void;
    /** @ignore */
    rotateSecondaryIcon(isRotated: boolean): void;
    /** @ignore */
    protected determineHorizontalMenuAlignment(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<UiMenuButtonComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<UiMenuButtonComponent, "sie-ui-menu-button", never, { "menuButtonScreenReaderText": { "alias": "menuButtonScreenReaderText"; "required": false; }; "menuTheme": { "alias": "menuTheme"; "required": false; }; "menuButtonType": { "alias": "menuButtonType"; "required": false; }; "menuButtonVariant": { "alias": "menuButtonVariant"; "required": false; }; "menuButtonThemeType": { "alias": "menuButtonThemeType"; "required": false; }; "menuButtonText": { "alias": "menuButtonText"; "required": false; }; "leadingButtonIcon": { "alias": "leadingButtonIcon"; "required": false; }; }, { "actionClicked": "actionClicked"; }, never, never, false, never>;
}
//# sourceMappingURL=ui-menu-button.component.d.ts.map