import { AfterViewInit, ChangeDetectorRef, EventEmitter, OnChanges, OnDestroy, OnInit, SimpleChanges, ViewContainerRef } from '@angular/core';
import { SieIcon, SieIconRegistryService } from '@siemens/icons';
import { MessageBoxElementLayout, MessageBoxType, MessageBoxVariant } from './ui-message-box.types';
import { UiAutoDestroyableComponent } from '../shared/components/ui-auto-destroyable.component';
import { UiOverflowInputs } from '../ui-overflow/ui-overflow-inputs';
import { ComponentBreakpointDefinition, ElementResizeDirective, LayoutService } from '@siemens/core';
import { LinkModel } from '../ui-link';
import { Observable, Subject } from 'rxjs';
import { UiButtonModel } from '../ui-button/base/ui-button.model';
import * as i0 from "@angular/core";
import * as i1 from "@siemens/core";
/**
 * # Message box component
 *
 * Message box provides useful status information to the user within a specific scope.
 * It is used to notify the user about successful or failed actions or to convey information about an element’s status.
 * For example if a product is about to be discontinued or a new successor version is available etc.
 *
 * ## Component variations
 *
 * - Text/headline behaviour
 *  - Standard Message Box
 *  - Message Box with Copy Text truncation
 *  - Message Box with headline only
 *  - Message Box with Copy text only
 * - Different states: info, warning, error, success
 * - With or without action button
 * - Fixed or closeable
 * - Condensed Message Box
 *
 * ## Content
 *
 * The message box component can contain child elements. With the right decorators they can be used as the following:
 * `messageContentSlot`: Used as the **messageContentSlot** within the message box
 *
 * ## Code example
 * @example ```html
 * <sie-ui-message-box
 *  variant="info"
 *  limit="3"
 *  headlineCollapsed="Show more"
 *  headlineExpanded="Show less"
 *  headline="This product is a Spare Part, please visit the Spares & Service section for more information"
 *  message="..."
 *  actionButtonLabel="Action"
 *  [closeable]="true"
 * >
 *  <div messageContentSlot>Lorem ipsum dolor sit amet, consectetur adipiscing elit.</div>
 * </sie-ui-message-box>
 * ```
 */
export declare class UiMessageBoxComponent extends UiAutoDestroyableComponent implements OnInit, OnDestroy, OnChanges, UiOverflowInputs, AfterViewInit {
    readonly iconReg: SieIconRegistryService;
    protected vcr: ViewContainerRef;
    protected readonly cdr: ChangeDetectorRef;
    private readonly layoutService;
    private readonly resizeDirective;
    /** @ignore */
    readonly messageViewports: ComponentBreakpointDefinition;
    /** @ignore */
    actionButtons: UiButtonModel[];
    /** @ignore */
    toggleAnimationState: 'hide' | 'show' | 'visible';
    /** @ignore */
    linesToTruncate$: Observable<number>;
    /** @ignore */
    smallViewport: boolean;
    /**
     * Type of the message box
     * @default 'standard'
     */
    set type(value: MessageBoxType);
    get type(): MessageBoxType;
    /**
     * Headline of the message box (only used for `standard` type)
     */
    headline: string;
    /**
     * Copy text of the message box
     */
    message: string;
    /**
     * Label to be shown under copy text when truncation is active and text is collapsed (only used for `standard` type)
     */
    headlineCollapsed: string;
    /**
     * Label to be shown under copy text when truncation is active and text is expanded (only used for `standard` type)
     */
    headlineExpanded: string;
    /**
     * Sets the point from which text gets truncated (e.g. '3': 3 lines, '50px': abs. px value, only used for `standard` type)
     */
    limit: string;
    /**
     * Defines the data of {@link LinkModel link} in a component.
     * If type of the component is `condensed`, then link {@link LinkModel variant} should be `inline`.
     */
    link: LinkModel;
    /** @ignore */
    playAnimation: Subject<boolean>;
    /**
     * Screen reader label for close icon when component is closeable
     * @default ''
     */
    screenReaderCloseIcon: string;
    /**
     * Additional input for element positioning (only used for `standard` type)
     * @default 'standard-layout'
     */
    elementsLayout: MessageBoxElementLayout;
    /**
     * If provided a fade in animation is displayed
     * @default false
     */
    fadeInAnimation: boolean;
    /**
     * If provided a button (or action-link) is added with the given label. When clicked an {@link actionTriggered event} is triggered
     */
    set actionButtonLabel(label: string);
    get actionButtonLabel(): string;
    /**
     * If provided the main button will behave as a link leading you to the destination specified
     */
    set actionButtonLink(link: string);
    /**
     * If provided a button is added with the given label with a different style. Only available for the `standard` type of the Message box.
     * When clicked an {@link actionTriggered event} is triggered
     */
    set secondaryActionButtonLabel(label: string);
    get secondaryActionButtonLabel(): string;
    /**
     * Variant of the message box
     * @default 'info'
     */
    set variant(value: MessageBoxVariant);
    get variant(): MessageBoxVariant;
    /**
     * Defines whether the message box can be closed. When the close button is closed an {@link messageClosed event} is triggered
     * @default true
     */
    closeable: boolean;
    /**
     * Defines if container-queries or media-queries are used for the message-box styling
     * @default true
     */
    containerStyled: boolean;
    /**
     * Event triggered when the action button or action link is clicked
     */
    actionTriggered: EventEmitter<string>;
    /**
     * Event triggered when the close button is clicked (finished action)
     */
    messageClosed: EventEmitter<Event>;
    /**
     * Event triggered when the close button is being clicked
     */
    messageClosing: EventEmitter<Event>;
    messageLinkTriggered: EventEmitter<Event>;
    /** @ignore */
    containerCssClass: boolean;
    private _icon;
    private _truncationGradientColor;
    private _variant;
    private _type;
    private _actionButtonLabel;
    private _secondaryActionButtonLabel;
    private readonly subscriptions;
    get iconName(): SieIcon;
    get gradientColor(): string;
    constructor(iconReg: SieIconRegistryService, vcr: ViewContainerRef, cdr: ChangeDetectorRef, layoutService: LayoutService, resizeDirective: ElementResizeDirective);
    /** @ignore */
    ngOnInit(): void;
    ngOnChanges(changes: SimpleChanges): void;
    ngAfterViewInit(): void;
    ngOnDestroy(): void;
    /** @ignore */
    destroy(event: Event): void;
    /** @ignore */
    triggerFadeInAnimation(): void;
    /** @ignore */
    onAnimationDone(event: Event): void;
    actionLinkClicked(e: Event): void;
    messageLinkClicked(e: Event): void;
    private setMessageBoxFunctionalType;
    private updateLinesToTruncate;
    private listenToSizeChange;
    private updateSmallViewport;
    static ɵfac: i0.ɵɵFactoryDeclaration<UiMessageBoxComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<UiMessageBoxComponent, "sie-ui-message-box", never, { "type": { "alias": "type"; "required": false; }; "headline": { "alias": "headline"; "required": false; }; "message": { "alias": "message"; "required": false; }; "headlineCollapsed": { "alias": "headlineCollapsed"; "required": false; }; "headlineExpanded": { "alias": "headlineExpanded"; "required": false; }; "limit": { "alias": "limit"; "required": false; }; "link": { "alias": "link"; "required": false; }; "playAnimation": { "alias": "playAnimation"; "required": false; }; "screenReaderCloseIcon": { "alias": "screenReaderCloseIcon"; "required": false; }; "elementsLayout": { "alias": "elementsLayout"; "required": false; }; "fadeInAnimation": { "alias": "fadeInAnimation"; "required": false; }; "actionButtonLabel": { "alias": "actionButtonLabel"; "required": false; }; "actionButtonLink": { "alias": "actionButtonLink"; "required": false; }; "secondaryActionButtonLabel": { "alias": "secondaryActionButtonLabel"; "required": false; }; "variant": { "alias": "variant"; "required": false; }; "closeable": { "alias": "closeable"; "required": false; }; "containerStyled": { "alias": "containerStyled"; "required": false; }; }, { "actionTriggered": "actionTriggered"; "messageClosed": "messageClosed"; "messageClosing": "messageClosing"; "messageLinkTriggered": "messageLinkTriggered"; }, never, ["[messageContentSlot]"], false, [{ directive: typeof i1.ElementResizeDirective; inputs: {}; outputs: {}; }]>;
    static ngAcceptInputType_fadeInAnimation: unknown;
    static ngAcceptInputType_closeable: unknown;
    static ngAcceptInputType_containerStyled: unknown;
}
//# sourceMappingURL=ui-message-box.component.d.ts.map