import { NgxSmartModalComponent } from 'ngx-smart-modal';
import { ChangeDetectorRef, ElementRef, OnDestroy, OnInit, Renderer2, ViewContainerRef } from '@angular/core';
import { UiBaseModalComponent } from '../ui-base-modal.component';
import { LayoutService } from '@siemens/core';
import { SieIcon, SieIconRegistryService } from '@siemens/icons';
import { UiModalComponentService } from '../ui-modal-component.service';
import { Subject, Subscription } from 'rxjs';
import { CdkOverlayService } from '../../services/cdk-overlay.service';
import { UiModalHeadlineVariant } from '../ui-modal.model';
import * as i0 from "@angular/core";
/**
 * Defines possible modal sizes. The 'page-size' value defines a modal that takes full width and height of the window with the maximum width of 1920px and maximum height of 2560px.
 */
export type ModalSizes = 'page-size' | 'large' | 'medium' | 'small';
/** @ignore */
export declare const MODAL_HEADLINE_ICON_MAPPING: {
    [key in UiModalHeadlineVariant]: SieIcon;
};
/**
 * # Modal component
 *
 * Present critical information to the user or to (re)assure users about a critical action.
 *
 * ## Component variations
 *
 * - Regular Modal component that contains a headline, arbitrary content and an optional footer.
 *
 * ## Content
 *
 * The component can contain child elements. With the right decorators
 * they can be used within the modal as the following:
 *
 * - `content`: Used as the content within the modal
 * - `footer`: Used as the footer within the modal
 *
 * ## Code example
 * @example ```html
 * <sie-ui-modal
 *  [headline]="'Do you want to delete this software?'"
 *  [identifier]="'modal1'"
 *  [closable]="true"
 *  [escapable]="true"
 *  screenReaderCloseIcon="Close"
 *  #myModal1
 * >
 *  <div content>
 *    <p>This is some content...</p>
 *  </div>
 *  <div footer>
 *    <ul class="footer__list">
 *      <li class="footer__list-item">
 *        <sie-ui-button variant="secondary" actionType="delete" fullWidth>Delete</sie-ui-button>
 *      </li>
 *      <li class="footer__list-item">
 *        <sie-ui-button variant="tertiary" fullWidth>Cancel</sie-ui-button>
 *      </li>
 *    </ul>
 *  </div>
 * </sie-ui-modal>
 * ```
 */
export declare class UiModalComponent extends UiBaseModalComponent implements OnInit, OnDestroy {
    readonly iconReg: SieIconRegistryService;
    protected cdkOverlayService: CdkOverlayService;
    /** @ignore */
    modalContentRef: ElementRef;
    /**
     * Defines the {@link ModalSizes size} that the modal takes
     * @default 'medium'
     */
    size: ModalSizes;
    /**
     * Headline of the modal
     */
    headline: string;
    /**
     * Icon displayed on the left of the headline
     */
    set headlineVariant(variant: UiModalHeadlineVariant);
    get headlineVariant(): UiModalHeadlineVariant;
    /**
     * Screen reader text for the close icon
     * @default '' empty string
     */
    screenReaderCloseIcon: string;
    /**
     * @param value Determines whether the modal has content inside the header
     * @default false
     */
    set hasHeaderContent(value: boolean);
    get hasHeaderContent(): boolean;
    /**
     * @param value Determines whether the modal has a footer area
     * @default true
     */
    set hasFooter(value: boolean);
    get hasFooter(): boolean;
    /**
     * @param value Defines whether the modal close button should be disabled
     * @default false
     */
    set closeButtonDisabled(value: boolean);
    get closeButtonDisabled(): boolean;
    /**
     * @param value Defines whether the modal should have the full available width
     * @default false
     */
    set fullWidth(value: boolean);
    get fullWidth(): boolean;
    /**
     * @param value Defines whether the modal should have the full available width on mobile
     * @default false
     */
    set fullScreenMobile(value: boolean);
    get fullScreenMobile(): boolean;
    /**
     * @param value Defines whether the modal should use sticky footer
     * @default false
     */
    set stickyFooter(value: boolean);
    get stickyFooter(): boolean;
    /**
     * The event that is triggered on scrolling
     */
    scrolled: Subject<number>;
    /** @ignore */
    headlineIcon: SieIcon;
    /** @ignore */
    hasShadow: boolean;
    /** @ignore */
    footerShadow: boolean;
    private _headlineVariant;
    private _fullWidth;
    private _fullScreenMobile;
    private _hasFooter;
    private _hasHeaderContent;
    private _closeButtonDisabled;
    private _stickyFooter;
    protected subscriptions: Subscription;
    private resizeObserver;
    constructor(layoutService: LayoutService, modalComponentService: UiModalComponentService, renderer: Renderer2, cdr: ChangeDetectorRef, vcr: ViewContainerRef, elRef: ElementRef, document: Document, _platformId: object, iconReg: SieIconRegistryService, cdkOverlayService: CdkOverlayService);
    /** @ignore */
    ngOnInit(): void;
    /** @ignore */
    ngOnDestroy(): void;
    /**
     * @param modalId Opens the modal instance with the selected modal id
     * @returns `NgxSmartModalComponent` the modal component
     */
    openDialog(modalId: string): NgxSmartModalComponent;
    /** @ignore */
    onScroll(): boolean;
    /** @ignore */
    setFooterShadow(): void;
    private updateFooterShadowBasedOnModalHeight;
    private createResizeObserver;
    static ɵfac: i0.ɵɵFactoryDeclaration<UiModalComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<UiModalComponent, "sie-ui-modal", never, { "size": { "alias": "size"; "required": false; }; "headline": { "alias": "headline"; "required": false; }; "headlineVariant": { "alias": "headlineVariant"; "required": false; }; "screenReaderCloseIcon": { "alias": "screenReaderCloseIcon"; "required": false; }; "hasHeaderContent": { "alias": "hasHeaderContent"; "required": false; }; "hasFooter": { "alias": "hasFooter"; "required": false; }; "closeButtonDisabled": { "alias": "closeButtonDisabled"; "required": false; }; "fullWidth": { "alias": "fullWidth"; "required": false; }; "fullScreenMobile": { "alias": "fullScreenMobile"; "required": false; }; "stickyFooter": { "alias": "stickyFooter"; "required": false; }; }, { "scrolled": "scrolled"; }, never, ["[header-content]", "[content]", "[footer]"], false, never>;
}
//# sourceMappingURL=ui-modal.component.d.ts.map