import { EventEmitter, OnChanges, OnInit, SimpleChanges } from '@angular/core';
import { SieIconRegistryService } from '@siemens/icons';
import { NgFormControlDirective } from '../ui-form-control/ui-ng-form-control.directive';
import { ValidationErrors } from '@angular/forms';
import * as i0 from "@angular/core";
/** @ignore */
export declare enum InputValidity {
    Valid = 0,
    RequiredError = 1,
    RangeError = 2,
    RangeMinError = 3,
    RangeMaxError = 4,
    StepSizeError = 5
}
/**
 * Data type for validity state changes
 */
export declare class UiNumericInputValidityChange {
    previous: boolean;
    current: boolean;
    errorMessage?: string;
    /**
     * @param previous Previous validity state (`true` = valid)
     * @param current Current validity state (`true` = valid)
     * @param [errorMessage] Error message representing current validity state
     */
    constructor(previous: boolean, current: boolean, errorMessage?: string);
}
/**
 * # Numeric Input Component
 *
 * Numeric Inputs are components that let the users choose the value they want to submit, e.g. as part of the form.
 *
 * ## Component variations
 * There are no variations
 *
 * ## Content
 *
 * The numeric input component does not accept any content.
 *
 * ## Code example
 * @example ```html
 * <sie-ui-numeric-input
 *   [min]="1"
 *   [max]="10"
 *   [value]="1"
 *   rangeErrorMessage="Invalid value. Please enter a value between <MIN_VALUE> and <MAX_VALUE>."
 *   rangeMinErrorMessage="Invalid value. Please enter a value >= <MIN_VALUE>."
 *   rangeMaxErrorMessage="Invalid value. Please enter a value between <MIN_VALUE> and <MAX_VALUE>."
 *   requiredErrorMessage="Invalid value. Please enter a value."
 *   stepSizeErrorMessage="Invalid value. Please enter a value in multiple of <STEP_SIZE>."
 *   label="Enter a number"
 * ></sie-ui-numeric-input>
 * ```
 */
export declare class UiNumericInputComponent extends NgFormControlDirective implements OnChanges, OnInit {
    readonly iconReg: SieIconRegistryService;
    /**
     * @param value Defines the current value of the component
     * @default 0 (if not provided, it will have the same value as `min`)
     */
    set value(value: number);
    get value(): number;
    /**
     * @param value Defines the maximum value of the component
     */
    set max(value: number);
    get max(): number;
    /**
     * @param min Defines the minimal value of the component
     * @default 0
     */
    set min(min: number);
    get min(): number;
    /**
     * @param step Defines the step in which the value can be increased or decreased
     * @default 1
     */
    set step(step: number);
    get step(): number;
    /**
     * @param decimal Defines if the value can be decimal (not fully implemented yet, decimal separators missing)
     * @default false
     */
    set decimal(decimal: boolean);
    get decimal(): boolean;
    /**
     * @param required Defines if the component's input is required
     * @default false
     */
    set required(required: boolean);
    get required(): boolean;
    /**
     * @param allowNegative Defines if the component allows negative numbers (not fully implemented yet)
     * @default false
     */
    set allowNegative(allowNegative: boolean);
    get allowNegative(): boolean;
    /**
     * @param suppressErrorLabel Defines if the error message for the wrong input should be shown or not
     * @default false
     */
    set suppressErrorLabel(suppressErrorLabel: boolean);
    get suppressErrorLabel(): boolean;
    /**
     * Defines the error message to be displayed if the value is not entered for the required numeric input
     */
    requiredErrorMessage: string;
    /**
     * Defines the error message to be displayed if the chosen value is out of range (won't ever be shown if the max is infinity)
     */
    rangeErrorMessage: string;
    /**
     * Defines the error message to be displayed if the chosen value is below the minimum allowed
     */
    rangeMinErrorMessage: string;
    /**
     * Defines the error message to be displayed if the chosen value is above the maximum allowed (won't ever be shown if the max is infinity)
     */
    rangeMaxErrorMessage: string;
    /**
     * Defines the error message to be displayed if the wrong step is used
     */
    stepSizeErrorMessage: string;
    /**
     * Event triggered when the value of the numeric input is changed
     */
    valueChange: EventEmitter<number>;
    /**
     * {@link UiNumericInputValidityChange Event} triggered when the value of numeric input goes from the invalid to valid value, and vice versa
     */
    validationStateChanged: EventEmitter<UiNumericInputValidityChange>;
    /** @ignore */
    get inputId(): string;
    /** @ignore */
    get isInvalid(): boolean;
    /** @ignore */
    get isEmpty(): boolean;
    /** @ignore */
    get controlsHovered(): boolean;
    /** @ignore */
    get inputFocused(): boolean;
    /** @ignore */
    get error(): string;
    /** @ignore */
    get disableArrowUp(): boolean;
    /** @ignore */
    get disableArrowDown(): boolean;
    private readonly _inputId;
    private validityState;
    private errorMessages;
    private _value;
    private _error;
    private _controlsHovered;
    private _inputFocused;
    private _min;
    private _max;
    private _step;
    private _required;
    private _decimal;
    private _allowNegative;
    private _suppressErrorLabel;
    constructor(iconReg: SieIconRegistryService);
    /** @ignore */
    ngOnChanges(changes: SimpleChanges): void;
    /** @ignore */
    ngOnInit(): void;
    /** @ignore */
    validateKeyDown(event: KeyboardEvent): boolean;
    /** @ignore */
    onModelChange(value: number): void;
    /** @ignore */
    onStepUp(event?: Event): void;
    /** @ignore */
    onStepDown(event?: Event): void;
    /** @ignore */
    onControlsHover(): void;
    /** @ignore */
    onControlsHoverEnd(): void;
    /** @ignore */
    onInputFocus(): void;
    /** @ignore */
    onInputBlur(): void;
    private populateErrorMessages;
    private validateValue;
    private emitValidityChange;
    /** @ignore */
    validateInternal(): ValidationErrors | null;
    /** @ignore */
    writeValue(value: number): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<UiNumericInputComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<UiNumericInputComponent, "sie-ui-numeric-input", never, { "value": { "alias": "value"; "required": false; }; "max": { "alias": "max"; "required": false; }; "min": { "alias": "min"; "required": false; }; "step": { "alias": "step"; "required": false; }; "decimal": { "alias": "decimal"; "required": false; }; "required": { "alias": "required"; "required": false; }; "allowNegative": { "alias": "allowNegative"; "required": false; }; "suppressErrorLabel": { "alias": "suppressErrorLabel"; "required": false; }; "requiredErrorMessage": { "alias": "requiredErrorMessage"; "required": false; }; "rangeErrorMessage": { "alias": "rangeErrorMessage"; "required": false; }; "rangeMinErrorMessage": { "alias": "rangeMinErrorMessage"; "required": false; }; "rangeMaxErrorMessage": { "alias": "rangeMaxErrorMessage"; "required": false; }; "stepSizeErrorMessage": { "alias": "stepSizeErrorMessage"; "required": false; }; }, { "valueChange": "valueChange"; "validationStateChanged": "validationStateChanged"; }, never, never, false, never>;
}
//# sourceMappingURL=ui-numeric-input.component.d.ts.map