import { ElementRef, EventEmitter, QueryList } from '@angular/core';
import { CircularArray, ElementResizeDirective } from '@siemens/core';
import { ConnectedPosition } from '@angular/cdk/overlay';
import { Observable } from 'rxjs';
import { SieIconRegistryService } from '@siemens/icons';
import { EmptyStateModel } from '../ui-empty-state/ui-empty-state.model';
import { UiPeoplePickerPerson } from './ui-people-picker.model';
import { CdkOverlayService } from '../services';
import * as i0 from "@angular/core";
import * as i1 from "@siemens/core";
/**
 * # People Picker Component
 * The people picker is used to allow selection of individuals for various processes or administrative tasks.
 *
 * ## Component variations
 *
 * The people picker component has no variations.
 *
 * ## Content
 * The people picker component does not accept any content.
 *
 * ## Code example
 * @example
 *  ```html
 * <sie-ui-people-picker
 *   label="Invite colleagues"
 *   placeholder="Name, email or company"
 *   loadingMessage="Fetching the options..."
 *   [loading]=false
 *   [emptyState]="emptyState"
 *   [people]="people"
 *   (personSelected)="onPersonSelection($event)"
 * ></sie-ui-people-picker>
 * ```
 *
 * ```ts
 * const emptyState: EmptyStateModel = {
 *   headline: 'No match found',
 *   text: "Sorry, we couldn't find any user with a matching search. Please check the search query and try again.",
 *   customIcon: SieIcon.SieportalEmptyStateJointControllerAgreementNotAllowed
 * };
 * const people: PeoplePickerPerson[] = [
 *   {
 *     id: '1',
 *     name: 'Anna Adams',
 *     initials: 'AA',
 *     email: 'anna.adams@companyname.com',
 *     company: 'Company name'
 *   },
 *   {
 *     id: '2',
 *     name: 'Herbie Hancock',
 *     initials: 'HH',
 *     email: 'herbie.hancock@companynameabc.com',
 *     company: 'Company name ABC'
 *   }
 * ];
 * ```
 */
export declare class UiPeoplePickerComponent {
    readonly elementRef: ElementRef;
    readonly resizeDirective: ElementResizeDirective;
    readonly iconRegistry: SieIconRegistryService;
    readonly cdkOverlayService: CdkOverlayService;
    /** @ignore */
    readonly id: string;
    /** @ignore */
    hasValueOrIsOverlayOpen: boolean;
    /** @ignore */
    buttons: QueryList<ElementRef<HTMLButtonElement>>;
    /** @ignore */
    input: ElementRef<HTMLInputElement>;
    /**
     * Descriptive label for the input component
     * @default undefined (=empty)
     */
    label: string;
    /**
     * Placeholder text shown in the input when user has not entered a value yet
     * @default ''
     */
    placeholder: string;
    /**
     * {@link EmptyStateModel Configuration} of empty state which will be displayed when no results are found/matched
     */
    emptyState: EmptyStateModel;
    /**
     * Displays loading state of people picker options if set to true
     * @default false
     */
    loading: boolean;
    /**
     * Defines the message shown when component is loading (e.g. fetching data from the API)
     */
    loadingMessage: string;
    /**
     * Defines whether filtering by name is possible
     * @default true
     */
    set filterByName(value: boolean);
    get filterByName(): boolean;
    /**
     * Defines whether filtering by email is possible
     * @default true
     */
    set filterByEmail(value: boolean);
    get filterByEmail(): boolean;
    /**
     * Defines whether filtering by company name is possible
     * @default true
     */
    set filterByCompany(value: boolean);
    get filterByCompany(): boolean;
    /**
     * List of {@link UiPeoplePickerPerson possible items (persons)} to filter and select from
     * @default []
     */
    set people(value: UiPeoplePickerPerson[]);
    get people(): UiPeoplePickerPerson[];
    /**
     * Sets disabled state of people picker component
     * @default false
     */
    set disabled(value: boolean);
    get disabled(): boolean;
    /**
     * {@link UiPeoplePickerPerson Event} is triggered when an item (person) is selected by the user
     */
    personSelected: EventEmitter<UiPeoplePickerPerson>;
    /**
     * Event triggered when the people picker overlay is opened
     */
    overlayOpened: EventEmitter<void>;
    /**
     * Event triggered when the people picker input value is changed
     */
    inputValueChanged: EventEmitter<string>;
    /**
     * Event triggered when the people picker empty state action button is clicked
     */
    emptyStateButtonClicked: EventEmitter<void>;
    /**
     * Defines whether overlay is currently opened
     */
    set overlayOpen(value: boolean);
    get overlayOpen(): boolean;
    private _overlayOpen;
    /**
     * Specifies the currently entered input text
     */
    set inputText(value: string);
    get inputText(): string;
    private readonly people$;
    private readonly inputText$;
    /** @ignore */
    positions: ConnectedPosition[];
    /** @ignore */
    readonly filteredPeople$: Observable<UiPeoplePickerPerson[]>;
    /** @ignore */
    readonly selectionArray: CircularArray<unknown>;
    private _filterByName;
    private _filterByEmail;
    private _filterByCompany;
    private _disabled;
    constructor(elementRef: ElementRef, resizeDirective: ElementResizeDirective, iconRegistry: SieIconRegistryService, cdkOverlayService: CdkOverlayService);
    /** @ignore */
    selectPerson(person: UiPeoplePickerPerson): void;
    /** @ignore */
    backdropClicked(): void;
    /** @ignore */
    openOverlay(): void;
    /** @ignore */
    closeOverlay(): void;
    /** @ignore */
    onInputFocused(): void;
    /** @ignore */
    handleKey(e: KeyboardEvent): void;
    private focusElement;
    private sortOptions;
    private getFilterKeys;
    static ɵfac: i0.ɵɵFactoryDeclaration<UiPeoplePickerComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<UiPeoplePickerComponent, "sie-ui-people-picker", never, { "label": { "alias": "label"; "required": false; }; "placeholder": { "alias": "placeholder"; "required": false; }; "emptyState": { "alias": "emptyState"; "required": false; }; "loading": { "alias": "loading"; "required": false; }; "loadingMessage": { "alias": "loadingMessage"; "required": false; }; "filterByName": { "alias": "filterByName"; "required": false; }; "filterByEmail": { "alias": "filterByEmail"; "required": false; }; "filterByCompany": { "alias": "filterByCompany"; "required": false; }; "people": { "alias": "people"; "required": false; }; "disabled": { "alias": "disabled"; "required": false; }; }, { "personSelected": "personSelected"; "overlayOpened": "overlayOpened"; "inputValueChanged": "inputValueChanged"; "emptyStateButtonClicked": "emptyStateButtonClicked"; }, never, never, false, [{ directive: typeof i1.ElementResizeDirective; inputs: {}; outputs: {}; }]>;
}
//# sourceMappingURL=ui-people-picker.component.d.ts.map