import { EventEmitter } from '@angular/core';
import { UiPictureModel } from './ui-picture.model';
import { ImageContext, ImageRatio, ImageSize } from './ui-picture.types';
import { ThemeVariant } from '@siemens/core';
import { SieIconRegistryService } from '@siemens/icons';
import * as i0 from "@angular/core";
/**
 * # Picture Component
 * Images are used as a part of a content item’s representation (functional), e.g. showing product images, diagrams etc.
 * or part of the brand expression (emotional), e.g. showing mood images.
 *
 * ## Component variations
 *
 * - With caption
 * - Without caption
 *
 * ## Content
 * The picture component does not accept any content.
 *
 * ## Code example
 * @example
 *  ```html
 * <sie-ui-picture
 *  ratio="16-9"
 *  [model]="pictureData"
 *  [context]="'services'"
 *  [shouldHaveOutline]="false"
 * ></sie-ui-picture>
 * ```
 *
 * ```ts
 * const pictureData = {
 *  urlSmall:'https://test-image/width:640/quality:low/Energy-Manager-MindSphere-App-v2.tif',
 *  urlMedium:'https://test-image/width:1280/quality:medium/Energy-Manager-MindSphere-App-v2.tif',
 *  urlLarge:'https://test-image/width:1920/quality:high/Energy-Manager-MindSphere-App-v2.tif',
 *  altText: 'In case the image does not load..',
 *  mode: 'cover',
 *  caption:'Lorem ipsum dolor sit amet, consetetur sadipscing elitra.'
 * };
 * ```
 */
export declare class UiPictureComponent {
    readonly iconReg: SieIconRegistryService;
    /**
     * Defines {@link UiPictureModel Model} of the picture to display
     */
    model: UiPictureModel;
    /**
     * Defines {@link ImageSize Size} of the picture to display
     */
    size?: ImageSize;
    /**
     * Defines {@link ImageRatio Ratio} of the picture to display
     */
    ratio?: ImageRatio;
    /**
     * Sets the text to display when the picture is not loaded
     */
    notLoadedLabel?: string;
    /**
     * Background {@link ThemeVariant Theme} of the partial where this picture component is used
     * @default 'light'
     */
    theme: ThemeVariant;
    get context(): ImageContext;
    /**
     * @param context {@link ImageContext Context} sets the correct icon to display when the picture is not loaded
     */
    set context(context: ImageContext);
    /**
     * @param value whether the picture have a visible caption or not
     * @default false
     */
    set caption(value: boolean);
    get caption(): boolean;
    /**
     * @param value sets outline on the fallback picture
     * @default false
     */
    set shouldHaveOutline(value: boolean);
    get shouldHaveOutline(): boolean;
    /**
     * Event triggered when image fails to load
     */
    failedToLoadImg: EventEmitter<boolean>;
    /** @ignore */
    Breakpoints: {
        XS: string;
        S: string;
        M: string;
        L: string;
        XL: string;
        XXL: string;
    };
    /** @ignore */
    failedToLoad: boolean;
    /** @ignore */
    placeholderImage: string;
    private _context;
    private _caption;
    private _shouldHaveOutline;
    private readonly contextPlaceholder;
    constructor(iconReg: SieIconRegistryService);
    /** @ignore */
    onLoadError(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<UiPictureComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<UiPictureComponent, "sie-ui-picture", never, { "model": { "alias": "model"; "required": false; }; "size": { "alias": "size"; "required": false; }; "ratio": { "alias": "ratio"; "required": false; }; "notLoadedLabel": { "alias": "notLoadedLabel"; "required": false; }; "theme": { "alias": "theme"; "required": false; }; "context": { "alias": "context"; "required": false; }; "caption": { "alias": "caption"; "required": false; }; "shouldHaveOutline": { "alias": "shouldHaveOutline"; "required": false; }; }, { "failedToLoadImg": "failedToLoadImg"; }, never, never, false, never>;
}
//# sourceMappingURL=ui-picture.component.d.ts.map