import { ElementRef, OnInit, OnDestroy, ChangeDetectorRef, TemplateRef } from '@angular/core';
import { Subject } from 'rxjs';
import { PopoverPlacement, PopoverSize } from './ui-popover.types';
import { AnimationEvent } from '@angular/animations';
import * as i0 from "@angular/core";
/**
 * # Popover Component
 *
 * Popover support users in understanding specific elements within a page on a detailed level.
 *
 * ## Component variations
 *
 * The popover component has no variations.
 *
 * ## Content
 *
 * The popover component is able to take any content by using `sieUiPopover` directive.
 *
 * ## Code example
 * @example
 *  ```html
 * <button sieUiPopover content="Please provide your feedback here!" popoverSize="l" popoverLightTheme="true">
 *   Tooltip white
 * </button>
 *
 * <button sieUiPopover popoverSize="s" [popoverTemplate]="popoverTemplate">Tooltip</button>
 * <ng-template #popoverTemplate>
 *   <p>
 *     Lorem ipsum dolor sit ame consetetur sadipscing elit, sed diam nonumy eirmod tempor invidunt ut labore et
 *     <sie-ui-link href="https://www.siemens.com" target="_blank" variant="inline">Click me!</sie-ui-link> dolore
 *     magna aliquyam.
 *   </p>
 *   <sie-ui-picture [model]="pictureItem"></sie-ui-picture>
 * </ng-template>
 * ```
 *
 * ```ts
 * pictureItem: UiPictureModel = {
 *   urlSmall:
 *    'https://assets.new.siemens.com/siemens/assets/api/uuid:b74b4f94-fe72-4745-9ace-ccd68ea46831/width:1920/quality:HIGH/IM2018110010PD_LAY02.jpg',
 *   urlMedium:
 *    'https://assets.new.siemens.com/siemens/assets/api/uuid:b74b4f94-fe72-4745-9ace-ccd68ea46831/width:1280/quality:MEDIUM/IM2018110010PD_LAY02.jpg',
 *   urlLarge:
 *    'https://assets.new.siemens.com/siemens/assets/api/uuid:b74b4f94-fe72-4745-9ace-ccd68ea46831/width:640/quality:LOW/IM2018110010PD_LAY02.jpg',
 *   altText: 'Alternative text',
 *   mode: 'cover',
 *   caption: 'Lorem ipsum dolor sit amet'
 * };
 * ```
 */
export declare class UiPopoverComponent implements OnInit, OnDestroy {
    private readonly el;
    private readonly cdr;
    /**
     * Content that is displayed in richtext within the popover
     */
    set content(value: string);
    get content(): string;
    /**
     * Content of the template that is displayed in the popover
     */
    popoverTemplate: TemplateRef<unknown>;
    /** @ignore */
    host: HTMLElement;
    /**
     * Defines {@link PopoverSize size} of the popover
     * @default 'l'
     */
    size: PopoverSize;
    /**
     * Defines {@link PopoverPlacement placement} of the popover
     * @default 'top'
     */
    placement: PopoverPlacement;
    /**
     * Defines if popover has animation
     * @default false
     */
    animation: boolean;
    /**
     * Defines the timeout when the animation will hide the popover if it is active
     * @default 3000
     */
    animationHideAfterTimeoutMS: number;
    /**
     * Defines if the animation of the popover is active
     */
    playAnimation: Subject<boolean>;
    /**
     * Defines if the theme of the popover is light
     * @default false
     */
    lightTheme: boolean;
    /**
     * Emitted when component is hovered
     * @default true
     */
    isHovered: Subject<boolean>;
    /**
     * Emitted when animation is done
     * @default false
     */
    isAnimationDone: Subject<boolean>;
    private _content;
    private popper;
    private popoverAnimationState;
    constructor(el: ElementRef, cdr: ChangeDetectorRef);
    /** @ignore */
    get animationState(): string;
    /** @ignore */
    ngOnInit(): void;
    /** @ignore */
    ngOnDestroy(): void;
    onMouseEnter(): void;
    onMouseLeave(): void;
    private initializePopper;
    private triggerPopoverAnimation;
    /** @ignore */
    onAnimationDone(animationChanged: AnimationEvent): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<UiPopoverComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<UiPopoverComponent, "sie-ui-popover", never, { "content": { "alias": "content"; "required": false; }; "popoverTemplate": { "alias": "popoverTemplate"; "required": false; }; "host": { "alias": "host"; "required": false; }; "size": { "alias": "size"; "required": false; }; "placement": { "alias": "placement"; "required": false; }; "animation": { "alias": "animation"; "required": false; }; "animationHideAfterTimeoutMS": { "alias": "animationHideAfterTimeoutMS"; "required": false; }; "playAnimation": { "alias": "playAnimation"; "required": false; }; "lightTheme": { "alias": "lightTheme"; "required": false; }; }, { "isHovered": "isHovered"; "isAnimationDone": "isAnimationDone"; }, never, never, false, never>;
}
//# sourceMappingURL=ui-popover.component.d.ts.map