import { UiTextInputComponent } from '../../ui-input/ui-text-input/ui-text-input.component';
import { ChangeDetectorRef, ElementRef, OnChanges, SimpleChanges } from '@angular/core';
import { SieIconRegistryService } from '@siemens/icons';
import { UiComboboxOption } from './ui-combobox.types';
import { Subject } from 'rxjs';
import { UiDropdownBaseDirective } from '../../ui-dropdown/base/ui-dropdown.base.directive';
import { UiEventPropagationService } from '../../services/ui-event-propagation.service';
import { Autocomplete } from '../../ui-input/ui-input-base.directive';
import { CdkOverlayService } from '../../services/cdk-overlay.service';
import { ConnectedPosition } from '@angular/cdk/overlay';
import * as i0 from "@angular/core";
/**
 * # Combobox component
 *
 * Combobox allows user to search and select a value from given set of options or add a value not offered in the options.
 *
 * ## Component variations
 *
 * There are no variations
 *
 * ## Content
 *
 * The Combobox component does not accept any content.
 *
 * ## Code example
 * @example
 * Template:
 * ```html
 * <sie-ui-combobox
 *   label="City"
 *   placeholder="Select city"
 *   autocomplete="off"
 *   [options]="comboboxSuggestions"
 *   [noResultsMessageTitle]="'No results title'"
 *   [noResultsMessageCopy]="'No results message copy'"
 *   [emptyStateMessageTitle]="'Empty state message title'"
 *   [emptyStateMessageCopy]="'Empty state message copy'"
 *   [invalidErrorMessage]="'Invalid error message'"
 *   [patternValidationErrorMessage]="'Component accepts alphanumeric characters and spaces'"
 *   [requiredErrorMessage]="'Field is required'"
 *   [loadingMessage]="'Combobox loading message'"
 *   [loading]="true"
 *   [clearSearchScreenReaderText]="'Clear search screen reader text'"
 *   [addCustomValueCopy]="'Add custom value'"
 *   (inputValueChanged)="onInputValueChanged($event)"
 * ></sie-ui-combobox>
 * ```
 *
 * Data example:
 * ``` js
 * const comboboxSuggestions = [
 *   {
 *     label: 'Kabul',
 *     value: 'Kabul',
 *     metaInformation: 'Capital city of Afghanistan'
 *   },
 *   {
 *     label: 'Mariehamn',
 *     value: 'Mariehamn',
 *     metaInformation: 'Meta information that gets truncated after one line when it reaches maximum width'
 *   },
 *   {
 *     label: 'Tirana',
 *     value: 'Tirana'
 *   }
 * ];
 * ```
 */
export declare class UiComboboxComponent extends UiDropdownBaseDirective<UiComboboxOption, UiTextInputComponent> implements OnChanges {
    readonly iconReg: SieIconRegistryService;
    protected readonly cdr: ChangeDetectorRef;
    protected readonly elementRef: ElementRef;
    readonly eventPropagationService: UiEventPropagationService;
    protected readonly cdkOverlayService: CdkOverlayService;
    /**
     * Defines the id of the combobox
     */
    id: string;
    /**
     * Defines the placeholder value of the component
     * @default '' (empty string)
     */
    placeholder: string;
    /**
     * Defines the value of the component
     * @default null
     */
    value: string;
    /**
     * Defines the title of the message shown when no results for input are found (when {@link addCustomValue} is `false`)
     * @default '' (empty string)
     */
    noResultsMessageTitle: string;
    /**
     * Defines the text of the message shown when no results for input are found (when {@link addCustomValue} is `false`)
     * @default '' (empty string)
     */
    noResultsMessageCopy: string;
    /**
     * Defines the title of the message shown in the empty state (e.g. when API fails to fetch suggestions data)
     * @default '' (empty string)
     */
    emptyStateMessageTitle: string;
    /**
     * Defines the copy of the message shown in the empty state (e.g. when API fails to fetch suggestions data)
     * @default '' (empty string)
     */
    emptyStateMessageCopy: string;
    /**
     * Defines the text used by screen readers for the clear search icon
     * @default '' (empty string)
     */
    clearSearchScreenReaderText: string;
    /**
     * Defines the text shown under the input value when 'Add option trigger' is used ({@link addCustomValue} is `true`)
     * @default '' (empty string)
     */
    addCustomValueCopy: string;
    /**
     * Defines the label of the component
     */
    label: string;
    /**
     * Defines the message shown when component is loading (e.g. fetching data from the API)
     */
    loadingMessage: string;
    /**
     * Defines the error message shown under the component when wrong characters are typed in the component
     */
    patternValidationErrorMessage: string;
    /**
     * Defines the error message shown under the component when component is in invalid state
     */
    invalidErrorMessage: string;
    /**
     * Defines the error message shown under the component when component is empty and is in `required`
     */
    requiredErrorMessage: string;
    /**
     * Defines the {@link Autocomplete autocomplete attribute}
     */
    autocomplete: Autocomplete;
    /**
     * Defines which regex should be used for combo box validation
     * @default null
     */
    validationPattern: any;
    /**
     * Defines the {@link UiComboboxOption options} (suggestions) shown in the overlay of the component
     */
    set options(value: UiComboboxOption[]);
    get options(): UiComboboxOption[];
    /**
     * Defines whether component should use 'Add option trigger' mode
     * @default false
     */
    set addCustomValue(value: boolean);
    get addCustomValue(): boolean;
    /**
     * Defines whether the loading state of the component should be shown
     * @default false
     */
    set loading(value: boolean);
    get loading(): boolean;
    /**
     * Defines whether the error state of the component should be shown
     * @default false
     */
    set error(value: boolean);
    get error(): boolean;
    /**
     * Defines whether the invalid state of the component should be shown
     */
    set invalid(value: boolean);
    get invalid(): boolean;
    /**
     * Defines whether the required state of the component should be shown
     */
    set required(value: boolean);
    get required(): boolean;
    /**
     * @param selectedValue Defines which option of the component is selected by default (controlled through `value` set in `options` input)
     */
    set selectedValue(selectedValue: string);
    /**
     * Defines whether the disabled state of the component should be shown
     * @default false
     */
    set disabled(value: boolean);
    get disabled(): boolean;
    /** @ignore */
    set focused(value: boolean);
    get focused(): boolean;
    /**
     * Event triggered when the option from the options list is selected
     * The event data is the {@link UiComboboxOption option} itself
     */
    optionSelected: Subject<UiComboboxOption>;
    /**
     * Event triggered when the value of the input field has been changed
     * The event data is the `value` attribute of the selected {@link UiComboboxOption option}
     */
    inputValueChanged: Subject<string>;
    customOption: UiComboboxOption;
    selectedItem: UiComboboxOption;
    highlightedItem: UiComboboxOption;
    protected _options: UiComboboxOption[];
    protected _disabled: boolean;
    protected positions: ConnectedPosition[];
    protected originalOptions: UiComboboxOption[];
    private readonly optionsCircularArray;
    private _invalid;
    private _required;
    private _addCustomValue;
    private _loading;
    private _error;
    private _focused;
    private _itemFocused;
    private _selectedValue;
    /** @ignore */
    leftAligned: boolean;
    /** @ignore */
    hover: boolean;
    constructor(iconReg: SieIconRegistryService, cdr: ChangeDetectorRef, elementRef: ElementRef, eventPropagationService: UiEventPropagationService, cdkOverlayService: CdkOverlayService);
    /** @ignore */
    ngOnChanges(changes: SimpleChanges): void;
    /** @ignore */
    onValueChange(value: string): void;
    /** @ignore */
    onInputKeyEnter(): void;
    /** @ignore */
    onInputKeyTab(): void;
    /** @ignore */
    onInputClick(): void;
    /** @ignore */
    onInputFocus(): void;
    /** @ignore */
    onInputArrowDown(event: KeyboardEvent): void;
    /** @ignore */
    onInputEscape(): void;
    /** @ignore */
    onResetButtonClicked(): void;
    /** @ignore */
    onOverlayArrowHandler(e: KeyboardEvent): void;
    /** @ignore */
    onOverlayKeyTab(): void;
    /** @ignore */
    onOverlayKeyEnter(e: Event, item: UiComboboxOption): void;
    /** @ignore */
    onOverlayKeyEscape(): void;
    /** @ignore */
    onOverlayClick(item: UiComboboxOption): void;
    /** @ignore */
    onOverlayMouseOver(index: number): void;
    /** @ignore */
    onOverlayMouseOut(): void;
    /** @ignore */
    focusOut(backdropClicked?: boolean): void;
    /** @ignore */
    closeOverlay(): void;
    /** @ignore */
    openOverlay(): void;
    /** @ignore */
    itemSelected(selectedItem: UiComboboxOption): void;
    /** @ignore */
    focusElement(index: number): void;
    /** @ignore */
    onArrowIconClicked(e: Event): void;
    /**
     * @ignore
     * This method is used and overridden in the UiSupportSearchComboboxComponent,
     * which uses template and styling from this component
     * */
    onArrowIconMouseDown(_e: Event): void;
    protected selectValueAndValidate(): void;
    private validateValue;
    protected validate(): boolean;
    private highlightItem;
    private highlightSuggestion;
    private unHighlightSuggestion;
    protected determineHorizontalMenuAlignment(): void;
    protected focusInputField(): void;
    protected updateDisplayedOptions(): void;
    private getCustomOption;
    protected sortOptions(a: UiComboboxOption, b: UiComboboxOption): number;
    protected filterOptions(): UiComboboxOption[];
    static ɵfac: i0.ɵɵFactoryDeclaration<UiComboboxComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<UiComboboxComponent, "sie-ui-combobox", never, { "id": { "alias": "id"; "required": false; }; "placeholder": { "alias": "placeholder"; "required": false; }; "value": { "alias": "value"; "required": false; }; "noResultsMessageTitle": { "alias": "noResultsMessageTitle"; "required": false; }; "noResultsMessageCopy": { "alias": "noResultsMessageCopy"; "required": false; }; "emptyStateMessageTitle": { "alias": "emptyStateMessageTitle"; "required": false; }; "emptyStateMessageCopy": { "alias": "emptyStateMessageCopy"; "required": false; }; "clearSearchScreenReaderText": { "alias": "clearSearchScreenReaderText"; "required": false; }; "addCustomValueCopy": { "alias": "addCustomValueCopy"; "required": false; }; "label": { "alias": "label"; "required": false; }; "loadingMessage": { "alias": "loadingMessage"; "required": false; }; "patternValidationErrorMessage": { "alias": "patternValidationErrorMessage"; "required": false; }; "invalidErrorMessage": { "alias": "invalidErrorMessage"; "required": false; }; "requiredErrorMessage": { "alias": "requiredErrorMessage"; "required": false; }; "autocomplete": { "alias": "autocomplete"; "required": false; }; "validationPattern": { "alias": "validationPattern"; "required": false; }; "options": { "alias": "options"; "required": false; }; "addCustomValue": { "alias": "addCustomValue"; "required": false; }; "loading": { "alias": "loading"; "required": false; }; "error": { "alias": "error"; "required": false; }; "invalid": { "alias": "invalid"; "required": false; }; "required": { "alias": "required"; "required": false; }; "selectedValue": { "alias": "selectedValue"; "required": false; }; "disabled": { "alias": "disabled"; "required": false; }; }, { "optionSelected": "optionSelected"; "inputValueChanged": "inputValueChanged"; }, never, never, false, never>;
}
//# sourceMappingURL=ui-combobox.component.d.ts.map