import { UiCellAlignment, UiTableCellModel, UiTableModel } from '../ui-table.model';
/**
 * Options for the table builder
 */
export interface UiTableBuilderOptions {
    width?: string;
    height?: string;
    caption?: string;
}
/**
 * Class to create new UiTableBuilder object using the {@link UiTableBuilderOptions}
 *
 * @example
 * ```ts
 * const generateTableWithBuilder = () => {
 *   const options: UiTableBuilderOptions = {
 *     width: '100%',
 *     height: '300px',
 *     caption: 'table caption'
 *   };
 *
 *   const builder = new UiTableBuilder(options);
 *
 *   const cells: UiTableCellModel[] = [
 *     {
 *       value: 'Cell one',
 *       alignment: 'center'
 *     },
 *     {
 *       value: 'Cell two',
 *       alignment: 'center'
 *     }
 *   ];
 *
 *   // Adds tbody ID = 0 to table
 *   builder.addRow(cells);
 *
 *   // Adds new tbody with ID = 1 to table
 *   builder.addRow(cells, '1');
 *
 *   // Adds new row to tbody with ID = 0
 *   builder.addRow([{ value: 'tbody1', alignment: 'left' }]);
 *
 *   // Adds new row to tbody with ID = 1
 *   builder.addRow([{ value: 'tbody2', alignment: 'left' }], '1');
 *
 *   builder.setFooter(cells);
 *
 *   return builder.toModel();
 * };
 * ```
 */
export declare class UiTableBuilder {
    width: string;
    height: string;
    caption?: string;
    tHead?: UiTableSection;
    tBodies: UiTableSection[];
    tFoot?: UiTableSection;
    constructor(options?: UiTableBuilderOptions);
    /**
     * Method to add a row to table section
     * @param [cells=[]] cells of rows
     * @param [bodyId=0] ID of table body
     */
    addRow(cells?: (UiTableCellModel | string)[], bodyId?: string): void;
    /**
     * Method to add new table body
     * @param id table body ID
     * @returns new table body
     */
    addBody(id: string): UiTableSection;
    /**
     * Method to set a table footer
     * @param [cells=[]] cells displayed in the table footer
     */
    setFooter(cells?: (UiTableCellModel | string)[]): void;
    /**
     * @returns Builds {@link UiTableModel table model}
     */
    toModel(): UiTableModel;
    private getBody;
    private getOrCreateBody;
    private getOrCreateFooter;
}
/**
 * Class to create table section object
 */
export declare class UiTableSection {
    get id(): string;
    readonly _id: string;
    rows: UiTableRow[];
    constructor(id: string);
    /**
     * Method that adds a new row to the rows array of the table section
     * @param [cells=[]] cells of the row
     */
    addRow(cells?: (UiTableCellModel | string)[]): void;
}
/**
 * Class to create table row object
 */
export declare class UiTableRow {
    cells: UiTableCell[];
    _columns: number;
    constructor(cells?: (UiTableCellModel | string)[]);
}
/**
 * Class to create table cell object
 */
export declare class UiTableCell {
    colspan?: number;
    rowspan?: number;
    truncate?: boolean;
    value: string;
    alignment: UiCellAlignment;
    width?: string;
    height?: string;
    constructor(cell: UiTableCellModel);
}
//# sourceMappingURL=ui-table-builder.d.ts.map