import { AfterViewInit, ChangeDetectorRef, ElementRef, EventEmitter, QueryList } from '@angular/core';
import { TabsControlConfig, TabsControlsType } from '../tabs-controls/ui-tabs-controls.types';
import { UiTabDirective } from './ui-tab.directive';
import { UiTabItem } from './ui-tabs-types';
import { UiTabsContainerComponentService } from './ui-tabs-container.component.service';
import { ThemeVariant } from '@siemens/core';
import { UiTabsControlsComponent } from '../tabs-controls/ui-tabs-controls.component';
import * as i0 from "@angular/core";
/**
 * # Tabs Container Component
 *
 * Provide direct access to contents of a category.
 * Use tabs when there are multiple items of equal importance available.
 *
 * ## Component variations
 *
 * - contained tabs
 * - uncontained tabs
 *
 * ## Content
 *
 * The content of tabs can be passed as child elements with using `sieUiTab`.
 * See the example below.
 *
 * ## Code example
 * @example
 * Template:
 * ```html
 * <sie-ui-tabs-container [tabs]="tabs" type="contained" theme="dark">
 *  <ng-template sieUiTab> Item 1</ng-template>
 *  <ng-template sieUiTab> Item 2</ng-template>
 *  <ng-template sieUiTab> Item 3</ng-template>
 *  <ng-template sieUiTab> Item 4</ng-template>
 * </sie-ui-tabs-container>
 * ```
 *
 * Tabs container data example:
 * ```js
 * tabs: TabsControlConfig = [
 *  {
 *    title: 'Any valid HTML',
 *    badge: {
 *      type: 'counter',
 *      status: 'error',
 *      mode: 'light',
 *      number: 1
 *    },
 *    icon: {
 *      name: 'InformationFilled',
 *      color: '#FF9000',
 *    },
 *    count: 99
 *  },
 *  {
 *    title: 'Any valid HTML',
 *    badge: {
 *      type: 'dot',
 *      status: 'warning',
 *      mode: 'light'
 *    },
 *    count: 1000
 *  },
 *  {
 *    title: 'Any valid HTML'
 *  }
 * ];
 * ```
 */
export declare class UiTabsContainerComponent implements AfterViewInit {
    protected cdr: ChangeDetectorRef;
    private readonly uiTabsContainerComponentService;
    /** @ignore */
    tabContents: QueryList<UiTabDirective> | UiTabItem[];
    /** @ignore */
    elementsRef: ElementRef;
    /**
     * @param value {@link TabsControlConfig Config} Defines data of tabs that will be displayed in tabs controls.
     */
    set tabs(value: TabsControlConfig[]);
    get tabs(): TabsControlConfig[];
    /**
     * @param value Defines which tab should be selected by default.
     * @default 0
     */
    set selectedItemIndex(value: number);
    get selectedItemIndex(): number;
    /**
     * Defines {@link TabsControlsType Type} which tab style should be used
     * @default 'un-contained'
     */
    type: TabsControlsType;
    /**
     * Defines {@link ThemeVariant Variant} theme of the tabs
     * @default 'light'
     */
    theme: ThemeVariant;
    /**
     * Defines background color for overflow in tabs controls.
     * Value has to be delivered as rgb list.
     */
    backgroundColor: string;
    /**
     * Event triggered when a different tab item is selected.
     */
    selectedItemIndexChange: EventEmitter<number>;
    private _tabs;
    private _selectedItemIndex;
    constructor(cdr: ChangeDetectorRef, uiTabsContainerComponentService: UiTabsContainerComponentService<unknown, UiTabsContainerComponent, UiTabsControlsComponent>);
    /** @ignore */
    ngAfterViewInit(): void;
    /**
     * @param index Selects the tab.
     */
    selectTab(index: number): void;
    /** @ignore */
    selectedItemChanged(index: number): void;
    /**
     * Updates the view by calling the change detection.
     */
    /** @ignore */
    updateView(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<UiTabsContainerComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<UiTabsContainerComponent, "sie-ui-tabs-container", never, { "tabs": { "alias": "tabs"; "required": false; }; "selectedItemIndex": { "alias": "selectedItemIndex"; "required": false; }; "type": { "alias": "type"; "required": false; }; "theme": { "alias": "theme"; "required": false; }; "backgroundColor": { "alias": "backgroundColor"; "required": false; }; }, { "selectedItemIndexChange": "selectedItemIndexChange"; }, ["tabContents"], [".tabs-item"], false, never>;
}
//# sourceMappingURL=ui-tabs-container.component.d.ts.map