import { AfterViewInit, ChangeDetectorRef, ElementRef, EventEmitter, OnDestroy, OnInit, QueryList } from '@angular/core';
import { LayoutService, PanEvent, SelectableItems, SelectableWithUnderlineDirective, ThemeVariant } from '@siemens/core';
import { SieIconRegistryService } from '@siemens/icons';
import { TabsControlConfig, TabsControlsAlignment, TabsControlsType } from './ui-tabs-controls.types';
import * as i0 from "@angular/core";
/**
 * # Tabs Controls Component
 *
 * The tabs controls represent the controls of the tabs component
 *
 * ## Component variations
 *
 * - contained tabs
 * - uncontained tabs
 *
 * ## Content
 *
 * The tabs controls component does not accept any content.
 *
 * ## Code example
 * @example
 * Template:
 * ```html
 * <sie-ui-tabs-controls [tabs]="tabs" [backgroundColor]="'235, 240, 245'"></sie-ui-tabs-controls>
 * ```
 *
 * Tabs controls data example:
 * ```js
 * tabs: TabsControlConfig = [
 *  {
 *    title: 'product',
 *    badge: {
 *      type: 'counter',
 *      status: 'error',
 *      mode: 'light',
 *      number: 9
 *    },
 *    count: 99,
 *    icon: {
 *      name: 'InformationFilled',
 *      color: '#FF9000'
 *    }
 *  },
 *  {
 *    title: 'service',
 *    badge: {
 *      type: 'counter',
 *      status: 'error',
 *      mode: 'light',
 *      number: 99
 *    }
 *  }
 * ];
 * ```
 */
export declare class UiTabsControlsComponent extends SelectableWithUnderlineDirective implements OnInit, OnDestroy, SelectableItems, AfterViewInit {
    layoutService: LayoutService;
    readonly iconReg: SieIconRegistryService;
    readonly cd: ChangeDetectorRef;
    /** @ignore */
    containerElement: ElementRef;
    /** @ignore */
    tabContainerElement: ElementRef;
    /** @ignore */
    tabListContainerElement: ElementRef;
    /** @ignore */
    selectableItems: QueryList<ElementRef>;
    /**
     * Defines background color for overflow in tabs controls.
     * Value has to be delivered as rgb list.
     */
    backgroundColor: string;
    /**
     * @param value Defines which tab should be selected by default. If the value is set to `-1`, no item is selected by default.
     * @default 0
     */
    set selectedItemIndex(value: number);
    /**
     * @param value Defines if the horizontal line on the tabs controls should be extended.
     * @default false
     */
    set afterLine(value: boolean);
    get afterLine(): boolean;
    /**
     * @param tabs {@link TabsControlConfig Config} Defines data of tabs that will be displayed in tabs controls.
     */
    set tabs(tabs: TabsControlConfig[]);
    get tabs(): TabsControlConfig[];
    /**
     * Defines {@link TabsControlsType Type} which tab style should be used.
     * @default 'un-contained'
     */
    type: TabsControlsType;
    /**
     * Defines {@link ThemeVariant Variant} theme of the tabs controls.
     * @default 'light'
     */
    theme: ThemeVariant;
    /**
     * Defines {@link TabsControlsAlignment Alignment} how tabs controls should be aligned.
     * @default 'left'
     */
    align: TabsControlsAlignment;
    /**
     * Defines which text should be used by screen readers when small screen navigate left button is used.
     * @default ''
     */
    navigateLeftScreenReaderText: string;
    /**
     * Defines which text should be used by screen readers when small screen navigate right button is used.
     * @default ''
     */
    navigateRightScreenReaderText: string;
    /**
     * Event triggered when a different tab item is selected.
     */
    selectionChanged: EventEmitter<number>;
    /**
     * Event triggered when a different tab item is selected.
     */
    selectedItemIndexChange: EventEmitter<number>;
    /**
     * Event triggered when a tab item is clicked.
     */
    tabClicked: EventEmitter<number>;
    /** @ignore */
    currentTranslateX: number;
    /** @ignore */
    wrapperStyle: {
        transform: string;
    };
    /** @ignore */
    panStarted: boolean;
    /** @ignore */
    showLeft: boolean;
    /** @ignore */
    showRight: boolean;
    readonly countLimit = 1000;
    readonly countExceededPlaceholder = "999+";
    private itemWidths;
    private itemsTotalWidth;
    private readonly subscriptions;
    private _selectedItemIndex;
    private _afterLine;
    private _tabs;
    private initialized;
    constructor(layoutService: LayoutService, iconReg: SieIconRegistryService, cd: ChangeDetectorRef);
    /** @ignore */
    ngOnInit(): void;
    /** @ignore */
    ngAfterViewInit(): void;
    /** @ignore */
    ngOnDestroy(): void;
    /** @ignore */
    activeItemChanged(): void;
    itemClicked(index: number, event?: Event): void;
    /** @ignore */
    positionToLeft(): void;
    /** @ignore */
    positionToRight(): void;
    /** @ignore */
    onPanStart(): void;
    /** @ignore */
    onPan(event: PanEvent): void;
    /** @ignore */
    onPanEnd(event: PanEvent): void;
    onBlur(): void;
    /** @ignore */
    bringIntoView(index: number): void;
    /** @ignore */
    blockScroll(): void;
    /** @ignore */
    tabTextTransitionEnd(): void;
    /** @ignore */
    calculateItemWidths(): void;
    /** @ignore */
    _resetUnderline(): void;
    private setDefaultBackground;
    private emitSelectionChange;
    private renderListItems;
    private setContainedItemWidth;
    private positionControls;
    private getContainerWidth;
    private getTabContainerWidth;
    private getNewTranslate;
    private subscribeToScreenResize;
    private getGradientOffset;
    private calculateItemMargin;
    static ɵfac: i0.ɵɵFactoryDeclaration<UiTabsControlsComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<UiTabsControlsComponent, "sie-ui-tabs-controls", never, { "backgroundColor": { "alias": "backgroundColor"; "required": false; }; "selectedItemIndex": { "alias": "selectedItemIndex"; "required": false; }; "afterLine": { "alias": "afterLine"; "required": false; }; "tabs": { "alias": "tabs"; "required": false; }; "type": { "alias": "type"; "required": false; }; "theme": { "alias": "theme"; "required": false; }; "align": { "alias": "align"; "required": false; }; "navigateLeftScreenReaderText": { "alias": "navigateLeftScreenReaderText"; "required": false; }; "navigateRightScreenReaderText": { "alias": "navigateRightScreenReaderText"; "required": false; }; }, { "selectionChanged": "selectionChanged"; "selectedItemIndexChange": "selectedItemIndexChange"; "tabClicked": "tabClicked"; }, never, never, false, never>;
}
//# sourceMappingURL=ui-tabs-controls.component.d.ts.map