import { UiTagMode, UiTagStatus } from './ui-tag.types';
import { ElementRef, EventEmitter, OnChanges, SimpleChanges } from '@angular/core';
import { ThemeVariant } from '@siemens/core';
import { SieIcon, SieIconRegistryService } from '@siemens/icons';
import * as i0 from "@angular/core";
/**
 * # Tag component
 *
 * Tags are used to highlight a status or a category of a particular item with a keyword. They allow quick recognition and navigation.
 *
 * ## Component variations
 *
 * - Non-interactive tag
 * - Interactive tag
 * - Status tag
 * - Interactive without icon tag
 *
 * ## Content
 *
 * The label of the tag component can be any valid markup.
 *
 * ## Code example
 * @example ```html
 * <sie-ui-tag [tagId]="'industrial-software'" (selected)="onTagSelected($event)" (unselected)="onTagUnselected($event)">Industrial Software</sie-ui-tag>
 * <sie-ui-tag mode="noninteractive" [tagId]="'industrial-software'">Industrial Software</sie-ui-tag>
 * <sie-ui-tag status="success">Industrial Software</sie-ui-tag>
 * ```
 */
export declare class UiTagComponent implements OnChanges {
    readonly iconReg: SieIconRegistryService;
    /** @ignore */
    tagButton: ElementRef;
    /**
     * Current {@link UiTagMode Mode} of the tag
     * @default 'unselected'
     */
    mode: UiTagMode;
    /**
     * {@link ThemeVariant Background} of the partial where this component is used
     */
    theme: ThemeVariant;
    /**
     * {@link UiTagStatus Status representation}. When used, the tag is not interactive
     */
    status: UiTagStatus;
    /**
     * ID used to emit as payload of the events:
     * - {@link UiTagComponent.selected}
     * - {@link UiTagComponent.unselected}
     * - {@link UiTagComponent.removed}
     */
    tagId: string;
    /**
     * Name of data attribute to be added to the span element of the tag
     */
    dataAttrName: string;
    /**
     * Value of data attribute to be added to the span element of the tag
     */
    dataAttrValue: string;
    /**
     * @param value Defines if the tag is disabled
     * @default false
     */
    set disabled(value: boolean);
    get disabled(): boolean;
    /**
     * @param value Removes top border radius when used as status tag
     * @default false
     */
    set croppedTop(value: boolean);
    get croppedTop(): boolean;
    /**
     * @param value Defines if the tag should have a smaller size of interactive tags
     * @default false
     */
    set condensed(value: boolean);
    get condensed(): boolean;
    /**
     * @param value Defines if the tag should change mode when in 'interactive-without-icon' variation or be linkable
     * @default false
     */
    set linkable(value: boolean);
    get linkable(): boolean;
    /**
     * Name of data attribute to be added to the span element of the tag
     */
    removeButtonAriaLabel: string;
    /**
     * When the tag is interactive and becomes selected. Payload is {@link UiTagComponent.tagId}
     */
    selected: EventEmitter<string>;
    /**
     * When the tag is interactive and becomes unselected. Payload is {@link UiTagComponent.tagId}
     */
    unselected: EventEmitter<string>;
    /**
     * When the tag is interactive and removable, and when it's removed. Payload is {@link UiTagComponent.tagId}
     */
    removed: EventEmitter<string>;
    /**
     * When the tag is clicked. Payload is {@link UiTagComponent.tagId}
     */
    clicked: EventEmitter<string>;
    private _disabled;
    private _condensed;
    private _croppedTop;
    private _linkable;
    private interactiveWithoutIcon;
    /** @ignore */
    readonly iconReferenceByMode: {
        [key in UiTagMode]: SieIcon;
    };
    constructor(iconReg: SieIconRegistryService);
    ngOnChanges(changes: SimpleChanges): void;
    /** @ignore */
    clickHandler(): void;
    private emitClickEvent;
    private toggleMode;
    private toggleInteractiveWithoutIconMode;
    private isModeInteractiveWithoutIcon;
    static ɵfac: i0.ɵɵFactoryDeclaration<UiTagComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<UiTagComponent, "sie-ui-tag", never, { "mode": { "alias": "mode"; "required": false; }; "theme": { "alias": "theme"; "required": false; }; "status": { "alias": "status"; "required": false; }; "tagId": { "alias": "tagId"; "required": false; }; "dataAttrName": { "alias": "dataAttrName"; "required": false; }; "dataAttrValue": { "alias": "dataAttrValue"; "required": false; }; "disabled": { "alias": "disabled"; "required": false; }; "croppedTop": { "alias": "croppedTop"; "required": false; }; "condensed": { "alias": "condensed"; "required": false; }; "linkable": { "alias": "linkable"; "required": false; }; "removeButtonAriaLabel": { "alias": "removeButtonAriaLabel"; "required": false; }; }, { "selected": "selected"; "unselected": "unselected"; "removed": "removed"; "clicked": "clicked"; }, never, ["*"], false, never>;
}
//# sourceMappingURL=ui-tag.component.d.ts.map