import { ChangeDetectorRef, ElementRef, OnDestroy, OnInit, QueryList } from '@angular/core';
import { Subject } from 'rxjs';
import { UiToastComponent } from '../ui-toast/ui-toast.component';
import { ToastMessageActionItem, UiToastLinkClickedModel, UiToastModel } from '../ui-toast';
import { LayoutService, NativeExposable } from '@siemens/core';
import * as i0 from "@angular/core";
/**
 * # Toast list component
 *
 * Toast list is the component that holds the toast messages inside, allowing us, e.g., to be notified about more than one action at the time.
 * Toast message itself has usage only inside the Toast List component
 *
 * ## Component variations
 *
 * Toast list doesn't have any variations
 *
 * ## Content
 *
 * The toast list can contain toasts managed by the exported functions
 *
 * ## Code example (Static Toast List)
 * @example
 * ```html
 * <sie-ui-toast-list
 *  [toasts]="toasts"
 *  [closeButtonScreenReaderText]="'Close button screen reader text'"
 * ></sie-ui-toast-list>
 * ```
 *
 * ```ts
 * const toasts = [
 *  {
 *    type: 'neutral',
 *    headline: 'Toast headline',
 *    message: 'Toast message lorem ipsum',
 *    messageAfterLink: ' Lorem ipsum dolor sit.',
 *    autoDismissible: false,
 *    autoDismissDelay: 0,
 *    inlineLink: true,
 *    linkLabel: 'link label.',
 *    linkHref: 'link href',
 *    primaryActionLabel: 'Primary action',
 *    secondaryActionLabel: 'Secondary action',
 *    additionalData: {
 *      action: 'RELOAD_ATTRIBUTES',
 *      item: 'itemId'
 *    },
 *    primaryActionCallback: () => {
 *      console.log('primary action done!');
 *    },
 *    secondaryActionCallback: () => {
 *      console.log('secondary action done!');
 *    },
 *    closeActionCallback: () => {
 *      console.log('close action done!');
 *    },
 *    linkActionCallback: () => {
 *      console.log('link action done!');
 *    }
 *  }
 * ];
 * ```
 *
 * # Code Example (Dynamic Toasts)
 * ```html
 * <sie-ui-toast-list
 *   class="toast-list"
 *   (primaryActionClicked)="onToastAction('primary', $event)"
 *   (secondaryActionClicked)="onToastAction('secondary', $event)"
 *   (dismissed)="onToastAction('dismiss', $event)"
 *   #toastListComponent
 * ></sie-ui-toast-list>
 *
 * <button (click)="toastListComponent.add({ headline: 'test' })">Add Toast</button>
 * ```
 */
export declare class UiToastListComponent implements NativeExposable, OnDestroy, OnInit {
    private readonly cdr;
    readonly hostElement: ElementRef;
    private readonly layoutService;
    /** @ignore */
    listElement: ElementRef;
    /** @ignore */
    toastComponents: QueryList<UiToastComponent>;
    /**
     * Determines the delay of the automatic dismissal (in milliseconds)
     * @default 6000
     */
    autoDismissDelay: number;
    /**
     * Defines the close button screen reader text
     * @default ''
     */
    closeButtonScreenReaderText: string;
    get toasts(): UiToastModel[];
    /**
     * @param value {@link UiToastModel Toasts} to be displayed inside the list
     */
    set toasts(value: UiToastModel[]);
    private _toasts;
    private readonly subscription;
    /** @ignore */
    entranceAnimations: import("../ui-toast").UiToastEntranceAnimation[];
    /** @ignore */
    exitAnimations: import("../ui-toast").UiToastExitAnimation[];
    /** @ignore */
    initialHeightAnimationState: import("../ui-toast").UiToastExitAnimation;
    /** @ignore */
    initialOpacityAnimationState: import("../ui-toast").UiToastEntranceAnimation;
    /**
     * Event triggered when the primary action button inside the toast is clicked {@link ToastMessageActionItem}
     */
    primaryActionClicked: Subject<ToastMessageActionItem>;
    /**
     * Event triggered when the primary action button inside the toast is clicked {@link ToastMessageActionItem}
     */
    secondaryActionClicked: Subject<ToastMessageActionItem>;
    /**
     * Event triggered when the secondary action button inside the toast is clicked {@link UiToastLinkClickedModel}
     */
    linkClicked: Subject<UiToastLinkClickedModel>;
    /**
     * Event triggered when the link inside the toast message is clicked {@link ToastMessageActionItem}
     */
    dismissed: Subject<ToastMessageActionItem>;
    constructor(cdr: ChangeDetectorRef, hostElement: ElementRef, layoutService: LayoutService);
    /** @ignore */
    ngOnInit(): void;
    /** @ignore */
    ngOnDestroy(): void;
    /** @ignore */
    trackByFn(_index: number, model: UiToastModel): string;
    /**
     * Adds another Toast into the Toast list
     *
     * @param toastModel
     */
    add(toastModel: UiToastModel): void;
    /** @ignore */
    slideInListItem(item: any): void;
    /** @ignore */
    dismissToast(toastId: string): void;
    /** @ignore */
    removeToast(toastActionData: ToastMessageActionItem): void;
    /** @ignore */
    onPrimaryAction(toastActionData: ToastMessageActionItem): void;
    /** @ignore */
    onSecondaryAction(toastActionData: ToastMessageActionItem): void;
    /** @ignore */
    onLinkClick(linkClicked: UiToastLinkClickedModel): void;
    /** @ignore */
    onDismissAction(toastActionData: ToastMessageActionItem): void;
    private pauseToastAutoDismiss;
    private resumeToastAutoDismiss;
    /** @ignore */
    animationChanged(): void;
    private setAnimations;
    static ɵfac: i0.ɵɵFactoryDeclaration<UiToastListComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<UiToastListComponent, "sie-ui-toast-list", never, { "autoDismissDelay": { "alias": "autoDismissDelay"; "required": false; }; "closeButtonScreenReaderText": { "alias": "closeButtonScreenReaderText"; "required": false; }; "toasts": { "alias": "toasts"; "required": false; }; }, { "primaryActionClicked": "primaryActionClicked"; "secondaryActionClicked": "secondaryActionClicked"; "linkClicked": "linkClicked"; "dismissed": "dismissed"; }, never, never, false, never>;
}
//# sourceMappingURL=ui-toast-list.component.d.ts.map