import { AfterViewInit, ChangeDetectorRef, ElementRef, OnDestroy, OnInit } from '@angular/core';
import { LayoutService } from '@siemens/core';
import { SieIcon, SieIconRegistryService } from '@siemens/icons';
import { Subject } from 'rxjs';
import { UiToastEntranceAnimation, UiToastExitAnimation, UiToastType } from './ui-toast.types';
import { ToastMessageActionItem, ToastMessageAdditionalData, UiToastLinkClickedModel } from './ui-toast.model';
import { UiToastComponentService } from './ui-toast.component.service';
import { UiBasicNavigationTarget } from '../shared/models';
import * as i0 from "@angular/core";
/**
 * # Toast component
 *
 * Toast messages are notifications used to inform a user about e.g. outcome status of the action the user has taken.
 * Toast message itself has usage only inside the Toast List component.
 *
 * ## Component variations
 *
 * There are no variations.
 *
 * ## Content
 *
 * The toast component does not accept any content.
 *
 * ## Code example
 * @example ```html
 * <sie-ui-toast
 *  type="neutral"
 *  headline="Toast headline"
 *  message='Toast message'
 *  messageAfterLink="Message that comes after link"
 *  [autoDismissible]="false"
 *  [autoDismissDelay]="0"
 *  linkLabel="Link label"
 *  linkHref="Link href"
 *  primaryActionLabel="Primary action"
 *  secondaryActionLabel="Secondary action"
 * ></sie-ui-toast>
 * ```
 */
export declare class UiToastComponent implements OnInit, OnDestroy, AfterViewInit {
    readonly iconReg: SieIconRegistryService;
    private readonly cdr;
    readonly layoutService: LayoutService;
    private readonly uiToastComponentService;
    /** @ignore */
    role: string;
    /** @ignore */
    get heightChangeAnimation(): {
        value: UiToastExitAnimation | UiToastEntranceAnimation;
        params: {
            height: number;
        };
    };
    /** @ignore */
    get opacityChangeAnimation(): UiToastExitAnimation | UiToastEntranceAnimation;
    /** @ignore */
    contentRef: ElementRef;
    /**
     * Toast identifier, must be unique for each toast
     */
    id: string;
    /**
     * Headline of the toast
     */
    headline: string;
    /**
     * The message that the toast is delivering
     */
    message: string;
    /**
     * The message shown after the link
     */
    messageAfterLink?: string;
    /**
     * Defines the text that the screen reader will read
     */
    closeButtonScreenReaderText: string;
    /**
     * Determines whether the link is inline or not
     * @default true
     */
    set inlineLink(value: boolean);
    get inlineLink(): boolean;
    /**
     * The label of the link
     */
    linkLabel: string;
    /**
     * Determines href of the link
     */
    linkHref: string;
    /**
     * Determines in which {@link UiBasicNavigationTarget tab} the link should open
     * @default '_blank'
     */
    linkTarget: UiBasicNavigationTarget;
    /**
     * Determines the router href
     */
    routerHref?: string;
    /**
     * {@link ToastMessageAdditionalData Additional data} of the toast that is being passed to the primary or secondary action and dismissed event
     */
    additionalData?: ToastMessageAdditionalData;
    /**
     * The label of the primary action button
     */
    primaryActionLabel: string;
    /**
     * The label of the secondary action button
     */
    secondaryActionLabel: string;
    /**
     * Determines the code to be executed when primary action button gets triggered
     */
    primaryActionCallback: () => void;
    /**
     * Determines the code to be executed when secondary action button gets triggered
     */
    secondaryActionCallback: () => void;
    /**
     * Determines the code to be executed when close button action gets triggered
     */
    closeActionCallback: () => void;
    /**
     * Determines the code to be executed when link action gets triggered
     */
    linkActionCallback: (linkClicked?: UiToastLinkClickedModel) => void;
    /**
     * @param type Determines the {@link UiToastType type} of the toast message
     * @default 'neutral'
     */
    set type(type: UiToastType);
    get type(): UiToastType;
    /**
     * @param value Determines the delay of the automatic dismissal (in milliseconds)
     */
    set autoDismissDelay(value: number);
    get autoDismissDelay(): number;
    /**
     * @param value Determines if the toast is automatically dismissible or not
     * @default false
     */
    set autoDismissible(value: boolean);
    get autoDismissible(): boolean;
    /**
     * @param value Determines {@link UiToastEntranceAnimation entrance animation} of the toast message
     */
    set entranceAnimation(value: UiToastEntranceAnimation[]);
    get entranceAnimation(): UiToastEntranceAnimation[];
    /**
     * @param value Determines {@link UiToastExitAnimation exit animation} of the toast message
     */
    set exitAnimation(value: UiToastExitAnimation[]);
    get exitAnimation(): UiToastExitAnimation[];
    /**
     * Determines initial height animation state (e.g. {@link UiToastExitAnimation exit animation}, {@link UiToastEntranceAnimation entrance animation})
     */
    initialHeightAnimationState: UiToastExitAnimation | UiToastEntranceAnimation;
    /**
     * Determines initial opacity animation state (e.g. {@link UiToastExitAnimation exit animation}, {@link UiToastEntranceAnimation entrance animation})
     */
    initialOpacityAnimationState: UiToastExitAnimation | UiToastEntranceAnimation;
    /**
     * Event triggered when the toast message is displayed
     */
    displayed: Subject<void>;
    /**
     * Event triggered when the toast message is dismissed {@link ToastMessageActionItem}
     */
    dismissed: Subject<ToastMessageActionItem>;
    /**
     * Event triggered when the primary action button inside the toast is clicked {@link ToastMessageActionItem}
     */
    primaryActionClicked: Subject<ToastMessageActionItem>;
    /**
     * Event triggered when the secondary action button inside the toast is clicked {@link ToastMessageActionItem}
     */
    secondaryActionClicked: Subject<ToastMessageActionItem>;
    /**
     * Event triggered when the link inside the toast message is clicked {@link UiToastLinkClickedModel}
     */
    linkClicked: Subject<UiToastLinkClickedModel>;
    /**
     * Event triggered when the toast changes the animation
     */
    animationChange: Subject<void>;
    /** @ignore */
    get headlineIcon(): SieIcon;
    /** @ignore */
    get contentHeight(): number;
    private _contentHeight;
    private _entranceAnimation;
    private _exitAnimation;
    private _autoDismissDelay;
    private _inlineLink;
    private _autoDismissible;
    private _type;
    private _headlineIcon;
    private autoDismissTimer;
    private animationQueue;
    private _heightChangeAnimation;
    private _opacityChangeAnimation;
    private breakpointSubscription;
    private readonly rendered;
    private renderedSubscription;
    constructor(iconReg: SieIconRegistryService, cdr: ChangeDetectorRef, layoutService: LayoutService, uiToastComponentService: UiToastComponentService);
    private static getAnimationType;
    private static getAnimationTarget;
    /** @ignore */
    ngOnInit(): void;
    /** @ignore */
    ngOnDestroy(): void;
    /** @ignore */
    ngAfterViewInit(): void;
    /** @ignore */
    enter(): void;
    /** @ignore */
    exit(closeButtonClicked?: Event): void;
    /** @ignore */
    pauseAutoDismissTimer(): void;
    /** @ignore */
    resumeAutoDismissTimer(): void;
    /** @ignore */
    onPrimaryAction(): void;
    /** @ignore */
    onSecondaryAction(): void;
    /** @ignore */
    onLinkClicked(linkClicked: UiToastLinkClickedModel): void;
    private doAnimations;
    private animationDone;
    private handleAnimationEnd;
    private createDismissTimer;
    static ɵfac: i0.ɵɵFactoryDeclaration<UiToastComponent, [null, { optional: true; skipSelf: true; }, null, null]>;
    static ɵcmp: i0.ɵɵComponentDeclaration<UiToastComponent, "sie-ui-toast", never, { "id": { "alias": "id"; "required": false; }; "headline": { "alias": "headline"; "required": false; }; "message": { "alias": "message"; "required": false; }; "messageAfterLink": { "alias": "messageAfterLink"; "required": false; }; "closeButtonScreenReaderText": { "alias": "closeButtonScreenReaderText"; "required": false; }; "inlineLink": { "alias": "inlineLink"; "required": false; }; "linkLabel": { "alias": "linkLabel"; "required": false; }; "linkHref": { "alias": "linkHref"; "required": false; }; "linkTarget": { "alias": "linkTarget"; "required": false; }; "routerHref": { "alias": "routerHref"; "required": false; }; "additionalData": { "alias": "additionalData"; "required": false; }; "primaryActionLabel": { "alias": "primaryActionLabel"; "required": false; }; "secondaryActionLabel": { "alias": "secondaryActionLabel"; "required": false; }; "primaryActionCallback": { "alias": "primaryActionCallback"; "required": false; }; "secondaryActionCallback": { "alias": "secondaryActionCallback"; "required": false; }; "closeActionCallback": { "alias": "closeActionCallback"; "required": false; }; "linkActionCallback": { "alias": "linkActionCallback"; "required": false; }; "type": { "alias": "type"; "required": false; }; "autoDismissDelay": { "alias": "autoDismissDelay"; "required": false; }; "autoDismissible": { "alias": "autoDismissible"; "required": false; }; "entranceAnimation": { "alias": "entranceAnimation"; "required": false; }; "exitAnimation": { "alias": "exitAnimation"; "required": false; }; "initialHeightAnimationState": { "alias": "initialHeightAnimationState"; "required": false; }; "initialOpacityAnimationState": { "alias": "initialOpacityAnimationState"; "required": false; }; }, { "displayed": "displayed"; "dismissed": "dismissed"; "primaryActionClicked": "primaryActionClicked"; "secondaryActionClicked": "secondaryActionClicked"; "linkClicked": "linkClicked"; "animationChange": "animationChange"; }, never, never, false, never>;
}
//# sourceMappingURL=ui-toast.component.d.ts.map