import { UiOverflowComponent } from '../ui-overflow/ui-overflow.component';
import { AfterViewInit, ChangeDetectorRef, EventEmitter, QueryList } from '@angular/core';
import { UiTreeNodeModel } from './ui-tree-node.model';
import { SieIconRegistryService } from '@siemens/icons';
import { UiCheckboxComponent } from '../ui-checkbox';
import * as i0 from "@angular/core";
export type BreadCrumbTreeSelection = 'full' | 'partial';
/**
 * # Tree List Component
 *
 * Tree list provides the user a set of nested options to choose from, either a single option only or a multitude of options.
 *
 * ## Component variations
 *
 * - Single select
 * - Multi select
 *
 * ## Content
 *
 * Tree list component does not accept any content
 *
 * ## Code example
 * @example
 * Template:
 * ```html
 * <sie-ui-tree-list
 *   [multiSelect]="true"
 *   [nodes]="treeListNodes"
 *   [breadCrumbSelection]="'partial'"
 *   [selectedNodes]="[]"
 *   [overflowLimit]="'5'"
 *   [overflowHeadlineCollapsed]="'Expandable button more'"
 *   [overflowHeadlineExpanded]="'Expandable button less'"
 *   [backToLabel]="'Tree list back to label'"
 *   [showSelectAllNode]="'Tree List Show All'"
 *   [selectAllLabel]="'All'"
 *   (selectedNodesChanged)="selectedNodesChanged($event)"
 *   (newNodeSelected)="newNodeSelected($event)"
 *   (overflowToggled)="overflowToggled($event)"
 * ></sie-ui-tree-list>
 * ```
 *
 * Data example:
 * ```js
 * const treeListNodeData = [
 *   {
 *     id: 'all',
 *     label: 'All',
 *     children: [
 *       {
 *         id: '13204',
 *         label: 'Drive Technology (4291)',
 *         children: [
 *           {
 *             id: '13205',
 *             label: 'Converters (2079)'
 *           }
 *         ]
 *       }
 *     ],
 *     selected: true
 *   }
 * ];
 * ```
 */
export declare class UiTreeListComponent implements AfterViewInit {
    readonly iconReg: SieIconRegistryService;
    private readonly cdr;
    /** @ignore */
    overflowComponent: UiOverflowComponent;
    /** @ignore */
    selectAllCheckbox: UiCheckboxComponent;
    /** @ignore */
    multiSelectCheckboxes: QueryList<UiCheckboxComponent>;
    /**
     * Defines title data when overflow is in collapsed state
     */
    overflowHeadlineCollapsed: string;
    /**
     * Defines title data when overflow is in expanded state
     */
    overflowHeadlineExpanded: string;
    /**
     * Defines how many nodes should be visible before overflow is used
     */
    overflowLimit: string;
    /**
     * Defines the `back to` label of the current node
     */
    backToLabel: string;
    /**
     * Defines the label for selecting all items
     */
    selectAllLabel: string;
    /**
     * Defines if the multi-select is enabled
     * @default false
     */
    set multiSelect(value: boolean);
    get multiSelect(): boolean;
    /**
     * Defines which nodes are selected
     * @default empty array
     */
    set selectedNodes(selectedNodes: Array<string>);
    get selectedNodes(): Array<string>;
    /**
     * Main source of the nodes data that should be displayed
     * @default empty array
     */
    set nodes(nodes: Array<UiTreeNodeModel>);
    get nodes(): UiTreeNodeModel[];
    /**
     * Defines which breadcrumb mode should be used. Applicable only in case of single-select mode.
     * In `'partial'` mode if selected node has no children, it will not be moved to the breadcrumb section.
     * In `'full'` mode if selected node has no children, it will be moved to the breadcrumb section
     * @default 'partial'
     */
    set breadCrumbSelection(breadCrumbSelection: BreadCrumbTreeSelection);
    get breadCrumbSelection(): BreadCrumbTreeSelection;
    /**
     * Defines if the option to select all should be shown or not
     * @default true
     */
    set showSelectAllNode(value: boolean);
    get showSelectAllNode(): boolean;
    /**
     * Defines whether the overflow should be expanded on initial component render
     * @default false
     */
    expandOverflowInitially: boolean;
    /**
     * Event triggered when a tree list selection is changed.
     * The event data is the list of selected node IDs.
     */
    selectedNodesChanged: EventEmitter<string[]>;
    /**
     * Event triggered when a new tree list node is selected.
     * The event data is the selected {@link UiTreeNodeModel Tree node data}
     */
    newNodeSelected: EventEmitter<UiTreeNodeModel>;
    /**
     * Event triggered when overflow component gets toggled by the user.
     * The event data is a boolean and will be true, false for expanded, collapsed respectively.
     */
    overflowToggled: EventEmitter<boolean>;
    /** @ignore */
    isOpen: boolean;
    /** @ignore */
    focusRadioButton: boolean;
    /** @ignore */
    hasFocus: boolean;
    /** @ignore */
    breadcrumbs: Array<UiTreeNodeModel>;
    /** @ignore */
    activeNode: UiTreeNodeModel;
    /** @ignore */
    visibleNodeId: string;
    /** @ignore */
    readonly uniqueId: string;
    /** @ignore */
    readonly itemLimit = 2;
    private _multiSelect;
    private initialized;
    private _selectedNodes;
    private _nodes;
    private _breadCrumbSelection;
    private _showSelectAll;
    constructor(iconReg: SieIconRegistryService, cdr: ChangeDetectorRef);
    /** @ignore */
    ngAfterViewInit(): void;
    /** @ignore */
    onFocus(hasFocus: boolean): void;
    /** @ignore */
    onSingleTreeSelection(node: UiTreeNodeModel): void;
    private updateTreeList;
    private updateSingleSelectTreeList;
    private initMultiSelectTreeList;
    private updateMultiSelectTreeList;
    private updateBreadCrumbsAndActiveNode;
    /** @ignore */
    handleMultiSelectChange(node: UiTreeNodeModel, state: boolean): void;
    /** @ignore */
    openNode(node: UiTreeNodeModel): void;
    private focusFirstCheckbox;
    /** @ignore */
    isIndeterminate(node: UiTreeNodeModel): boolean;
    static ɵfac: i0.ɵɵFactoryDeclaration<UiTreeListComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<UiTreeListComponent, "sie-ui-tree-list", never, { "overflowHeadlineCollapsed": { "alias": "overflowHeadlineCollapsed"; "required": false; }; "overflowHeadlineExpanded": { "alias": "overflowHeadlineExpanded"; "required": false; }; "overflowLimit": { "alias": "overflowLimit"; "required": false; }; "backToLabel": { "alias": "backToLabel"; "required": false; }; "selectAllLabel": { "alias": "selectAllLabel"; "required": false; }; "multiSelect": { "alias": "multiSelect"; "required": false; }; "selectedNodes": { "alias": "selectedNodes"; "required": false; }; "nodes": { "alias": "nodes"; "required": false; }; "breadCrumbSelection": { "alias": "breadCrumbSelection"; "required": false; }; "showSelectAllNode": { "alias": "showSelectAllNode"; "required": false; }; "expandOverflowInitially": { "alias": "expandOverflowInitially"; "required": false; }; }, { "selectedNodesChanged": "selectedNodesChanged"; "newNodeSelected": "newNodeSelected"; "overflowToggled": "overflowToggled"; }, never, never, false, never>;
}
//# sourceMappingURL=ui-tree-list.component.d.ts.map