import { UiVerticalProgressTrackerItem } from './ui-vertical-progress-tracker-types';
import { UiVerticalProgressTrackerItemComponent } from './ui-vertical-progress-tracker-item/ui-vertical-progress-tracker-item.component';
import { AfterViewInit, ChangeDetectorRef, ElementRef, EventEmitter, QueryList } from '@angular/core';
import { UiVerticalProgressTrackerItemDirective } from './ui-vertical-progress-tracker-item/ui-vertical-progress-tracker-item.directive';
import { UiVerticalProgressTrackerComponentService } from './ui-vertical-progress-tracker.component.service';
import * as i0 from "@angular/core";
/**
 * # Vertical Progress Tracker Component
 *
 * Vertical Progress Tracker tracks multistep processes and shows the status of different steps.
 * It can be used where multi-step processes like checkout, data package compilation, etc. are involved.
 *
 * ## Component variations
 *
 * Vertical Progress Tracker doesn't have any variations.
 *
 * ## Content
 *
 * The content of vertical progress tracker items can be any valid markup.
 * Next to the parameters, the content can be passed as child elements with using `sieUiVerticalProgressTrackerItem` directive.
 * See the example below.
 *
 * ## Code example
 * @example
 * Template:
 * ```html
 * <sie-ui-vertical-progress-tracker #verticalProgressTracker>
 *  <ng-template
 *   sieUiVerticalProgressTrackerItem
 *   label="Some component label"
 *   status="active"
 *   selectedValue="this value was available before"
 *   [open]="true"
 *   >
 *    Item 1
 *  <ng-template [ngTemplateOutlet]="previousNextButtons"></ng-template>
 *  </ng-template>
 *  <ng-template sieUiVerticalProgressTrackerItem label="Another component label" status="idle">
 *    Item 2
 *  <ng-template [ngTemplateOutlet]="previousNextButtons"></ng-template>
 *  </ng-template>
 * </sie-ui-vertical-progress-tracker>
 *
 * <ng-template #previousNextButtons>
 *  <sie-ui-button
 *   variant="tertiary"
 *   icon="ArrowUp"
 *   buttonType="button"
 *   themeType="un-contained"
 *   (clicked)="onPreviousStepClicked()"
 *   [disabled]="disablePreviousStep"
 *  >Previous</sie-ui-button>
 *  <sie-ui-button
 *   variant="tertiary"
 *   icon="ArrowDown"
 *   buttonType="button"
 *   themeType="un-contained"
 *   iconPosition="trailing"
 *   (clicked)="onNextStepClicked()"
 *   [disabled]="disableNextStep"
 *   >Next</sie-ui-button>
 * </ng-template>
 * ```
 *
 * Component:
 * ```js
 *
 * disableNextStep: boolean;
 * disablePreviousStep: boolean;
 *
 * onPreviousStepClicked(): void {
 *  this.verticalProgressTracker.onPreviousStepClicked();
 * }
 *
 * onNextStepClicked(): void {
 *  this.verticalProgressTracker.onNextStepClicked();
 * }
 *
 * nextStepDisabled(): boolean {
 *  return this.verticalProgressTracker.nextStepDisabled();
 * }
 *
 * previousStepDisabled(): boolean {
 *  return !this.verticalProgressTracker.previousStepExists();
 * }
 * ```
 */
export declare class UiVerticalProgressTrackerComponent implements AfterViewInit {
    readonly cdr: ChangeDetectorRef;
    private readonly uiVerticalProgressTrackerComponentService;
    /** @ignore */
    items: QueryList<UiVerticalProgressTrackerItemDirective> | UiVerticalProgressTrackerItem[];
    /** @ignore */
    verticalProgressTrackerItems: QueryList<UiVerticalProgressTrackerItemComponent>;
    /** @ignore */
    elementsRef: ElementRef;
    /**
     * Defines if selected value should be displayed
     * @default true
     */
    set displaySelectedValue(value: boolean);
    get displaySelectedValue(): boolean;
    /**
     * Event triggered when the vertical progress tracker item is clicked
     */
    itemClicked: EventEmitter<number>;
    /** @ignore */
    initialItemIndex: number;
    private _displaySelectedValue;
    constructor(cdr: ChangeDetectorRef, uiVerticalProgressTrackerComponentService: UiVerticalProgressTrackerComponentService<unknown, UiVerticalProgressTrackerComponent>);
    /** @ignore */
    ngAfterViewInit(): void;
    /** @ignore */
    onInitialItemIndex(initialItemId: number): void;
    /** @ignore */
    onItemClicked(itemId: number): void;
    /**
     * Method that if the previous step exist opens it and go to that step
     */
    onPreviousStepClicked(): void;
    /**
     * Method that if the next step exists and is not disabled open it and goes to that step
     */
    onNextStepClicked(): void;
    /**
     * Method that defines if the next step in vertical progress tracker is disabled
     * @returns boolean value
     */
    nextStepDisabled(): boolean;
    /**
     * Method that defines if the previous step in vertical progress tracker is disabled
     * @returns boolean value
     */
    previousStepDisabled(): boolean;
    /** @ignore */
    nextStepStatus(index: number): string;
    /** @ignore */
    previousStepStatus(index: number): string;
    /** @ignore */
    nextStepOpen(index: number): boolean;
    /**
     * Method that defines if the previous step in vertical progress tracker exist
     * @returns boolean value
     */
    previousStepExists(): boolean;
    private loopItemsAndToggle;
    /**
     * Opens designated step by index number and closes other opened step (incl. animation).
     *
     * Disclaimer: There is no check if the step is disabled as this can be done from outside.
     *
     * @param index Index of step to be open. (If index is active step or if index is out of order the action is ignored)
     */
    openStep(index: number): void;
    /** @ignore Use only intended in web components */
    openNextStep(): void;
    /** @ignore Use only intended in web components */
    openPreviousStep(): void;
    /** @ignore Use only intended in web components */
    checkIfPreviousStepExists(): boolean;
    /** @ignore Use only intended in web components */
    checkIfNextStepDisabled(): boolean;
    static ɵfac: i0.ɵɵFactoryDeclaration<UiVerticalProgressTrackerComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<UiVerticalProgressTrackerComponent, "sie-ui-vertical-progress-tracker", never, { "displaySelectedValue": { "alias": "displaySelectedValue"; "required": false; }; "openNextStep": { "alias": "openNextStep"; "required": false; }; "openPreviousStep": { "alias": "openPreviousStep"; "required": false; }; "checkIfPreviousStepExists": { "alias": "checkIfPreviousStepExists"; "required": false; }; "checkIfNextStepDisabled": { "alias": "checkIfNextStepDisabled"; "required": false; }; }, { "itemClicked": "itemClicked"; }, ["items"], [".item"], false, never>;
}
//# sourceMappingURL=ui-vertical-progress-tracker.component.d.ts.map